-- ARCHIVO CON LAS ACTUALIZACIONES DE DATA DE SQL PARA MIGRAR AL NUEVO BUILD DEL NOMBRE DE LA CARPETA
-- DECLARAMOS DOS VARIABLES, UNA CON LA VERSION DE LA QUE PARTIMOS Y OTRA CON LA NUEVA VERSION QUE ESTAMOS APUNTANDO
DECLARE @OLD_DATABASE_BUILD_VERSION VARCHAR(50) = '6.2.0'
DECLARE @NEW_DATABASE_BUILD_VERSION VARCHAR(50) = '6.2.1'

-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
BEGIN TRY
    -- VALIDAMOS QUE LA VERSION EXISTENTE COINCIDE CON NUESTRA NEW_DATABASE_BUILD_VERSION
    IF NOT EXISTS (
        SELECT 1 
            FROM [dbo].[Version] V 
            WHERE V.[BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    )	
        -- LANZAMOS UN MENSAJE DE ERROR INDICANDO QUE LA VERSION ACTUAL NO COINCIDE CON LA OLD_DATABASE_BUILD_VERSION
        RAISERROR('DATABASE_ERROR_INCORRECT_TARGET_VERSION', 16, 16)
        
    -- INICIAMOS LA TRANSACCION
    BEGIN TRANSACTION




    -- AQUI EMPIEZA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION
    -- ELIMINAR LOS NLU DE SENTIMIENTOS QUE NO SERAN NECESARIOS 
    DELETE Utterance 
        FROM  Utterance U 
        INNER JOIN NLU N 
            ON U.AppId = N.AppId
                AND U.VCC = N.VCC
                AND N.VCC <> 'system'
                AND N.isSystemApp = 1
                AND N.Name like 'sentiment-%'

    DELETE Intent
        FROM Intent I
        INNER JOIN NLU N 
            ON I.AppId = N.AppId
                AND I.VCC = N.VCC
                AND N.VCC <> 'system'
                AND N.isSystemApp = 1
                AND N.Name like 'sentiment-%'

    DELETE FROM NLU
        WHERE [VCC] <> 'system'
            AND [isSystemApp] = 1
            AND [Name] like 'sentiment-%'

	-- ACTUALIZAR LOS NLUS DE SENTIMIENTOS DE SISTEMAS


    UPDATE NLU 
        SET [NeedTrain] = 1,
			[NeedPublish] = 0,
			[isTrained] = 0,
			[isPublished] = 0
		WHERE VCC = 'system' 
			AND [name] IN ('sentiment-es','sentiment-en')	

    UPDATE NLU 
        SET [cognitiveEngine] = 'RASA'
		WHERE VCC = 'system' 
        
    -- AGREGAR INTENCIONES DE NLUS DE SENTIMIENTOS.
        
    INSERT INTO [dbo].[Intent]([VCC], [Name],[IntentId],[AppId],[Color],[CreatedDate],[CreatedByUserId],[LastModifiedDate], [LastModifiedByUserId], [TimeStamp],[Status],[StatusCode]) VALUES ('system','Positive','Positive','system::sentiment-en','far fa-smile',GETUTCDATE(),'system',GETUTCDATE(),'system',GETUTCDATE(),1,'AVAILABLE')
    INSERT INTO [dbo].[Intent]([VCC], [Name],[IntentId],[AppId],[Color],[CreatedDate],[CreatedByUserId],[LastModifiedDate], [LastModifiedByUserId], [TimeStamp],[Status],[StatusCode]) VALUES ('system','Negative','Negative','system::sentiment-en','far fa-frown',GETUTCDATE(),'system',GETUTCDATE(),'system',GETUTCDATE(),1,'AVAILABLE')
    INSERT INTO [dbo].[Intent]([VCC], [Name],[IntentId],[AppId],[Color],[CreatedDate],[CreatedByUserId],[LastModifiedDate], [LastModifiedByUserId], [TimeStamp],[Status],[StatusCode]) VALUES ('system','Neutral','Neutral','system::sentiment-en','far fa-meh',GETUTCDATE(),'system',GETUTCDATE(),'system',GETUTCDATE(),1,'AVAILABLE')

    INSERT INTO [dbo].[Intent]([VCC], [Name],[IntentId],[AppId],[Color],[CreatedDate],[CreatedByUserId],[LastModifiedDate], [LastModifiedByUserId], [TimeStamp],[Status],[StatusCode]) VALUES ('system','Positive','Positive','system::sentiment-es','far fa-smile',GETUTCDATE(),'system',GETUTCDATE(),'system',GETUTCDATE(),1,'AVAILABLE')
    INSERT INTO [dbo].[Intent]([VCC], [Name],[IntentId],[AppId],[Color],[CreatedDate],[CreatedByUserId],[LastModifiedDate], [LastModifiedByUserId], [TimeStamp],[Status],[StatusCode]) VALUES ('system','Negative','Negative','system::sentiment-es','far fa-frown',GETUTCDATE(),'system',GETUTCDATE(),'system',GETUTCDATE(),1,'AVAILABLE')
    INSERT INTO [dbo].[Intent]([VCC], [Name],[IntentId],[AppId],[Color],[CreatedDate],[CreatedByUserId],[LastModifiedDate], [LastModifiedByUserId], [TimeStamp],[Status],[StatusCode]) VALUES ('system','Neutral','Neutral','system::sentiment-es','far fa-meh',GETUTCDATE(),'system',GETUTCDATE(),'system',GETUTCDATE(),1,'AVAILABLE')

    INSERT INTO [dbo].[Intent]([VCC], [Name],[IntentId],[AppId],[Color],[CreatedDate],[CreatedByUserId],[LastModifiedDate], [LastModifiedByUserId], [TimeStamp],[Status],[StatusCode]) VALUES ('system','Positive','Positive','system::sentiment-pt','far fa-smile',GETUTCDATE(),'system',GETUTCDATE(),'system',GETUTCDATE(),1,'AVAILABLE')
    INSERT INTO [dbo].[Intent]([VCC], [Name],[IntentId],[AppId],[Color],[CreatedDate],[CreatedByUserId],[LastModifiedDate], [LastModifiedByUserId], [TimeStamp],[Status],[StatusCode]) VALUES ('system','Negative','Negative','system::sentiment-pt','far fa-frown',GETUTCDATE(),'system',GETUTCDATE(),'system',GETUTCDATE(),1,'AVAILABLE')
    INSERT INTO [dbo].[Intent]([VCC], [Name],[IntentId],[AppId],[Color],[CreatedDate],[CreatedByUserId],[LastModifiedDate], [LastModifiedByUserId], [TimeStamp],[Status],[StatusCode]) VALUES ('system','Neutral','Neutral','system::sentiment-pt','far fa-meh',GETUTCDATE(),'system',GETUTCDATE(),'system',GETUTCDATE(),1,'AVAILABLE')

    INSERT INTO [dbo].[Intent]([VCC], [Name],[IntentId],[AppId],[Color],[CreatedDate],[CreatedByUserId],[LastModifiedDate], [LastModifiedByUserId], [TimeStamp],[Status],[StatusCode]) VALUES ('system','Positive','Positive','system::sentiment-fr','far fa-smile',GETUTCDATE(),'system',GETUTCDATE(),'system',GETUTCDATE(),1,'AVAILABLE')
    INSERT INTO [dbo].[Intent]([VCC], [Name],[IntentId],[AppId],[Color],[CreatedDate],[CreatedByUserId],[LastModifiedDate], [LastModifiedByUserId], [TimeStamp],[Status],[StatusCode]) VALUES ('system','Negative','Negative','system::sentiment-fr','far fa-frown',GETUTCDATE(),'system',GETUTCDATE(),'system',GETUTCDATE(),1,'AVAILABLE')
    INSERT INTO [dbo].[Intent]([VCC], [Name],[IntentId],[AppId],[Color],[CreatedDate],[CreatedByUserId],[LastModifiedDate], [LastModifiedByUserId], [TimeStamp],[Status],[StatusCode]) VALUES ('system','Neutral','Neutral','system::sentiment-fr','far fa-meh',GETUTCDATE(),'system',GETUTCDATE(),'system',GETUTCDATE(),1,'AVAILABLE')
     
    -- AQUI TERMINA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION
    -- ACTUALIZAR LA DATA DE SENTIMIENTOS SI EXISTIERAN REGISTROS 
    

    

    -- TERMINAMOS LA ACTUALIZACION DE DATA ACTUALIZANDO EL BUILDVERSION
    UPDATE [dbo].[Version] 
        SET [BuildVersion] = @NEW_DATABASE_BUILD_VERSION, 
            [IsRegistered] = 0,
            [TimeStamp] = GETUTCDATE() 
        WHERE [BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    PRINT 'UPDATED_DATABASE_BUILD_VERSION'

    -- COMPLETAMOS LA TRANSACCION
    COMMIT TRANSACTION
END TRY
BEGIN CATCH
    IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

    DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
    DECLARE @Severity integer = ERROR_SEVERITY()
    DECLARE @State integer = ERROR_STATE()

    RAISERROR(@Message, @Severity, @State)
    --RETURN -1
END CATCH