IF EXISTS (select top 1 1 from [dbo].[Audio])
    RAISERROR (N'Se detectaron filas. La actualización del esquema va a terminar debido a una posible pérdida de datos.', 16, 127) WITH NOWAIT

GO
PRINT N'Quitando Restricción DEFAULT [dbo].[DF_AuditorEvaluationPlan_IsDeleted]...';


GO
ALTER TABLE [dbo].[AuditorEvaluationPlan] DROP CONSTRAINT [DF_AuditorEvaluationPlan_IsDeleted];


GO
PRINT N'Creando Índice [dbo].[Audio].[GetI6AlreadyRegisteredCallInteractions_01]...';


GO
CREATE NONCLUSTERED INDEX [GetI6AlreadyRegisteredCallInteractions_01]
    ON [dbo].[Audio]([VCC] ASC, [ID] ASC);


GO
PRINT N'Iniciando recompilación de la tabla [dbo].[AuditorEvaluationPlan]...';


GO
BEGIN TRANSACTION;

SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;

SET XACT_ABORT ON;

CREATE TABLE [dbo].[tmp_ms_xx_AuditorEvaluationPlan] (
    [Instance]             VARCHAR (50)   NOT NULL,
    [IdEvaluationPlan]     VARCHAR (50)   NOT NULL,
    [IdAuditor]            VARCHAR (50)   NOT NULL,
    [IdInteraction]        VARCHAR (250)  NOT NULL,
    [Completed]            BIT            NULL,
    [Score]                NUMERIC (5, 2) NULL,
    [AutomaticScore]       NUMERIC (5, 2) NULL,
    [ManualScore]          NUMERIC (5, 2) NULL,
    [IdCampaign]           VARCHAR (50)   NOT NULL,
    [IdAgent]              VARCHAR (50)   NOT NULL,
    [InteractionDate]      DATETIME       NULL,
    [InteractionType]      VARCHAR (50)   NOT NULL,
    [InteractionDuration]  NUMERIC (8)    NULL,
    [InteractionOrigin]    VARCHAR (50)   NULL,
    [InteractionFormat]    VARCHAR (50)   NULL,
    [InteractionDateEnd]   DATETIME       NULL,
    [ManagementResult]     VARCHAR (500)  NULL,
    [ContactId]            VARCHAR (100)  NULL,
    [ContactName]          VARCHAR (300)  NULL,
    [ContactAddress]       VARCHAR (300)  NULL,
    [EvaluationTime]       INT            NULL,
    [Status]               BIT            CONSTRAINT [DF_AuditorEvaluationPlan_IsDeleted] DEFAULT ((1)) NULL,
    [StatusDescription]    VARCHAR (50)   NULL,
    [CreatedByUserId]      VARCHAR (50)   NULL,
    [CreatedDate]          DATETIME       NULL,
    [LastModifiedByUserId] VARCHAR (50)   NULL,
    [LastModifiedDate]     DATETIME       NULL,
    [TimeStamp]            DATETIME       NULL,
    CONSTRAINT [tmp_ms_xx_constraint_PK_AuditorEvaluationPlan_11] PRIMARY KEY CLUSTERED ([Instance] ASC, [IdEvaluationPlan] ASC, [IdAuditor] ASC, [IdInteraction] ASC, [IdAgent] ASC, [InteractionType] ASC)
);

IF EXISTS (SELECT TOP 1 1 
           FROM   [dbo].[AuditorEvaluationPlan])
    BEGIN
        INSERT INTO [dbo].[tmp_ms_xx_AuditorEvaluationPlan] ([Instance], [IdEvaluationPlan], [IdAuditor], [IdInteraction], [IdAgent], [InteractionType], [Completed], [Score], [AutomaticScore], [ManualScore], [IdCampaign], [InteractionDate], [InteractionDuration], [InteractionOrigin], [InteractionFormat], [InteractionDateEnd], [ManagementResult], [ContactId], [Status], [StatusDescription], [CreatedByUserId], [CreatedDate], [LastModifiedByUserId], [LastModifiedDate], [TimeStamp], [ContactName], [ContactAddress], [EvaluationTime])
        SELECT   [Instance],
                 [IdEvaluationPlan],
                 [IdAuditor],
                 [IdInteraction],
                 [IdAgent],
                 [InteractionType],
                 [Completed],
                 [Score],
                 [AutomaticScore],
                 [ManualScore],
                 [IdCampaign],
                 [InteractionDate],
                 [InteractionDuration],
                 [InteractionOrigin],
                 [InteractionFormat],
                 [InteractionDateEnd],
                 [ManagementResult],
                 [ContactId],
                 [Status],
                 [StatusDescription],
                 [CreatedByUserId],
                 [CreatedDate],
                 [LastModifiedByUserId],
                 [LastModifiedDate],
                 [TimeStamp],
                 [ContactName],
                 [ContactAddress],
                 [EvaluationTime]
        FROM     [dbo].[AuditorEvaluationPlan]
        ORDER BY [Instance] ASC, [IdEvaluationPlan] ASC, [IdAuditor] ASC, [IdInteraction] ASC, [IdAgent] ASC, [InteractionType] ASC;
    END

DROP TABLE [dbo].[AuditorEvaluationPlan];

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_AuditorEvaluationPlan]', N'AuditorEvaluationPlan';

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_constraint_PK_AuditorEvaluationPlan_11]', N'PK_AuditorEvaluationPlan_1', N'OBJECT';

COMMIT TRANSACTION;

SET TRANSACTION ISOLATION LEVEL READ COMMITTED;


GO
PRINT N'Creando Índice [dbo].[AuditorEvaluationPlan].[IX_AuditorEvaluationPlan]...';


GO
CREATE NONCLUSTERED INDEX [IX_AuditorEvaluationPlan]
    ON [dbo].[AuditorEvaluationPlan]([Instance] ASC, [IdAuditor] ASC, [IdCampaign] ASC, [IdAgent] ASC, [InteractionType] ASC, [InteractionOrigin] ASC, [InteractionFormat] ASC, [ManagementResult] ASC);


GO
PRINT N'Creando Índice [dbo].[AuditorEvaluationPlan].[IX_AuditorEvaluationPlan_IdEvaluationPlan]...';


GO
CREATE NONCLUSTERED INDEX [IX_AuditorEvaluationPlan_IdEvaluationPlan]
    ON [dbo].[AuditorEvaluationPlan]([IdEvaluationPlan] ASC)
    INCLUDE([Instance], [IdAuditor], [IdInteraction], [IdAgent], [InteractionType]);


GO
PRINT N'Modificando Tabla [dbo].[InteractionEvaluationPlan]...';


GO
ALTER TABLE [dbo].[InteractionEvaluationPlan] ALTER COLUMN [ContactId] VARCHAR (100) NULL;


GO
PRINT N'Creando Índice [dbo].[AsyncInteraction].[GetI6AlreadyRegisteredTextInteractions_01]...';


GO
CREATE NONCLUSTERED INDEX [GetI6AlreadyRegisteredTextInteractions_01]
    ON [dbo].[AsyncInteraction]([VCC] ASC, [ID] ASC, [Folder] ASC);


GO
PRINT N'Creando Índice [dbo].[ProcessAudio].[BulkProgress]...';


GO
CREATE NONCLUSTERED INDEX [BulkProgress]
    ON [dbo].[ProcessAudio]([VCC] ASC, [ProcessId] ASC);


GO
PRINT N'Modificando Procedimiento [dbo].[BulkAbilityCognitive]...';


GO
ALTER PROCEDURE [dbo].[BulkAbilityCognitive]
AS
BEGIN
	SET NOCOUNT ON

	/*-- INSERTAMOS LA DATA DE LA TEMPORAL PARA DEPURAR EL SP MANUALMENTE
	IF OBJECT_ID(N'[dbo].[TMP_BULK_INTENT]', N'U') IS NULL
	BEGIN
		SELECT *
			INTO [dbo].[TMP_BULK_INTENT]
			FROM [dbo].[#AbilityCognitiveTemp]

		/*
		SELECT * FROM [dbo].[TMP_BULK_INTENT] (NOLOCK)
		SELECT * 
			INTO [#AbilityCognitiveTemp]
			FROM [dbo].[TMP_BULK_INTENT] (NOLOCK)
		SELECT * FROM [#AbilityCognitiveTemp]
		*/
	END
	ELSE
	BEGIN
		INSERT INTO [dbo].[TMP_BULK_INTENT]
			SELECT * 
				FROM [dbo].[#AbilityCognitiveTemp]
	END
	*/
	
	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR LOS PLANES Y SU CORRESPONDIENTE VCC
	DECLARE MY_CURSOR CURSOR 
	LOCAL STATIC READ_ONLY FORWARD_ONLY -- SCROLL 
		FOR 
		-- CONSULTAMOS LOS ID DE PLANES EN LA TABLA TEMPORAL
		SELECT DISTINCT ACTMP.[VCC],
							ACTMP.[EvaluationPlanId] 'EVALUATION_PLAN_ID'
						FROM [#AbilityCognitiveTemp] ACTMP (NOLOCK)
						WHERE ACTMP.[VCC] IS NOT NULL 
							AND ACTMP.[EvaluationPlanId] IS NOT NULL

	-- DECLARARAMOS VARIABLES PARA INDICAR EL PLAN Y VCC
	DECLARE @CURRENT_VCC VARCHAR(50) = ''
	DECLARE @CURRENT_EVALUATION_PLAN_ID VARCHAR(100) = ''

	-- ABRIMOS Y RECORREMOS EL ARRAY DE PLANES
	OPEN MY_CURSOR
	FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	WHILE @@FETCH_STATUS = 0
	BEGIN 
		-- EJECUTAMOS EL SP QUE INSERTA LOS RESULT BASE DE LOS PLANES QUE AUN NO LOS TIENEN
		EXEC [dbo].[SaveEvaluationBaseResult] @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID, 'AUTOMATIC'
			
		FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	END
	CLOSE MY_CURSOR
	DEALLOCATE MY_CURSOR
	
	-- ACTUALIZAMOS LOS EVALUATION RESULT DE LAS HABILIDADES EN LA TABLA TEMPORAL DEL BULK
	UPDATE ER
		SET ER.[Qualification] = (AEF.[Score] * S.[Value]) / 100,
			ER.[OwnScore] = (AEF.[Score] * S.[Value]) / 100,
			ER.[ScoreDescription] = S.[Description],
			ER.[AbilityInnerScore] = S.[Value]
		FROM [#AbilityCognitiveTemp] ACTMP 
		INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
			ON EP.[ID] = ACTMP.[EvaluationPlanId]
		INNER JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
			ON AEF.[Instance] = EP.[Instance]
				AND AEF.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
				AND AEF.[IdAbility] = ACTMP.[AbilityId]
		INNER JOIN EvaluationResult ER (NOLOCK)
			ON ER.[Instance] = EP.[Instance] 
				AND ER.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
				AND ER.[IdInteraction] = ACTMP.[ID]
		INNER JOIN [dbo].[Ability] A (NOLOCK) 
	       ON A.[Instance] = ER.[Instance] 
	            AND A.[ID] = ER.[IdAbility]
		INNER JOIN [dbo].[Score] S (NOLOCK)
			ON S.[IdAbility] = ACTMP.[AbilityId]
				AND S.[Value] = IIF(A.[IsNegative] = 1, 0, 100)
		WHERE AEF.[IdAbility] = ER.[IdAbility]
			AND ER.[IdAuditor] = 'SPEECH'

	/* Script para actualizar la tabla AuditorEvaluationPlan a Completed y Suma de Scores de la evaluacion */
	UPDATE AEP
		SET --AEP.[Completed] = '1',
			AEP.[Completed] = CASE WHEN AEPR.[Evaluation_Mode] = 'X' AND AEPR.[MinAutomaticQualification] <= AEPR.[SCORE] THEN '0' ELSE '1' END,
			AEP.[StatusDescription] = CASE WHEN AEPR.[Evaluation_Mode] = 'X' AND AEPR.[MinAutomaticQualification] <= AEPR.[SCORE] THEN 'NEW' ELSE 'COMPLETED' END,
			AEP.[Score] = AEPR.[SCORE],
			AEP.[AutomaticScore] = AEPR.[SCORE],
			-- AEP.[ManualScore] = AEPR.[SCORE], -- UNA EVALUACION AUTOMATICA DEBE TENER 0 DE MANUALSCORE
			AEP.[ManualScore] = 0,
			AEP.[LastModifiedDate] = GETUTCDATE(),
			AEP.[TimeStamp] = GETUTCDATE()
		FROM AuditorEvaluationPlan AEP (NOLOCK)
		LEFT JOIN (
			SELECT AEP.[Instance],
				AEP.[IdEvaluationPlan],
				AEP.[IdInteraction],
				EP.[Evaluation_Mode],
				EF.[MinAutomaticQualification],
				SUM(ER.[Qualification]) AS SCORE
			FROM AuditorEvaluationPlan AEP (NOLOCK)
			LEFT JOIN EvaluationPlan EP (NOLOCK)
				ON EP.[Instance] = AEP.[Instance]
					AND EP.[ID] = AEP.[IdEvaluationPlan] 
			LEFT JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
				ON EF.[Instance] = AEP.[Instance]
					AND EF.[ID] = EP.[IdEvaluationFormat]
			LEFT JOIN EvaluationResult ER (NOLOCK)
				ON ER.[Instance] = AEP.[Instance]
					AND ER.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND ER.[IdInteraction] = AEP.[IdInteraction]
			LEFT JOIN AbilityEvaluationFormat AEF (NOLOCK) 
				ON AEF.[Instance] = EP.[Instance]
					AND AEF.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
					AND AEF.[IdAbility] = ER.[IdAbility]
			LEFT JOIN (SELECT DISTINCT ACTMP.[VCC],
									ACTMP.[EvaluationPlanId]
								FROM [#AbilityCognitiveTemp] ACTMP (NOLOCK)
								WHERE ACTMP.[VCC] IS NOT NULL 
									AND ACTMP.[EvaluationPlanId] IS NOT NULL) TMP 
				ON TMP.[VCC] = AEP.[Instance]
					AND TMP.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
			WHERE TMP.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
				AND AEP.[IdAuditor] = 'SPEECH'
			GROUP BY AEP.[Instance], AEP.[IdEvaluationPlan], AEP.[IdInteraction], EP.[Evaluation_Mode], EF.[MinAutomaticQualification]
		) AEPR 
		ON AEPR.[Instance] = AEP.[Instance]
			AND AEPR.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
			AND AEPR.[IdInteraction] = AEP.[IdInteraction]
		WHERE AEPR.[Instance] = AEP.[Instance]
			AND AEPR.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
			AND AEPR.[IdInteraction] = AEP.[IdInteraction]
	
	;
	/****************************************************************************************/
	/*INICIO SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
	/****************************************************************************************/
	
	-- EMULAMOS UNA NUEVA TABLA VARIABLE PARA DETERMINAR LAS INTERACCIONES QUE TIENEN HABILIDAD(ES) PENALIZADA(S) POR NOTA CERO
	--  ORDENANDO POR PRIORIDAD (INTERACCION 1, GRUPO 2 Y SUBGRUPO 3)
	WITH CTEFP AS (
		SELECT DISTINCT 
				ER.[Instance],
				ER.[IdInteraction],
				ER.[IdEvaluationPlan],
				ER.[IdEvaluationFormat],
				ER.[IdAbility],
				CASE WHEN ER.[AbilityInnerScore] = 0 AND ER.[NotApplies] = 0 AND HAEF.[Penalizes] <> 'NO' THEN 1 ELSE 0 END 'Penalized',
				HAEF.[Penalizes],
				CASE HAEF.[Penalizes]
					WHEN 'INT' THEN ER.[IdInteraction] 
					WHEN 'GRP' THEN ER.[IdGroup] 
					WHEN 'SGR' THEN ER.[IdSubGroup] 
				END 'PenalizedOn',
				RN = ROW_NUMBER() OVER(PARTITION BY ER.[IdInteraction], CASE WHEN ER.[AbilityInnerScore] = 0 THEN 1 ELSE 0 END 
					ORDER BY CASE AEF.[Penalizes]
					WHEN 'INT' THEN 1 
					WHEN 'GRP' THEN 2 
					WHEN 'SGR' THEN 3 
				END)
			FROM [dbo].[EvaluationResult] ER (NOLOCK) 
			LEFT JOIN [dbo].[HistoricAbilityEvaluationFormat] HAEF (NOLOCK) 
				ON HAEF.[VCC] = ER.[Instance]
					AND HAEF.[EvaluationPlanId] = ER.[IdEvaluationPlan]
					AND HAEF.[IdEvaluationFormat] = ER.[IdEvaluationFormat]
					AND HAEF.[IdAbility] = ER.[IdAbility]
			WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM [#AbilityCognitiveTemp]) 
				AND ER.[AbilityInnerScore] = 0
				AND ER.[NotApplies] = 0
				AND HAEF.[Penalizes] <> 'NO'
			-- WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EPA.[EvaluationPlanId] FROM [DummyEvaluationPlanAbility] EPA (NOLOCK) WHERE EPA.[EvaluationPlanId] IS NOT NULL)
	),

	-- ALMACENAMOS EL RESULTADO AGRUPADO DE LAS EVALUACIONES EN UNA TABLA VARIABLE PARA HACER UN CRUCE DIRECTO CON
	--  LA TABLA AuditorEvaluationPlan
	CTEFS AS (
		SELECT ER.[Instance],
				ER.[IdEvaluationPlan],
				ER.[IdInteraction],
				ER.[IdAuditor],
				SUM(ER.[Qualification])															'TOTAL_SCORE',
				SUM(IIF(HA.[Type] = 'MANUAL_AUTOMATIC', ER.[Qualification], 0))					'TOTAL_AUTOMATIC_SCORE',
				SUM(IIF(HA.[Type] = 'MANUAL', ER.[Qualification], 0))							'TOTAL_MANUAL_SCORE',
				--SUM(ER.[Qualification] * CASE WHEN FP2.[Penalized] IS NULL THEN 1 ELSE 0 END) 'PENALIZED_SCORE',
				SUM(ER.[Qualification] * (
					CASE WHEN (
						CASE FP2.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP2.[PenalizedOn]
						AND FP2.[Penalized] = 1) THEN 0 ELSE 1 END
				))																				'PENALIZED_SCORE',
				SUM(IIF(HA.[Type] = 'MANUAL_AUTOMATIC',
					ER.[Qualification] * (
					CASE WHEN (
						CASE FP2.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP2.[PenalizedOn]
						AND FP2.[Penalized] = 1
					) THEN 0 ELSE 1 END),
					0) 
				)																				'PENALIZED_AUTOMATIC_SCORE',
				SUM(IIF(HA.[Type] = 'MANUAL',
					ER.[Qualification] * (
					CASE WHEN (
						CASE FP2.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP2.[PenalizedOn]
						AND FP2.[Penalized] = 1
					) THEN 0 ELSE 1 END),
					0) 
				)																				'PENALIZED_MANUAL_SCORE'
			FROM [dbo].[EvaluationResult] ER (NOLOCK) 
			LEFT JOIN (
				-- HACEMOS UN CRUCE CON LA TABLA VARIABLE Y TOMAMOS SOLO UNA DE LAS PENALIZACIONES POR INTERACCION, EMPEZANDO 
				--  POR LA MAS PRIORITARIA (FP.[RN])
				SELECT DISTINCT FP.[Instance],
								FP.[IdEvaluationPlan], 
								FP.[IdInteraction], 
								FP.[Penalized],
								FP.[Penalizes], 
								FP.[PenalizedOn]
					FROM CTEFP FP (NOLOCK)
					WHERE FP.[Penalizes] <> 'NO'
						AND FP.[RN] = 1
			) FP2
				ON FP2.[Instance] = ER.[Instance]
					AND ER.[IdEvaluationPlan] = FP2.[IdEvaluationPlan]
					AND ER.[IdInteraction] = FP2.[IdInteraction]
					/*
					AND CASE FP2.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP2.[PenalizedOn]
					AND FP2.[Penalized] = 1
					*/
			INNER JOIN [dbo].[HistoricAbility] HA (NOLOCK)
				ON HA.[VCC] = ER.[Instance]
					AND HA.[EvaluationPlanId] = ER.[IdEvaluationPlan]
					AND HA.[ID] = ER.[IdAbility]
			--WHERE ER.[Instance] = 'multisalud'
			WHERE -- ER.[Instance] = FP2.[Instance] -- ESTA LINEA CAUSA QUE NO SE ACTUALICEN LOS SCORES LAS EVALUACIONES QUE NO PENALIZAN
				-- AND 
				ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM [#AbilityCognitiveTemp])
				--AND ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM DummyEvaluationPlanAbility)
			GROUP BY ER.[Instance],
				ER.[IdEvaluationPlan],
				ER.[IdInteraction],
				ER.[IdAuditor]
	)
	--SELECT * FROM CTEFS

	-- ACTUALIZAMOS LOS REGISTROS DE EVALUACION CON LA NOTA PENALIZADA OBTENIDA EN LOS PASOS ANTERIORES
	UPDATE AEP 
		SET AEP.[Score] = FS.[PENALIZED_SCORE],
			AEP.[AutomaticScore] = FS.[PENALIZED_AUTOMATIC_SCORE],
			AEP.[ManualScore] = FS.[PENALIZED_MANUAL_SCORE],
			AEP.[LastModifiedDate] = GETUTCDATE(),
			AEP.[TimeStamp] = GETUTCDATE()
		FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
		LEFT JOIN CTEFS FS (NOLOCK) 
			ON FS.[Instance] = AEP.[Instance] 
				AND FS.[IdEvaluationPlan] = AEP.[IdEvaluationPlan] 
				AND FS.[IdInteraction] = AEP.[IdInteraction]
				AND FS.[IdAuditor] = AEP.[IdAuditor]
		WHERE FS.[Instance] IS NOT NULL
		
	/*************************************************************************************/
	/*FIN SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
	/*************************************************************************************/
     --insert into test(origin,content) values('BulkAbilityCognitive',(select *  from [dbo].[#AbilityCognitiveTemp] FOR JSON AUTO))
	DROP TABLE [dbo].[#AbilityCognitiveTemp];
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando Procedimiento [dbo].[BulkEvaluationPlanAbility]...';


GO
ALTER PROCEDURE [dbo].[BulkEvaluationPlanAbility]
AS
BEGIN
	SET NOCOUNT ON
	-- ESTE PROCEDURE RECIBE COMO RESULTADO LAS INTERACCIONES QUE COINCIDEN CON UN QUERY EN UN PLAN DE EVALUACION
	
	/*-- INSERTAMOS LA DATA DE LA TEMPORAL PARA DEPURAR EL SP MANUALMENTE
	IF OBJECT_ID(N'[dbo].[TMP_BULK_QUERY]', N'U') IS NULL
	BEGIN
		SELECT *
			INTO [dbo].[TMP_BULK_QUERY]
			FROM [dbo].[#EvaluationPlanAbilityTemp]

		/*
		SELECT * 
			INTO #EvaluationPlanAbilityTemp
			FROM [dbo].[TMP_BULK_QUERY] (nolock)
		*/
	END
	*/

	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR LOS PLANES Y SU CORRESPONDIENTE VCC
	DECLARE MY_CURSOR CURSOR 
	LOCAL STATIC READ_ONLY FORWARD_ONLY -- SCROLL 
		FOR 
		-- CONSULTAMOS LOS ID DE PLANES EN LA TABLA TEMPORAL
		SELECT DISTINCT
				EPATMP.[VCC]						'VCC', 
				EPATMP.[EvaluationPlanId]			'EVALUATION_PLAN_ID'
			FROM [dbo].[#EvaluationPlanAbilityTemp] EPATMP (NOLOCK)

	-- DECLARARAMOS VARIABLES PARA INDICAR EL PLAN Y VCC
	DECLARE @CURRENT_VCC VARCHAR(50) = ''
	DECLARE @CURRENT_EVALUATION_PLAN_ID VARCHAR(100) = ''

	-- ABRIMOS Y RECORREMOS EL ARRAY DE CANALES
	OPEN MY_CURSOR
	FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	WHILE @@FETCH_STATUS = 0
	BEGIN 
		-- EJECUTAMOS EL SP QUE INSERTA LOS RESULT BASE DE LOS PLANES QUE AUN NO LOS TIENEN
		EXEC [dbo].[SaveEvaluationBaseResult] @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID, 'AUTOMATIC'

		-- INSERTAMOS LOS RESULTADOS DE LAS INTERACCIONES DE AUDIO QUE MATCHEARON CON LA QUERY
		INSERT INTO [dbo].[InteractionQueryResult] (
			[VCC],
			[InteractionId],
			[Section],
			[Part],
			[InteractionType],
			[TranscriptionId],
			[BatchType],
			[BatchTypeId],
			[BatchTypeName],
			[AnalysisType],
			[QueryId],
			[QueryName],
			[QueryValue],
			[QueryData],
			[Matches],
			[Details],
			[CreatedDate],
			[TimeStamp]
		)
			SELECT @CURRENT_VCC,
					PA.[AudioId],
					PA.[Section],
					PA.[Part],
					'CALL', --EPATMP.[Channel],
					CONCAT(PA.[AudioId], '_', ISNULL(PA.[Section], '0'), '_', ISNULL(PA.[Part], '0')),
					'EVALUATION_PLAN',
					@CURRENT_EVALUATION_PLAN_ID,
					EP.[Description],
					'SEMANTIC',
					GQ.[Name],
					GQ.[Name],
					GQ.[Query],
					GQ.[RawData],
					EPATMP.[Matches],
					EPATMP.[MatchesDetail],
					GETUTCDATE(),
					GETUTCDATE()
				FROM [#EvaluationPlanAbilityTemp] EPATMP (NOLOCK)
				INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
					ON EP.[Instance] = EPATMP.[VCC]
						AND EP.[ID] = EPATMP.[EvaluationPlanId]
				INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK)
					ON PA.[VCC] = EPATMP.[VCC]
						AND PA.[ProcessId] = EPATMP.[ProcessId]
						AND PA.[AudioId] = EPATMP.[AudioId]
						AND PA.[Section] = EPATMP.[Section]
						AND PA.[Part] = EPATMP.[Part]
				INNER JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
					ON AEF.[Instance] = EPATMP.[VCC]
						AND AEF.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
				/*
				INNER JOIN [dbo].[AbilityQuery] AQ (NOLOCK)
					ON AQ.[VCC] = EPATMP.[VCC]
						AND AQ.[AbilityId] = AEF.[IdAbility] 
						AND AQ.[QueryId] = EPATMP.[QueryId]
				*/
				INNER JOIN [GenericQuery] GQ (NOLOCK)
					ON GQ.[VCC] = EPATMP.[VCC]
						AND GQ.[Name] = EPATMP.[QueryId]
				WHERE EPATMP.[VCC] = @CURRENT_VCC
					AND EPATMP.[EvaluationPlanId] = @CURRENT_EVALUATION_PLAN_ID

		-- INSERTAMOS LOS RESULTADOS DE LAS INTERACCIONES DE TEXTO QUE MATCHEARON CON LA QUERY
		INSERT INTO [dbo].[InteractionQueryResult] (
			[VCC],
			[InteractionId],
			[Section],
			[Part],
			[InteractionType],
			[TranscriptionId],
			[BatchType],
			[BatchTypeId],
			[BatchTypeName],
			[AnalysisType],
			[QueryId],
			[QueryName],
			[QueryValue],
			[QueryData],
			[Matches],
			[Details],
			[CreatedDate],
			[TimeStamp]
		)
			SELECT @CURRENT_VCC,
					PAI.[InteractionId],
					NULL,
					NULL,
					EPATMP.[Channel],
					EPATMP.[AudioId],
					'EVALUATION_PLAN',
					@CURRENT_EVALUATION_PLAN_ID,
					EP.[Description],
					'SEMANTIC',
					GQ.[Name],
					GQ.[Name],
					GQ.[Query],
					GQ.[RawData],
					EPATMP.[Matches],
					EPATMP.[MatchesDetail],
					GETUTCDATE(),
					GETUTCDATE()
				FROM [#EvaluationPlanAbilityTemp] EPATMP (NOLOCK)
				INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
					ON EP.[Instance] = EPATMP.[VCC]
						AND EP.[ID] = EPATMP.[EvaluationPlanId]
				INNER JOIN [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
					ON PAI.[VCC] = EPATMP.[VCC]
						AND PAI.[ProcessId] = EPATMP.[ProcessId]
						AND PAI.[InteractionType] = EPATMP.[Channel]
						AND PAI.[FormattedEndDate] = EPATMP.[EndDate]
						AND PAI.[Campaign] = EPATMP.[Campaign]
						/* LA TEMPORAL DE TYPESCRIPT REMOVIA EL PREFIJO, POR ELLO SE CAMBIO PARA MATCHEAR CON EL ID
						AND (
							CONCAT(
									PAI.[InteractionType], 
									'_', 
									PAI.[Campaign], 
									'_', 
									PAI.[FormattedEndDate], 
									'_', 
									REPLACE(PAI.[InteractionId], ':', '_')
							) = EPATMP.[AudioId]
						)
						*/
						AND PAI.[InteractionId] = EPATMP.[AudioId]
				INNER JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
					ON AEF.[Instance] = EPATMP.[VCC]
						AND AEF.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
				/*
				INNER JOIN [dbo].[AbilityQuery] AQ (NOLOCK)
					ON AQ.[VCC] = EPATMP.[VCC]
						AND AQ.[AbilityId] = AEF.[IdAbility] 
						AND AQ.[QueryId] = EPATMP.[QueryId]
				*/
				INNER JOIN [GenericQuery] GQ (NOLOCK)
					ON GQ.[VCC] = EPATMP.[VCC]
						AND GQ.[Name] = EPATMP.[QueryId]
				WHERE EPATMP.[VCC] = @CURRENT_VCC
					AND EPATMP.[EvaluationPlanId] = @CURRENT_EVALUATION_PLAN_ID
		
		FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	END
	CLOSE MY_CURSOR
	DEALLOCATE MY_CURSOR
	-- FIN MEDIDA PARA PLANES FINALIZADOS QUE NO TIENE RESULTS REGISTRADOS

	
	
	
	--ACTUALIZAR LOS SCORES DE LAS HABILIDADES RETORNADAS EN LA TABLA TEMPORAL
	UPDATE ER 
	SET ER.[Qualification] = (S.[Value] * AEF.[Score] / 100), 
		ER.[OwnScore] = (AEF.[Score] * S.[Value]) / 100,
		ER.[ScoreDescription] = S.[Description],
		ER.[AbilityInnerScore] = S.[Value]
	/*
	SELECT (S.[Value] * AEF.[Score] / 100), 
			(AEF.[Score] * S.[Value]) / 100,
			S.[Description],
			S.[Value]
	*/
	FROM [dbo].[EvaluationResult] ER (NOLOCK)
	INNER JOIN [dbo].[#EvaluationPlanAbilityTemp] EPATMP (NOLOCK)
	--INNER JOIN [dbo].[DummyEvaluationPlanAbility] EPATMP (NOLOCK)
		ON ER.[Instance] = EPATMP.[VCC]
		AND ER.[IdEvaluationPlan] = EPATMP.[EvaluationPlanId]
		AND ER.[IdInteraction] = EPATMP.[AudioId] 
	LEFT JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
		ON AEF.[Instance] = ER.[Instance] 
		AND AEF.[IdEvaluationFormat] = ER.[IdEvaluationFormat]
		AND AEF.[IdAbility] = ER.[IdAbility]
	INNER JOIN [dbo].[Ability] A (NOLOCK) 
		ON A.[Instance] = ER.[Instance] 
		AND A.[ID] = ER.[IdAbility]
	INNER JOIN [dbo].[AbilityQuery] AB (NOLOCK)
		ON AB.[VCC] = ER.[Instance] 
			AND AB.[AbilityId] = AEF.[IdAbility]
			AND AB.[QueryId] = EPATMP.[QueryId]
	LEFT JOIN [dbo].[Score] S (NOLOCK) 
		ON S.[Instance] = ER.[Instance] 
		AND S.[IdAbility] = ER.[IdAbility]
		AND S.[Value] =  IIF(A.[IsNegative] = 1, 0, 100)

	;WITH 
	-- DECLARAMOS UNA CTE PARA DEPOSITAR LOS RESULTADOS DE LA SUMA DE HABILIDADES PARA LA EVALUACION
	CteEvaluationScoreResult AS (
		-- ESTE BLOQUE ACTUALIZA LAS NOTAS DE EVALUACIONES AUTOMATICAS SEGUN LOS PLANES CONTENIDOS EN LA TEMPORAL
		SELECT ER.[Instance], ER.[IdEvaluationPlan], ER.[IdEvaluator], ER.[IdInteraction], SUM(ER.[Qualification]) TOTAL
			FROM EvaluationResult ER 
			INNER JOIN (SELECT DISTINCT EvaluationPlanId FROM #EvaluationPlanAbilityTemp) EPATMP 
			--INNER JOIN (SELECT DISTINCT EvaluationPlanId FROM DummyEvaluationPlanAbility) EPATMP 
				ON EPATMP.[EvaluationPlanId] = ER.[IdEvaluationPlan] 
			LEFT JOIN AbilityEvaluationFormat AEF 
				ON AEF.[Instance] = ER.[Instance]
					AND AEF.[IdEvaluationFormat] = ER.[IdEvaluationFormat]
					AND AEF.[IdAbility] = ER.[IdAbility]
					AND AEF.[ID] = ER.[IdAbilityEvaluationFormat]
			WHERE ER.[IdAuditor] = 'SPEECH'
			GROUP BY ER.[Instance], ER.[IdEvaluationPlan], ER.[IdEvaluator], ER.[IdInteraction]
	)
	
	-- SE ACTUALIZA LAS EVALUACIONES QUE COINCIDEN CON LOS RESULTADOS
	UPDATE AEP 
		SET AEP.[Score] = ESR.[TOTAL],
			AEP.[AutomaticScore] =  ESR.[TOTAL],
			AEP.[ManualScore] = 0,
			AEP.[LastModifiedDate] = GETUTCDATE(),
			AEP.[TimeStamp] = GETUTCDATE()
		FROM AuditorEvaluationPlan AEP (NOLOCK)
		INNER JOIN CteEvaluationScoreResult ESR 
			ON AEP.[Instance] = ESR.[Instance]
				AND AEP.[IdEvaluationPlan] = ESR.[IdEvaluationPlan]
				AND AEP.[IdAuditor] = ESR.[IdEvaluator]
				AND AEP.[IdInteraction] = ESR.[IdInteraction]

	/****************************************************************************************/
	/*INICIO SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
	/****************************************************************************************/
	
	-- EMULAMOS UNA NUEVA TABLA VARIABLE PARA DETERMINAR LAS INTERACCIONES QUE TIENEN HABILIDAD(ES) PENALIZADA(S) POR NOTA CERO
	--  ORDENANDO POR PRIORIDAD (INTERACCION 1, GRUPO 2 Y SUBGRUPO 3)
	;WITH CTEFP AS (
		SELECT DISTINCT 
				ER.[Instance],
				ER.[IdInteraction],
				ER.[IdEvaluationPlan],
				ER.[IdEvaluationFormat],
				ER.[IdAbility],
				CASE WHEN ER.[AbilityInnerScore] = 0 AND ER.[NotApplies] = 0 AND HAEF.[Penalizes] <> 'NO' THEN 1 ELSE 0 END 'Penalized',
				HAEF.[Penalizes],
				CASE HAEF.[Penalizes]
					WHEN 'INT' THEN ER.[IdInteraction] 
					WHEN 'GRP' THEN ER.[IdGroup] 
					WHEN 'SGR' THEN ER.[IdSubGroup] 
				END 'PenalizedOn',
				RN = ROW_NUMBER() OVER(PARTITION BY ER.[IdInteraction], CASE WHEN ER.[AbilityInnerScore] = 0 THEN 1 ELSE 0 END 
					ORDER BY CASE HAEF.[Penalizes]
					WHEN 'INT' THEN 1 
					WHEN 'GRP' THEN 2 
					WHEN 'SGR' THEN 3 
				END)
			FROM [dbo].[EvaluationResult] ER (NOLOCK) 
			LEFT JOIN [dbo].[HistoricAbilityEvaluationFormat] HAEF (NOLOCK) 
				ON HAEF.[VCC] = ER.[Instance]
					AND HAEF.[EvaluationPlanId] = ER.[IdEvaluationPlan]
					AND HAEF.[IdEvaluationFormat] = ER.[IdEvaluationFormat]
					AND HAEF.[IdAbility] = ER.[IdAbility]
			WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM #EvaluationPlanAbilityTemp) 
			--WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM DummyEvaluationPlanAbility) 
				AND ER.[AbilityInnerScore] = 0
                AND ER.[NotApplies] = 0
				AND HAEF.[Penalizes] <> 'NO'
			-- WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EPA.[EvaluationPlanId] FROM [DummyEvaluationPlanAbility] EPA (NOLOCK) WHERE EPA.[EvaluationPlanId] IS NOT NULL)
	),
	--SELECT * FROM CTEFP

	-- ALMACENAMOS EL RESULTADO AGRUPADO DE LAS EVALUACIONES EN UNA TABLA VARIABLE PARA HACER UN CRUCE DIRECTO CON
	--  LA TABLA AuditorEvaluationPlan
	CTEFS AS (
		SELECT ER.[Instance],
				ER.[IdEvaluationPlan],
				ER.[IdInteraction],
				ER.[IdAuditor],
				SUM(ER.[Qualification])															'TOTAL_SCORE',
				SUM(IIF(HA.[Type] = 'MANUAL_AUTOMATIC', ER.[Qualification], 0))					'TOTAL_AUTOMATIC_SCORE',
				SUM(IIF(HA.[Type] = 'MANUAL', ER.[Qualification], 0))							'TOTAL_MANUAL_SCORE',
				--SUM(ER.[Qualification] * CASE WHEN FP2.[Penalized] IS NULL THEN 1 ELSE 0 END) 'PENALIZED_SCORE',
				SUM(ER.[Qualification] * (
					CASE WHEN (
						CASE FP2.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP2.[PenalizedOn]
						AND FP2.[Penalized] = 1) THEN 0 ELSE 1 END
				))																				'PENALIZED_SCORE',
				SUM(IIF(HA.[Type] = 'MANUAL_AUTOMATIC',
					ER.[Qualification] * (
					CASE WHEN (
						CASE FP2.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP2.[PenalizedOn]
						AND FP2.[Penalized] = 1
					) THEN 0 ELSE 1 END),
					0) 
				)																				'PENALIZED_AUTOMATIC_SCORE',
				SUM(IIF(HA.[Type] = 'MANUAL',
					ER.[Qualification] * (
					CASE WHEN (
						CASE FP2.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP2.[PenalizedOn]
						AND FP2.[Penalized] = 1
					) THEN 0 ELSE 1 END),
					0) 
				)																				'PENALIZED_MANUAL_SCORE'
			FROM [dbo].[EvaluationResult] ER (NOLOCK) 
			LEFT JOIN (
				-- HACEMOS UN CRUCE CON LA TABLA VARIABLE Y TOMAMOS SOLO UNA DE LAS PENALIZACIONES POR INTERACCION, EMPEZANDO 
				--  POR LA MAS PRIORITARIA (FP.[RN])
				SELECT DISTINCT FP.[Instance],
								FP.[IdEvaluationPlan], 
								FP.[IdInteraction], 
								FP.[Penalized],
								FP.[Penalizes], 
								FP.[PenalizedOn]
					FROM CTEFP FP (NOLOCK)
					WHERE FP.[Penalizes] <> 'NO'
						AND FP.[RN] = 1
			) FP2
				ON FP2.[Instance] = ER.[Instance]
					AND ER.[IdEvaluationPlan] = FP2.[IdEvaluationPlan]
					AND ER.[IdInteraction] = FP2.[IdInteraction]
					/*
					AND CASE FP2.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP2.[PenalizedOn]
					AND FP2.[Penalized] = 1
					*/
			INNER JOIN [dbo].[HistoricAbility] HA (NOLOCK)
				ON HA.[VCC] = ER.[Instance]
					AND HA.[EvaluationPlanId] = ER.[IdEvaluationPlan]
					AND HA.[ID] = ER.[IdAbility]
			--WHERE ER.[Instance] = 'multisalud'
			WHERE -- ER.[Instance] = FP2.[Instance] -- ESTA LINEA CAUSA QUE NO SE ACTUALICEN LOS SCORES LAS EVALUACIONES QUE NO PENALIZAN
				-- AND 
				ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM #EvaluationPlanAbilityTemp)
				--AND ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM DummyEvaluationPlanAbility)
			GROUP BY ER.[Instance],
				ER.[IdEvaluationPlan],
				ER.[IdInteraction],
				ER.[IdAuditor]
	)
	--SELECT * FROM CTEFS

	-- ACTUALIZAMOS LOS REGISTROS DE EVALUACION CON LA NOTA PENALIZADA OBTENIDA EN LOS PASOS ANTERIORES
	UPDATE AEP 
		SET AEP.[Score] = FS.[PENALIZED_SCORE],
			AEP.[AutomaticScore] = FS.[PENALIZED_AUTOMATIC_SCORE],
			AEP.[ManualScore] = FS.[PENALIZED_MANUAL_SCORE],
			AEP.[LastModifiedDate] = GETUTCDATE(),
			AEP.[TimeStamp] = GETUTCDATE()
		FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
		LEFT JOIN CTEFS FS (NOLOCK) 
			ON FS.[Instance] = AEP.[Instance] 
				AND FS.[IdEvaluationPlan] = AEP.[IdEvaluationPlan] 
				AND FS.[IdInteraction] = AEP.[IdInteraction]
				AND FS.[IdAuditor] = AEP.[IdAuditor]
		WHERE FS.[Instance] IS NOT NULL
		
	/*************************************************************************************/
	/*FIN SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
	/*************************************************************************************/
	--insert into test(origin,content) values('BulkAbilityCognitive',(select *  from [dbo].[#AbilityCognitiveTemp] FOR JSON AUTO))

	-- ELIMINAMOS LA TABLA TEMPORAL
	DROP TABLE [dbo].[#EvaluationPlanAbilityTemp]
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando Procedimiento [dbo].[CleanFailedEvaluationPlanData]...';


GO
ALTER procedure [dbo].[CleanFailedEvaluationPlanData](
@VCC VARCHAR(50),
@idEvaluationPlan VARCHAR(50)
)
AS
BEGIN

SET NOCOUNT ON

	-- Verifica que exista el proceso para eliminar.
	IF EXISTS(SELECT [ID] FROM [dbo].[EvaluationPlan] WHERE [Instance] = @VCC AND [ID] = @idEvaluationPlan)
	BEGIN
		-- ELIMINAMOS LA DATA DE LAS TABLAS PRINCIPALES
		DELETE FROM InteractionEvaluationPlan WHERE IdEvaluationPlan = @idEvaluationPlan AND Instance = @VCC
		DELETE FROM AuditorEvaluationPlan WHERE IdEvaluationPlan = @idEvaluationPlan AND Instance = @VCC
		DELETE FROM EvaluationPlan WHERE id = @idEvaluationPlan AND Instance = @VCC

		-- ELIMINAMOS LA DATA DE LAS TABLAS HISTORICAS
		DELETE FROM [dbo].[HistoricEvaluationFormat] WHERE [VCC] = @VCC AND [EvaluationPlanId] = @idEvaluationPlan 
		DELETE FROM [dbo].[HistoricAbilityEvaluationFormat] WHERE [VCC] = @VCC AND [EvaluationPlanId] = @idEvaluationPlan 
		DELETE FROM [dbo].[HistoricEvaluationFormatCustomField] WHERE [VCC] = @VCC AND [EvaluationPlanId] = @idEvaluationPlan 
		DELETE FROM [dbo].[HistoricCustomField] WHERE [VCC] = @VCC AND [EvaluationPlanId] = @idEvaluationPlan 
		DELETE FROM [dbo].[HistoricCustomFieldResult] WHERE [VCC] = @VCC AND [EvaluationPlanId] = @idEvaluationPlan 
		DELETE FROM [dbo].[HistoricEvaluationFormatAttachedSignature] WHERE [VCC] = @VCC AND [EvaluationPlanId] = @idEvaluationPlan 
		DELETE FROM [dbo].[HistoricCampaignEvaluationFormat] WHERE [VCC] = @VCC AND [EvaluationPlanId] = @idEvaluationPlan 
		DELETE FROM [dbo].[HistoricGroup] WHERE [VCC] = @VCC AND [EvaluationPlanId] = @idEvaluationPlan 
		DELETE FROM [dbo].[HistoricSubGroup] WHERE [VCC] = @VCC AND [EvaluationPlanId] = @idEvaluationPlan 
		DELETE FROM [dbo].[HistoricAbility] WHERE [VCC] = @VCC AND [EvaluationPlanId] = @idEvaluationPlan 
		DELETE FROM [dbo].[HistoricScore] WHERE [VCC] = @VCC AND [EvaluationPlanId] = @idEvaluationPlan 
		DELETE FROM [dbo].[HistoricEvaluationFormatAbilityScoreTipification] WHERE [VCC] = @VCC AND [EvaluationPlanId] = @idEvaluationPlan 
		DELETE FROM [dbo].[HistoricEvaluationFormatAbilityScoreTipificationQuery] WHERE [VCC] = @VCC AND [EvaluationPlanId] = @idEvaluationPlan 
		DELETE FROM [dbo].[HistoricEvaluationFormatAbilityScoreTipificationItem] WHERE [VCC] = @VCC AND [EvaluationPlanId] = @idEvaluationPlan 
		DELETE FROM [dbo].[HistoricAbilityQuery] WHERE [VCC] = @VCC AND [EvaluationPlanId] = @idEvaluationPlan 
		DELETE FROM [dbo].[HistoricAbilityQueryEntity] WHERE [VCC] = @VCC AND [EvaluationPlanId] = @idEvaluationPlan 
	
		SELECT 1 AS 'result'
	END
	ELSE
	BEGIN
		SELECT 0 AS 'result'
	END		
END
GO
PRINT N'Modificando Procedimiento [dbo].[DeleteEvaluationPlan]...';


GO
-- PARA ELIMINAR UN PLAN DE EVALUACION SE SISTEMA, DEBEMOS ELIMINARLO DE LAS TABLAS EVALUATIONRESULT, 
--  AUDITOREVALUATIONPLAN, INTERACTIONSEVALUATIONPLAN Y EVALUATIONPLAN EN ESE ORDEN
ALTER PROCEDURE [dbo].[DeleteEvaluationPlan] (
	@Instance Varchar(50) = NULL, 
	@IdEvaluationPlan Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	-- DECLARAMOS UNA VARIABLE PARA DETERMINAR SI EXISTE EL PLAN DADO O NO
	DECLARE @EVALUATIONPLAN_EXISTS BIT = 0

	-- CONTAMOS CUANTOS PLANES DE EVALUACION EXISTEN CON EL ID Y VCC DADOS
	SELECT @EVALUATIONPLAN_EXISTS = COUNT(EP.[ID]) 
		FROM EvaluationPlan EP 
		WHERE EP.[Instance] = @Instance
			AND EP.[ID] = @IdEvaluationPlan
	
	-- SI EXISTE UN PLAN DE EVALUACION CON LOS PARAMETROS RECIBIDOS, ELIMINAMOS
	--  LOS REGISTROS CORRESPONDIENTES QUE SE ENCUENTRAN EN OTRAS TABLAS
	IF (@EVALUATIONPLAN_EXISTS = 1) 
	BEGIN
		-- ELIMANOS LOS REGISTROS DE RESULTADOS DE LAS EVALUACIONES DEL PLAN
		DELETE FROM [dbo].[EvaluationResult] 
			WHERE [Instance] = @Instance
				AND [IdEvaluationPlan] = @IdEvaluationPlan

		-- ELIMINAMOS LOS REGISTROS DE LOS RESULTADOS DE CAMPOS PERSONALIZADOS
		DELETE FROM [dbo].[EvaluationCustomFieldResult]
			WHERE [VCC] = @Instance
				AND [EvaluationPlanId] = @IdEvaluationPlan

		-- ELIMINAMOS LOS REGISTROS DE EVALUACION DEL PLAN
		DELETE FROM [dbo].[AuditorEvaluationPlan]
			WHERE [Instance] = @Instance
				AND [IdEvaluationPlan] = @IdEvaluationPlan

		-- ELIMINAMOS LOS REGISTROS DE INTERACCIONES RELACIONADAS AL PLAN
		DELETE FROM [dbo].[InteractionEvaluationPlan]
			WHERE [Instance] = @Instance
				AND [IdEvaluationPlan] = @IdEvaluationPlan

		-- ELIMINAR DATA HISTORICA
		EXEC [dbo].[CleanFailedEvaluationPlanData] @Instance, @IdEvaluationPlan

		-- ELIMINAMOS EL REGISTROS DEL PLAN DE EVALUACION
		DELETE [dbo].[EvaluationPlan]
			WHERE [Instance] = @Instance
				AND [ID] = @IdEvaluationPlan
		
		SELECT 1 AS 'result'

	END 
	ELSE
	BEGIN
		SELECT 0 AS 'result'
	END
    
    SET NOCOUNT OFF
END
GO
PRINT N'Modificando Procedimiento [dbo].[GetEfectivityPlans]...';


GO
ALTER  PROCEDURE [dbo].[GetEfectivityPlans] (
@VCC                Varchar(50) = NULL,
@SearchCriteria     Varchar(50) = NULL,
@SearchExpression   Varchar(50) = NULL
)
AS
BEGIN
SET NOCOUNT ON

	--SELECCIONAMOS TODOS LOS PLANES AUTOMATICOS EXISTENTES PARA GENERAR  LA MUESTRA  A PARTIR DEL PLAN DE EVALUACION

    SELECT
			e.[ID]							'id',
			e.[Modality]					'modality',
			e.[DateFin]						'dateFin',
			e.CreatedDate					'createdDate',
			e.CreatedByUserId				'createdByUserId',
			e.LastModifiedDate				'lastModifiedDate',
			e.LastModifiedByUserId			'lastModifiedByUserId',
			e.Description					'description',
			e.IdEvaluationFormat            'idEvaluationFormat',
			e.Enabled						'enabled',
			e.Status						'status',
			e.Evaluation_Mode				'evaluation_mode',
			e.processId    				    'processId',
			ef.templateId    				'templateId',
			COUNT(a.IdInteraction)			'totalEvaluations',		
			COUNT(DISTINCT CASE a.[Completed] WHEN 1 THEN a.[IdInteraction] ELSE NULL END)					'completedEvaluations',
			(
				(
					CAST(
						(
							COUNT(DISTINCT CASE a.[Completed] WHEN 1 THEN a.[IdInteraction] ELSE NULL END)
							+ 
							COUNT(DISTINCT CASE a.[Status] WHEN 0 THEN a.[IdInteraction] ELSE NULL END)
						)
					 AS NUMERIC(10,2)) 
				)
				/
				CASE COUNT(DISTINCT a.[IdInteraction]) WHEN 0 THEN 1 ELSE COUNT(DISTINCT a.[IdInteraction]) END 
			) * 100																							'completedPercentage',
			e.[Percentage]					'percentage',
			e.[StatusDescription]			'statusDescription',
			e.[BatchStatus]					'batchStatus'		
		FROM EvaluationPlan e (NOLOCK)
		LEFT JOIN AuditorEvaluationPlan a (NOLOCK) 
			ON a.[Instance] = e.[Instance]
				AND a.[IdEvaluationPlan] = e.[ID]
		INNER JOIN EvaluationFormat ef (NOLOCK)
			ON ef.[Instance] = e.[Instance]
				AND ef.[ID] = e.[IdEvaluationFormat]
        
		WHERE e.Instance = @VCC
			AND e.Evaluation_Mode IN ('A','X')
			AND e.Status = '7'			
		GROUP BY e.[ID],e.[Modality],e.[DateFin],e.CreatedDate,e.CreatedByUserId,
				 e.LastModifiedDate,e.LastModifiedByUserId,e.Description,e.IdEvaluationFormat,
				 e.Enabled, e.Status, e.Evaluation_Mode,e.processId,ef.templateId, 
				 e.Percentage, e.StatusDescription, e.[BatchStatus]	
		
		
		--SELECCIONAR PLANES DE EFECTIVIDAD GENERADOS PARA LA GRILLA DE ADMINISTRACION 

		;WITH Temp_EfectivityPlan AS (

		SELECT DISTINCT 
		[EfectivityPlanId],[EvaluationPlanId],[InteractionId],[EfectivityStatus] 
		FROM dbo.[EvaluationResultEfectivity] (NOLOCK)
		WHERE [VCC] = @VCC
		),
		Temp_EfectivityPlan_Result  AS (
		SELECT [EfectivityPlanId],[EvaluationPlanId],COUNT(InteractionId)  'total',
		COUNT(DISTINCT CASE WHEN [EfectivityStatus] = 'COMPLETED' THEN [InteractionId] ELSE NULL END)					'completedEvaluations',
		CAST(CAST(COUNT(DISTINCT CASE WHEN [EfectivityStatus] = 'COMPLETED' THEN [InteractionId] ELSE NULL END) AS DECIMAL(10,2))*100
		/
		CAST(COUNT(InteractionId) AS DECIMAL(10,2)) AS DECIMAL)															'completedPercentage'
		
        FROM Temp_EfectivityPlan EP1		

		WHERE  ISNULL(EfectivityPlanId, '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
			
		
		GROUP BY  EfectivityPlanId,EvaluationPlanId
		)		

		SELECT DISTINCT 
		TER.[EfectivityPlanId] 'id',
		TER.[EvaluationPlanId] 'evaluationPlanId',
		TER.[total] 'total',
		TER.[completedEvaluations] 'completedEvaluations',
		TER.[completedPercentage]	'completedPercentage',	
		TE.[CreatedDate] 'createdDate', 
		CASE WHEN TER.[completedPercentage] = 100 THEN 'COMPLETED' 
			 WHEN TER.[completedPercentage] = 0 THEN 'CREATED' ELSE 'IN_PROCESS' END  'statusDescription',
		TE.[AuditorId]	'auditorId'
		
		FROM Temp_EfectivityPlan_Result TER 
		INNER JOIN (SELECT DISTINCT [EfectivityPlanId],[EvaluationPlanId],[CreatedDate],[AuditorId] FROM dbo.[EvaluationResultEfectivity]
					WHERE VCC = @VCC) AS TE ON 
		TER.EfectivityPlanId = TE.EfectivityPlanId
	    AND TER.EvaluationPlanId = TE.EvaluationPlanId
		

    SET NOCOUNT OFF
END
GO
PRINT N'Modificando Procedimiento [dbo].[GetEvaluationFormatsFromHistoricEvaluationPlans]...';


GO
ALTER PROCEDURE [dbo].[GetEvaluationFormatsFromHistoricEvaluationPlans] (
	@VCC VARCHAR(50)
	)
AS
BEGIN
	SET NOCOUNT ON

 	SELECT DISTINCT HEF.[ID]			'id',
					HEF.[Description]	'description' 
		FROM [dbo].[EvaluationResult] ER (NOLOCK)
		INNER JOIN [dbo].[HistoricEvaluationFormat] HEF (NOLOCK)
			ON HEF.[EvaluationPlanId] = ER.[IdEvaluationPlan]
				AND HEF.[VCC] = ER.[Instance] 
				AND HEF.[ID] = ER.[IdEvaluationFormat]
		INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
			ON AEP.[Instance] = ER.[Instance]
				AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]
		WHERE HEF.[VCC] = @VCC 
			AND AEP.[Completed] = 1
		ORDER BY HEF.[Description] ASC

 	SET NOCOUNT OFF
END
GO
PRINT N'Modificando Procedimiento [dbo].[SaveInteractionEvaluationPlanResult]...';


GO
ALTER PROCEDURE [dbo].[SaveInteractionEvaluationPlanResult] (
	@VCC VARCHAR(50),
	@IdEvaluationPlan VARCHAR(50),
	@IdAuditor VARCHAR(50),
	@IdInteraction VARCHAR(250),
	@InteractionType VARCHAR(50),
	@Score NUMERIC(5,2),
	@AutomaticScore NUMERIC(5,2),
	@ManualScore NUMERIC(5,2),
	@EvaluationTime INT,
	@IsDraft BIT
) AS
BEGIN
	SET NOCOUNT ON

	-- EN CASO LLEGUE NULL ASIGNAMOS UN VALOR
	IF @IsDraft IS NULL
		SET @IsDraft = 0

 	UPDATE [dbo].[AuditorEvaluationPlan] 
		SET [Completed] = IIF (@IsDraft = 1, 0, 1), 
			[Score] = @Score, 
			[AutomaticScore] = @AutomaticScore,
			[ManualScore] = @ManualScore,
			[EvaluationTime] = @EvaluationTime,
			[StatusDescription] = IIF (@IsDraft = 1, 'DRAFT', 'COMPLETED'),
			[LastModifiedDate] = GETUTCDATE(),
			[TimeStamp] = GETUTCDATE()
		WHERE [Instance] = @VCC
			AND [IdEvaluationPlan] = @IdEvaluationPlan
			AND [IdInteraction] = @IdInteraction
			AND [InteractionType] = @InteractionType
			AND [IdAuditor] = @IdAuditor

	-- ACTUALIZAMOS LAS NOTAS FINALES TENIENDO EN CUENTA LAS PENALIZACIONES
	IF @IsDraft = 0
	BEGIN
		/****************************************************************************************/
		/*INICIO SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
		/****************************************************************************************/
	
		-- EMULAMOS UNA NUEVA TABLA VARIABLE PARA DETERMINAR LAS INTERACCIONES QUE TIENEN HABILIDAD(ES) PENALIZADA(S) POR NOTA CERO
		--  ORDENANDO POR PRIORIDAD (INTERACCION 1, GRUPO 2 Y SUBGRUPO 3)
		;WITH CTEFP AS (
			SELECT DISTINCT 
					ER.[Instance],
					ER.[IdInteraction],
					ER.[IdEvaluationPlan],
					ER.[IdEvaluationFormat],
					ER.[IdAbility],
					CASE WHEN ER.[AbilityInnerScore] = 0 AND ER.[NotApplies] = 0 AND HAEF.[Penalizes] <> 'NO' THEN 1 ELSE 0 END 'Penalized',
					HAEF.[Penalizes],
					CASE HAEF.[Penalizes]
						WHEN 'INT' THEN ER.[IdInteraction] 
						WHEN 'GRP' THEN ER.[IdGroup] 
						WHEN 'SGR' THEN ER.[IdSubGroup] 
					END 'PenalizedOn',
					RN = ROW_NUMBER() OVER(PARTITION BY ER.[IdInteraction], CASE WHEN ER.[AbilityInnerScore] = 0 THEN 1 ELSE 0 END 
						ORDER BY CASE HAEF.[Penalizes]
						WHEN 'INT' THEN 1 
						WHEN 'GRP' THEN 2 
						WHEN 'SGR' THEN 3 
					END)
				FROM [dbo].[EvaluationResult] ER (NOLOCK) 
				LEFT JOIN [HistoricAbilityEvaluationFormat] HAEF (NOLOCK) 
					ON HAEF.[VCC] = ER.[Instance]
						AND HAEF.[EvaluationPlanId] = ER.[IdEvaluationPlan]
						AND HAEF.[IdEvaluationFormat] = ER.[IdEvaluationFormat]
						AND HAEF.[IdAbility] = ER.[IdAbility]
				WHERE ER.[IdEvaluationPlan] IN (@IdEvaluationPlan) 
					AND ER.[IdInteraction] = @IdInteraction
					AND ER.[IdAuditor] = @IdAuditor
					AND ER.[AbilityInnerScore] = 0
					AND ER.[NotApplies] = 0
					AND HAEF.[Penalizes] <> 'NO'
				-- WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EPA.[EvaluationPlanId] FROM [DummyEvaluationPlanAbility] EPA (NOLOCK) WHERE EPA.[EvaluationPlanId] IS NOT NULL)
		),
		CTEFS AS (
			SELECT ER.[Instance],
					ER.[IdEvaluationPlan],
					ER.[IdInteraction],
					ER.[IdAuditor],
					SUM(ER.[Qualification])															'TOTAL_SCORE',
					SUM(IIF(HA.[Type] = 'MANUAL_AUTOMATIC', ER.[Qualification], 0))					'TOTAL_AUTOMATIC_SCORE',
					SUM(IIF(HA.[Type] = 'MANUAL', ER.[Qualification], 0))							'TOTAL_MANUAL_SCORE',
					--SUM(ER.[Qualification] * CASE WHEN FP2.[Penalized] IS NULL THEN 1 ELSE 0 END) 'PENALIZED_SCORE',
					SUM(ER.[Qualification] * (
						CASE WHEN (
							CASE FP2.[Penalizes]
								WHEN 'INT' THEN ER.[IdInteraction] 
								WHEN 'GRP' THEN ER.[IdGroup] 
								WHEN 'SGR' THEN ER.[IdSubGroup] 
							END = FP2.[PenalizedOn]
							AND FP2.[Penalized] = 1) THEN 0 ELSE 1 END
					))																				'PENALIZED_SCORE',
					SUM(IIF(HA.[Type] = 'MANUAL_AUTOMATIC',
						ER.[Qualification] * (
						CASE WHEN (
							CASE FP2.[Penalizes]
								WHEN 'INT' THEN ER.[IdInteraction] 
								WHEN 'GRP' THEN ER.[IdGroup] 
								WHEN 'SGR' THEN ER.[IdSubGroup] 
							END = FP2.[PenalizedOn]
							AND FP2.[Penalized] = 1
						) THEN 0 ELSE 1 END),
						0) 
					)																				'PENALIZED_AUTOMATIC_SCORE',
					SUM(IIF(HA.[Type] = 'MANUAL',
						ER.[Qualification] * (
						CASE WHEN (
							CASE FP2.[Penalizes]
								WHEN 'INT' THEN ER.[IdInteraction] 
								WHEN 'GRP' THEN ER.[IdGroup] 
								WHEN 'SGR' THEN ER.[IdSubGroup] 
							END = FP2.[PenalizedOn]
							AND FP2.[Penalized] = 1
						) THEN 0 ELSE 1 END),
						0) 
					)																				'PENALIZED_MANUAL_SCORE'
				FROM [dbo].[EvaluationResult] ER (NOLOCK) 
				LEFT JOIN (
					-- HACEMOS UN CRUCE CON LA TABLA VARIABLE Y TOMAMOS SOLO UNA DE LAS PENALIZACIONES POR INTERACCION, EMPEZANDO 
					--  POR LA MAS PRIORITARIA (FP.[RN])
					SELECT DISTINCT FP.[Instance],
									FP.[IdEvaluationPlan], 
									FP.[IdInteraction], 
									FP.[Penalized],
									FP.[Penalizes], 
									FP.[PenalizedOn]
						FROM CTEFP FP (NOLOCK)
						WHERE FP.[Penalizes] <> 'NO'
							AND FP.[RN] = 1
				) FP2
					ON FP2.[Instance] = ER.[Instance]
						AND ER.[IdEvaluationPlan] = FP2.[IdEvaluationPlan]
						AND ER.[IdInteraction] = FP2.[IdInteraction]
						/*
						AND CASE FP2.[Penalizes]
								WHEN 'INT' THEN ER.[IdInteraction] 
								WHEN 'GRP' THEN ER.[IdGroup] 
								WHEN 'SGR' THEN ER.[IdSubGroup] 
							END = FP2.[PenalizedOn]
						AND FP2.[Penalized] = 1
						*/
				INNER JOIN [dbo].[HistoricAbility] HA (NOLOCK)
					ON HA.[VCC] = ER.[Instance]
						AND HA.[EvaluationPlanId] = ER.[IdEvaluationPlan]
						AND HA.[ID] = ER.[IdAbility]
				--WHERE ER.[Instance] = 'multisalud'
				WHERE -- ER.[Instance] = FP2.[Instance] -- ESTA LINEA CAUSA QUE NO SE ACTUALICEN LOS SCORES LAS EVALUACIONES QUE NO PENALIZAN
					-- AND 
					ER.[IdEvaluationPlan] IN (@IdEvaluationPlan) 
					AND ER.[IdInteraction] = @IdInteraction
					AND ER.[IdAuditor] = @IdAuditor
					--AND ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM DummyEvaluationPlanAbility)
				GROUP BY ER.[Instance],
					ER.[IdEvaluationPlan],
					ER.[IdInteraction],
					ER.[IdAuditor]
		)
		--SELECT * FROM CTEFS

		-- ACTUALIZAMOS LOS REGISTROS DE EVALUACION CON LA NOTA PENALIZADA OBTENIDA EN LOS PASOS ANTERIORES
		UPDATE AEP 
			SET AEP.[Score] = FS.[PENALIZED_SCORE],
				AEP.[AutomaticScore] = FS.[PENALIZED_AUTOMATIC_SCORE],
				AEP.[ManualScore] = FS.[PENALIZED_MANUAL_SCORE],
				AEP.[LastModifiedDate] = GETUTCDATE(),
				AEP.[TimeStamp] = GETUTCDATE()
			FROM AuditorEvaluationPlan AEP (NOLOCK)
			LEFT JOIN CTEFS FS (NOLOCK) 
				ON FS.[Instance] = AEP.[Instance] 
					AND FS.[IdEvaluationPlan] = AEP.[IdEvaluationPlan] 
					AND FS.[IdInteraction] = AEP.[IdInteraction]
					AND FS.[IdAuditor] = AEP.[IdAuditor]
			WHERE FS.[Instance] IS NOT NULL

		/*************************************************************************************/
		/*FIN SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
		/*************************************************************************************/
	END

    SELECT 1 AS 'result'

 	SET NOCOUNT OFF
END
GO
PRINT N'Modificando Procedimiento [dbo].[BulkInteractionEvaluationPlan]...';


GO
ALTER PROCEDURE [dbo].[BulkInteractionEvaluationPlan]
AS
BEGIN
	SET NOCOUNT ON

	-- DECLARAMOS UNA VARIABLE PARA DEFINIR EL VCC
	DECLARE @VCC VARCHAR(50) = NULL
	DECLARE @VCC_TYPE VARCHAR(50) = NULL
	DECLARE @NEED_I6_UPDATE BIT = 0 

	-- ASIGNAMOS A LA VARIABLE EL NOMBRE DEL VCC
	SELECT TOP 1 @VCC = [VCC] FROM [#InteractionEvaluationPlanTemp] (NOLOCK)

	-- BUSCAMOS EL TIPO DE VCC
	SELECT @VCC_TYPE = V.[Type] FROM [dbo].[VCC] V (NOLOCK) WHERE V.[VCC] = @VCC

	-- CAMBIAMOS EL VALOR DEL FLAG
	IF @VCC_TYPE = 'I6' SET @NEED_I6_UPDATE = 1

	-- INSERTAMOS LA DATA DE LA TABLA TEMPORAL
	INSERT INTO [dbo].[InteractionEvaluationPlan] (
			[Instance], [IdEvaluationPlan], [IdAgent],
			[AgentName], [IdCampaign], [IdInteraction], 
			[FormattedEndDate], [InteractionSection], [InteractionPart], 
			[InteractionDateStart], [InteractionDateEnd], [InteractionType], 
			[InteractionMessages], [InteractionDuration], [InteractionOrigin], 
			[ManagementResult], [RelativePath], [FileName],
			[ContactId], [ContactAddress], [ContactName], 
			[InteractionFormat], [NeedI6Update], [RelativeFileName], 
			[Ender], [Ticket],
			[CreatedByUserId], [CreatedDate], [TimeStamp])
		SELECT IEP.[VCC], IEP.[IdEvaluationPlan], IEP.[IdAgent],
				IEP.[AgentName], IEP.[IdCampaign], IEP.[IdInteraction], 
				IEP.[InteractionFolder], IEP.[InteractionSection], IEP.[InteractionPart], 
				IEP.[InteractionDateStart], IEP.[InteractionDateEnd], IEP.[InteractionType], 
				IEP.[TotalMessages], IEP.[InteractionDuration], IEP.[InteractionOrigin], 
				IEP.[InteractionManagementResult], IEP.[RelativePath], IEP.[FileName],
				IEP.[InteractionContactId], IEP.[InteractionContactAddress], IEP.[InteractionContactName],
				IEP.[InteractionFormat], 
				CASE WHEN @VCC_TYPE = 'OCC'
					THEN IIF(IEP.[InteractionType] = 'CALL', 0 , 1) 
					ELSE @NEED_I6_UPDATE
					END,
				[RelativeFileName],
				IEP.[Ender], IEP.[Ticket],
				IEP.[CreatedByUserId], GETUTCDATE(), GETUTCDATE()
			FROM [#InteractionEvaluationPlanTemp] IEP (NOLOCK)
			/*
			LEFT JOIN [dbo].[Agent] A (NOLOCK)
				ON A.[VCC] = IEP.[VCC]
					AND A.[AgentId] = IEP.[IdAgent]
			*/

	-- ELIMINAMOS LA TABLA TEMPORAL 
	DROP TABLE [#InteractionEvaluationPlanTemp]
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando Procedimiento [dbo].[GetAgentsFromEvaluation]...';


GO
-- ESTE SP RETORNA LOS AGENTES ASOCIADOS A EVALUACIONES
ALTER PROCEDURE [dbo].[GetAgentsFromEvaluation] 
(
	@VCC					VARCHAR(50) = NULL,
	@UserId					VARCHAR(50) = NULL,
	@Campaigns				VARCHAR(MAX) = NULL,
	@SearchType				VARCHAR(50) = NULL,
	@EfectivityMode			BIT = 0 
) 
AS
BEGIN
	-- DECLARAMOS UN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_FROM_EFECTIVITY VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER_EFECTIVITY VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';

	-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
	SET @SQL_SELECT += '
		SELECT DISTINCT IEP.[Instance]							''vcc'', 
						IEP.[IdAgent]							''userId''
						-- IEP.[IdCampaign]						''campaignId'' -- NO SE USA APARENTEMENTE (PROBLEMA SAT V.3.7.0) '

	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction] '
	SET @SQL_FROM_EFECTIVITY += '
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction] 
			INNER JOIN (
				SELECT DISTINCT [VCC],
								[InteractionId],
								[AgentId],
								[EvaluationPlanId],
								[AuditorId] 
					FROM [dbo].[EvaluationResultEfectivity] (NOLOCK)
					WHERE [VCC] = ''' + @VCC + ' '' 
						AND [EfectivityStatus] IN (''' + 'CREATED' + '''' + ',' + '''' + 'DRAFT' + ''''+ ')' + '
			) AS ERE ON 
				(AEP.[Instance] = ERE.[VCC] 
					AND AEP.[IdEvaluationPlan] = ERE.[EvaluationPlanId]
					AND AEP.[IdInteraction] = ERE.[InteractionId])'	

	-- ARMAMOS LA PARTE DE FILTROS
	SET @SQL_FILTER += '
			WHERE AEP.[Instance] = ''' + @VCC + ''' 
				AND LEN(IEP.[IdAgent]) > 0 '
	SET @SQL_FILTER_EFECTIVITY += '
			WHERE AEP.[Instance] = ''' + @VCC + ''' 
				AND LEN(IEP.[IdAgent]) > 0 '

	-- ARMAMOS LA PARTE DE EXTRAS
	SET @SQL_EXTRA = '
			ORDER BY IEP.[IdAgent] ASC '

	-- FILTRAMOS SEGUN EL TIPO DE BUSQUEDA
	IF @SearchType = 'PENDING'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES QUE NO HAN SIDO EVALUADAS
		SET @SQL_FILTER += '
			AND AEP.[Completed] = 0 '
	END
	ELSE IF @SearchType = 'HISTORY'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES QUE YA HAN SIDO EVALUADAS
		SET @SQL_FILTER += '
			AND AEP.[Completed] = 1 '
	END

	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR EL ROLE DEL USUARIO
	DECLARE @USER_ROLE VARCHAR(50) 
	SELECT TOP 1 @USER_ROLE = U.[Role] 
		FROM [dbo].[User] U (NOLOCK) 
		WHERE U.[VCC] = @VCC
			AND U.[ID] = @UserId

	-- FILTRAMOS SEGUN EL ROLE DEL USUARIO
	-- IF @RoleId = 'administrator, quality_admin'
	IF @USER_ROLE = 'quality_auditor'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES AUDITADAS POR EL USUARIO
		SET @SQL_FILTER += '
			AND AEP.[IdAuditor] = ''' + @UserId + ''' '
		SET @SQL_FILTER_EFECTIVITY += '
			AND ERE.[AuditorId] = ''' + @UserId + ''' '
	END
	ELSE IF @USER_ROLE = 'quality_agent'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES HECHAS POR EL USUARIO
		SET @SQL_FILTER += '
			AND AEP.[IdAgent] = ''' + @UserId + ''' '
	END

	-- FILTRAMOS SEGUN EL VALOR DE CAMPAIGNS
	IF @Campaigns IS NOT NULL AND @Campaigns <> ''
	BEGIN
		SET @SQL_FILTER += '
			AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
        SET @SQL_FILTER_EFECTIVITY += '
			AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	END 

	-- UNIMOS LAS PARTES DEL QUERY
	IF (@EfectivityMode =1)
	SET @SQL_SELECT += @SQL_FROM_EFECTIVITY + @SQL_FILTER_EFECTIVITY + @SQL_EXTRA
	ELSE
	SET @SQL_SELECT += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA
	
	-- EJECUTAMOS LA CONSULTA
	--PRINT @SQL_SELECT
	EXEC (@SQL_SELECT)
	
END
GO
PRINT N'Modificando Procedimiento [dbo].[GetCampaignsFromEvaluation]...';


GO
-- ESTE SP RETORNA LAS CAMPANAS ASOCIADAS A EVALUACIONES
ALTER PROCEDURE [dbo].[GetCampaignsFromEvaluation] 
(
	@VCC					VARCHAR(50) = NULL,
	@UserId					VARCHAR(50) = NULL,
	@SearchType				VARCHAR(50) = 'HISTORY',
	@EfectivityMode			BIT = 0
) 
AS
BEGIN
	-- DECLARAMOS UN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_FROM_EFECTIVITY VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER_EFECTIVITY VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';

	-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
	SET @SQL_SELECT += '
		SELECT DISTINCT IEP.[Instance]							''vcc'', 
						IEP.[IdCampaign]						''id'',
						IEP.[IdCampaign]						''description'' '

	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction] '
	SET @SQL_FROM_EFECTIVITY +=	'
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction]
			INNER JOIN ( SELECT DISTINCT [VCC],[InteractionId],[AgentId],[EvaluationPlanId],[AuditorId] FROM [dbo].[EvaluationResultEfectivity] 
						 WHERE [EfectivityStatus] IN( ''' + 'CREATED'+''''+','+ ''''+ 'DRAFT'+''''+ ')' +

			')AS ERE ON 
				(AEP.[Instance] = ERE.[VCC] 
					AND AEP.[IdEvaluationPlan] = ERE.[EvaluationPlanId]
					AND AEP.[IdInteraction] = ERE.[InteractionId])'	

	-- ARMAMOS LA PARTE DE FILTROS
	SET @SQL_FILTER += '
			WHERE AEP.[Instance] = ''' + @VCC + ''' 
				AND IEP.[IdCampaign] IS NOT NULL '
	SET @SQL_FILTER_EFECTIVITY += '
			WHERE AEP.[Instance] = ''' + @VCC + ''' 
				AND IEP.[IdCampaign] IS NOT NULL '

	-- ARMAMOS LA PARTE DE EXTRAS
	SET @SQL_EXTRA = '
			ORDER BY IEP.[IdCampaign] ASC '

	-- FILTRAMOS SEGUN EL TIPO DE BUSQUEDA
	IF @SearchType = 'PENDING'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES QUE NO HAN SIDO EVALUADAS
		SET @SQL_FILTER += '
			AND AEP.[Completed] = 0 '
	END
	ELSE IF @SearchType = 'HISTORY'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES QUE YA HAN SIDO EVALUADAS
		SET @SQL_FILTER += '
			AND AEP.[Completed] = 1 '
	END

	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR EL ROLE DEL USUARIO
	DECLARE @USER_ROLE VARCHAR(50) 
	SELECT TOP 1 @USER_ROLE = U.[Role] 
		FROM [dbo].[User] U (NOLOCK) 
		WHERE U.[VCC] = @VCC
			AND U.[ID] = @UserId

	-- FILTRAMOS SEGUN EL ROLE DEL USUARIO
	-- IF @RoleId = 'administrator, quality_admin'
	IF @USER_ROLE = 'quality_auditor'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES AUDITADAS POR EL USUARIO
		SET @SQL_FILTER += '
			AND AEP.[IdAuditor] = ''' + @UserId + ''' '
		SET @SQL_FILTER_EFECTIVITY += '
			AND ERE.[AuditorId] = ''' + @UserId + ''' '
		
	END
	ELSE IF @USER_ROLE = 'quality_agent'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES HECHAS POR EL USUARIO
		SET @SQL_FILTER += '
			AND AEP.[IdAgent] = ''' + @UserId + ''' '
	END

	-- UNIMOS LAS PARTES DEL QUERY
	IF (@EfectivityMode =1)
	SET @SQL_SELECT += @SQL_FROM_EFECTIVITY + @SQL_FILTER_EFECTIVITY + @SQL_EXTRA
	ELSE
	SET @SQL_SELECT += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA
	
	-- EJECUTAMOS LA CONSULTA
	--PRINT @SQL_SELECT
	EXEC (@SQL_SELECT)
	
END
GO
PRINT N'Modificando Procedimiento [dbo].[GetEnvironment]...';


GO
ALTER PROCEDURE [dbo].[GetEnvironment] (
	@VCC Varchar(50) = NULL, @Name Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	SELECT [VCC]				'vcc',
		[Name]					'name',
		[Type]					'type',
		[Description]			'description',
		[FTPDirectory]			'ftpDirectory',
		[ApiHost]				'apiHost',
		[ApiPort]				'apiPort',
		[ApiUser]				'apiUser',
		[ApiPassword]			'apiPassword',
		[DbDisabled]			'dbDisabled',
		[DbServer]				'dbServer',
		[DbPort]				'dbPort',
		[DbUser]				'dbUser',
		[DbPassword]			'dbPassword',
		[PbxDisabled]			'pbxDisabled',
		[PbxServer]			    'pbxServer',
		[PbxPort]			    'pbxPort',
		[PbxUser]			    'pbxUser',
		[PbxPassword]			'pbxPassword',
		[CreatedDate]			'createdDate',
		[CreatedByUserId]		'createdByUserId',
		[LastModifiedDate]		'lastModifiedDate',
		[LastModifiedByUserId]	'lastModifiedByUserId'
	FROM [Environment] (NOLOCK)
	WHERE [VCC] = @VCC
	AND [Name] = @Name
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando Procedimiento [dbo].[GetNLU]...';


GO
ALTER PROCEDURE [dbo].[GetNLU] (
	@VCC Varchar(50) = NULL, @Name Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON
	IF EXISTS (SELECT 1 FROM [NLU]
	WHERE [VCC] = CASE WHEN ISNULL(@VCC, '') = '' THEN [VCC] ELSE @VCC END 
	AND [Name] = @Name )
	
	BEGIN 
		SELECT
			[VCC]							'vcc',
			[Name]						    'name',
			[CognitiveEngine]				'cognitiveEngine',
			[Culture]						'culture',
			[Description]					'description',
			[AppId]							'appId',
			[SubscriptionKey]				'subscriptionKey',
			[IsSystemApp]					'isSystemApp',
			[NeedTrain]						'needTrain',
			[LastTrainedDate]				'lastTrainedDateTime',
			[LastPublishedDate]				'lastPublishedDateTime',
			[CreatedDate]					'createdDate',
			[CreatedByUserId]				'createdByUserId',
			[LastModifiedDate]				'lastModifiedDate',
			[LastModifiedByUserId]			'lastModifiedByUserId'
		FROM [NLU] (NOLOCK)
		WHERE [VCC] = CASE WHEN ISNULL(@VCC, '') = '' THEN [VCC] ELSE @VCC END 
		AND [Name] = @Name
	END
	ELSE
	BEGIN
		SELECT
				[VCC]							'vcc',
				[Name]						    'name',
				[CognitiveEngine]				'cognitiveEngine',
				[Culture]						'culture',
				[Description]					'description',
				[AppId]							'appId',
				[SubscriptionKey]				'subscriptionKey',
				[IsSystemApp]					'isSystemApp',
				[NeedTrain]						'needTrain',
				[LastTrainedDate]				'lastTrainedDateTime',
				[LastPublishedDate]				'lastPublishedDateTime',
				[CreatedDate]					'createdDate',
				[CreatedByUserId]				'createdByUserId',
				[LastModifiedDate]				'lastModifiedDate',
				[LastModifiedByUserId]			'lastModifiedByUserId'
			FROM [NLU] (NOLOCK)
			WHERE [VCC] = 'system'
			AND [Name] = @Name
			AND [Name] LIKE 'sentiment-%'
		
	END
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando Procedimiento [dbo].[GetNotEvaluatedInteractionsAuditor]...';


GO
ALTER PROCEDURE [dbo].[GetNotEvaluatedInteractionsAuditor] (
	@Instance Varchar(50) = NULL, 
	@UserId Varchar(50) = NULL,
	@IdCampaigns VARCHAR(MAX) = NULL,
	@IdAgents Varchar(MAX) = NULL,
	@EvaluationPlans Varchar(MAX) = NULL,
	@InteractionTypes Varchar(100) = NULL,
	@InteractionResults Varchar(MAX) = NULL,
	@EvaluationDateFrom VARCHAR(50) = '1980-01-01T00:00:00',
    @EvaluationDateTo VARCHAR(50) = '2050-01-01T23:59:59',
 	@EvaluationPlanDateTo   VARCHAR(MAX) = '2050-01-01T23:59:59',
	@EvaluationStatus BIT = 1,
 	@InteractionIds     VARCHAR(MAX) = NULL,
	@ContactAddress VARCHAR(300) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	IF @EvaluationDateFrom IS NULL OR LEN(@EvaluationDateFrom) = 0 SET @EvaluationDateFrom = '1980-01-01T00:00:00'
	IF @EvaluationDateTo IS NULL OR LEN(@EvaluationDateTo) = 0 SET @EvaluationDateTo = '2050-01-01T23:59:59'
	IF @EvaluationPlanDateTo IS NULL OR LEN(@EvaluationPlanDateTo) = 0 SET @EvaluationPlanDateTo = '2050-01-01T23:59:59'

	DECLARE @USER_ROLE VARCHAR(50) = ''
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''

	-- IDENTIFICAMOS EL ROL DEL USUARIO
	SELECT @USER_ROLE = U.[Role]
		FROM [dbo].[User] U (NOLOCK)
		WHERE U.[VCC] = @Instance
			AND U.[ID] = @UserId

	-- EMULAMOS UNA NUEVA TABLA EN BASE A AuditorEvaluationPlan DONDE SE REMOVERAN TODOS LOS REGISTROS DUPLICADOS PARA EL PK DE LA TABLA Audio
	SET @SQL_SELECT_1 += '
		WITH CTE AS (
			SELECT AEP.[Instance], 
					AEP.[IdEvaluationPlan], 
					AEP.[IdInteraction], 
					AEP.[IdAuditor], 
					AEP.[Score], 
					IEP.[AgentName],
					AEP.[LastModifiedDate],
					RN = ROW_NUMBER() OVER(PARTITION BY AEP.[Instance], AEP.[IdEvaluationPlan], AEP.[IdInteraction] ORDER BY AEP.[LastModifiedDate] DESC)
			FROM AuditorEvaluationPlan AEP (NOLOCK)
			LEFT JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance] 
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction]
					AND IEP.[IdAgent] = AEP.[IdAgent]
			WHERE AEP.[Instance] = ''' + @Instance + ''' 
				AND AEP.[Completed] = 0 
				AND AEP.[IdAuditor] <> ''SPEECH''
				AND AEP.[StatusDescription] NOT IN(''INVALID'') '

	IF @USER_ROLE = 'quality_auditor' 
	BEGIN
		SET @SQL_SELECT_1 += '
				AND	AEP.[IdAuditor] = ''' + @UserId + ''' '
	END

	IF (@IdCampaigns IS NOT NULL AND @IdCampaigns != '') SET @SQL_SELECT_1 += 'AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaigns + ''','','')) ';
	IF (@IdAgents IS NOT NULL AND @IdAgents != '') SET @SQL_SELECT_1 += 'AND AEP.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgents + ''','','')) ';
	IF (@EvaluationPlans IS NOT NULL AND @EvaluationPlans != '') SET @SQL_SELECT_1 += 'AND AEP.[IdEvaluationPlan] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationPlans + ''','','')) '
	IF (@InteractionTypes IS NOT NULL AND @InteractionTypes != '') SET @SQL_SELECT_1 += 'AND AEP.[InteractionType] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTypes + ''','','')) ';
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') 
		SET @SQL_SELECT_1 += 'AND (
								(CONCAT(AEP.[IdCampaign], ISNULL(REPLACE(AEP.[ManagementResult], ''/'', ''_''), ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(CONCAT(AEP.[IdCampaign], ''_'', ISNULL(AEP.[ManagementResult], ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(AEP.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
							)'

	SET @SQL_SELECT_1 += '
		),
		CLEANED_CTE AS (
			SELECT C.[Instance], 
					C.[IdEvaluationPlan], 
					C.[IdInteraction], 
					C.[IdAuditor], 
					C.[Score], 
					C.[AgentName],
					C.[LastModifiedDate]
			FROM [CTE] C
			WHERE C.[RN] = 1
		) '
	-- EL CTE SOLO PUEDE SER INVOCADO UNA VEZ POR ESO LO PONEMOS EN EL SELECT FINAL DONDE EL CONTADOR(RN) ES 1
	
	-- ARMAMOS EL SELECT PRINCIPAL PARA LA BUSQUEDA DE EVALUACIONES PENDIENTES DEL AUDITOR
	SET @SQL_SELECT_1 += '
		SELECT DISTINCT '
	SET @SQL_SELECT_1 += '
				AEP.[IdInteraction]															''id'', 
				AEP.[IdCampaign]															''descriptionCampaign'',
				AEP.[IdAgent]																''idAgent'',
				AEP.[IdAgent]																''descriptionAgent'',
				AEP.[InteractionDate]														''dateIni'',
				AEP.[InteractionDateEnd]													''dateFin'',
				AEP.[InteractionDuration]													''interactionTime'',
				AEP.[Completed]																''evaluated'',
				AEP.[InteractionType]														''interactionType'',
				AEP.[ManagementResult]														''dispositionCode'',
				AEP.[ContactAddress]																''address'',
				AEP.[InteractionOrigin]														''origin'',
				AEP.[IdEvaluationPlan]														''idEvaluationPlan'',
				EP.[ProcessId]																''processId'',
				EP.[Description]															''descriptionEvaluationPlan'',
				EP.[DateFin]																''dateFinEvaluationPlan'', 
				EP.[Modality]																''evaluationPlanModality'',
				EP.[Evaluation_Mode]														''evaluationPlanEvaluationMode'',
				A.[ID]																		''idAuditor'', 
				A.[Description]																''descriptionAuditor'',
				ISNULL(U.[FirstName] + '' '', '''') + ISNULL(U.[LastName], '''')			''auditorName'',						-- NOMBRE DEL AUDITOR
				C.[AgentName]																''agentName'',							-- NOMBRE DEL AGENTE
				C.[IdAuditor]																''lastEvaluationEvaluator'', 
				C.[Score]																	''lastEvaluationScore'',
				AEP.[Status]																''status'',
				CASE
					WHEN EP.[DateFin] < CAST(GETDATE()  AS DATE)
					THEN 1
					ELSE 0
				END																			''isExpired'',
				AEP.[StatusDescription]														''statusDescription'''

	SET @SQL_FROM += '
			FROM [AuditorEvaluationPlan] AEP (NOLOCK) 
			INNER JOIN [EvaluationPlan] EP (NOLOCK) 
				ON (EP.[Instance] = EP.Instance
					AND EP.[ID] = AEP.IdEvaluationPlan) 
			INNER JOIN CLEANED_CTE C (NOLOCK) 
				ON C.[Instance] = AEP.[Instance] 
					AND C.[IdEvaluationPlan] = AEP.[IdEvaluationPlan] 
					AND C.[IdInteraction] = AEP.[IdInteraction]
			LEFT JOIN [dbo].[User] U (NOLOCK)
				ON U.[VCC] = AEP.[Instance]
					AND U.[ID] = AEP.[IdAuditor]
			LEFT JOIN [Auditor] A (NOLOCK) 
				ON (A.[ID] = AEP.[IdAuditor]) '

	SET @FILTERS_FIXED_PART = '
			WHERE AEP.[Instance] = ''' + @Instance + '''
				AND AEP.[InteractionDate] >= ''' + @EvaluationDateFrom + '''
				AND AEP.[InteractionDate] <= ''' + @EvaluationDateTo + ''' 
				AND AEP.[Completed] = 0
				AND AEP.[StatusDescription] NOT IN(''INVALID'')
				AND EP.[Enabled] = 1 
				AND (
					(EP.[Evaluation_Mode] = ''X'' AND EP.[Status] = 8)
					OR
					(EP.[Evaluation_Mode] = ''M'')
				) '

	-- AGREGAMOS EL FILTRO DE ESTADO
	IF @EvaluationStatus = 0
	BEGIN
		SET @FILTERS_FIXED_PART += '
				AND AEP.[Status] = 0 '
	END
	ELSE IF @EvaluationStatus = 1
	BEGIN
		SET @FILTERS_FIXED_PART += '
				AND AEP.[Status] = 1 '
	END

	-- HACEMOS EL FILTRADO SEGUN EL ROL DEL USUARIO
	IF @USER_ROLE = 'quality_auditor'
	BEGIN
		SET @FILTERS_FIXED_PART += '
				AND	AEP.[IdAuditor] = ''' + @UserId + ''' '
	END
	ELSE IF @USER_ROLE = 'administrator' OR @USER_ROLE = 'quality_admin'
	BEGIN
		SET @FILTERS_FIXED_PART += ''
	END
	ELSE 
	BEGIN
		SET @FILTERS_FIXED_PART += '
				AND	AEP.[IdAuditor] = ''' + @UserId + ''' '
	END

	/*
	IF (@IdCampaigns IS NOT NULL AND @IdCampaigns != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaigns + ''','','')) ';
	IF (@IdAgents IS NOT NULL AND @IdAgents != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgents + ''','','')) ';
	--IF (@EvaluationPlans IS NOT NULL AND @EvaluationPlans != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdEvaluationPlan] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationPlans + ''','','')) '
	IF (@InteractionTypes IS NOT NULL AND @InteractionTypes != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionType] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTypes + ''','','')) ';
	-- IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') SET @FILTERS_EXCLUDING_PART += 'AND CONCAT(AEP.[IdCampaign], ''_'', AEP.[ManagementResult]) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')) ';
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND (
								(CONCAT(AEP.[IdCampaign], ISNULL(REPLACE(AEP.[ManagementResult], ''/'', ''_''), ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(CONCAT(AEP.[IdCampaign], ''_'', ISNULL(AEP.[ManagementResult], ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(AEP.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
							)'
	*/
	IF (@EvaluationPlanDateTo IS NOT NULL AND @EvaluationPlanDateTo != '') SET @FILTERS_OPTIONAL_PART += 'AND EP.[DateFin] <= ''' + @EvaluationPlanDateTo + '''  ';
	IF(@ContactAddress IS NOT NULL AND @ContactAddress <>'')
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND AEP.ContactAddress LIKE ''%' + @ContactAddress + '%''
			'
	END	
	
	IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
       BEGIN 
            SET @FILTERS_OPTIONAL_PART = '';
	        SET @FILTERS_EXCLUDING_PART=' AND AEP.[IdInteraction] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) ';
       END

	SET @SQL_SELECT_1 += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART;

	-- print @SQL_SELECT_1
	EXEC (@SQL_SELECT_1)

 	SET NOCOUNT OFF
END
GO
PRINT N'Actualizando Procedimiento [dbo].[BulkAudio]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkAudio]';


GO
PRINT N'Actualizando Procedimiento [dbo].[BulkInteractionProcess]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkInteractionProcess]';


GO
PRINT N'Actualizando Procedimiento [dbo].[BulkInteractionQueryStudy]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkInteractionQueryStudy]';


GO
PRINT N'Actualizando Procedimiento [dbo].[BulkProcessI6Update]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkProcessI6Update]';


GO
PRINT N'Actualizando Procedimiento [dbo].[BulkProcessInteraction]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkProcessInteraction]';


GO
PRINT N'Actualizando Procedimiento [dbo].[CloseI6InteractionAudio]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[CloseI6InteractionAudio]';


GO
PRINT N'Actualizando Procedimiento [dbo].[DeleteI6InteractionAudio]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteI6InteractionAudio]';


GO
PRINT N'Actualizando Procedimiento [dbo].[DeleteInteraction]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteInteraction]';


GO
PRINT N'Actualizando Procedimiento [dbo].[EvaluateProcessStatus]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[EvaluateProcessStatus]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetAllegroBillingInteractionsForEvaluationPlan]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAllegroBillingInteractionsForEvaluationPlan]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetAudio]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAudio]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetAudioNavigatorInteractions]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAudioNavigatorInteractions]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetAudios]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAudios]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetAudiosByProcessId]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAudiosByProcessId]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetAudiosProcess]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAudiosProcess]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetBillingInteractions]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetBillingInteractions]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetCleanerData]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetCleanerData]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetCognitiveAnalysisProcessValidDurationTime]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetCognitiveAnalysisProcessValidDurationTime]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetEvaluationPlanCognitiveInteractionTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanCognitiveInteractionTask]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetEvaluationPlanCognitiveTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanCognitiveTask]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetEvaluationPlanInteractionByTypeAndId]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanInteractionByTypeAndId]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetEvaluationPlanTipificationInteractionTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanTipificationInteractionTask]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetExecuteTemplateProcess]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetExecuteTemplateProcess]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetGlobalSearchFilters]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetGlobalSearchFilters]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetGlobalSearchInteractions]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetGlobalSearchInteractions]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetI6AlreadyRegisteredCallInteractions]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetI6AlreadyRegisteredCallInteractions]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetI6InteractionAudios]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetI6InteractionAudios]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetInteractionAgents]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetInteractionAgents]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetInteractionCampaigns]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetInteractionCampaigns]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetInteractionsCognitive]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetInteractionsCognitive]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetInteractionsResult]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetInteractionsResult]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetInteractionTranscription]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetInteractionTranscription]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetLinguisticProcessStatus]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetLinguisticProcessStatus]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetPendingAudios]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetPendingAudios]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetProcess]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetProcess]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetProcessFiltersData]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetProcessFiltersData]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetProcessI6InteractionsToUpdate]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetProcessI6InteractionsToUpdate]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetProcessInteractionsByProcessId]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetProcessInteractionsByProcessId]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetProcessInteractionsHistory]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetProcessInteractionsHistory]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetProcessInteractionsTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetProcessInteractionsTask]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetProcessSummary]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetProcessSummary]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetProcessValidDurationTime]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetProcessValidDurationTime]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetStudiesInProcess]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetStudiesInProcess]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetStudyCognitiveInteractionsTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetStudyCognitiveInteractionsTask]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetTeamPerformanceFromEvaluationPlan]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetTeamPerformanceFromEvaluationPlan]';


GO
PRINT N'Actualizando Procedimiento [dbo].[SaveAudio]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveAudio]';


GO
PRINT N'Actualizando Procedimiento [dbo].[SaveAudioLinguisticProcess]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveAudioLinguisticProcess]';


GO
PRINT N'Actualizando Procedimiento [dbo].[SaveEvaluationBaseResult]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveEvaluationBaseResult]';


GO
PRINT N'Actualizando Procedimiento [dbo].[SaveProcess]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveProcess]';


GO
PRINT N'Actualizando Procedimiento [dbo].[SaveStudyBaseResult]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveStudyBaseResult]';


GO
PRINT N'Actualizando Procedimiento [dbo].[BulkInteractionCognitive]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkInteractionCognitive]';


GO
PRINT N'Actualizando Procedimiento [dbo].[BulkAuditorEvaluationPlan]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkAuditorEvaluationPlan]';


GO
PRINT N'Actualizando Procedimiento [dbo].[BulkEvaluationPlanQuery]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkEvaluationPlanQuery]';


GO
PRINT N'Actualizando Procedimiento [dbo].[CleanFailedBatchData]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[CleanFailedBatchData]';


GO
PRINT N'Actualizando Procedimiento [dbo].[DeleteAuditorEvaluationPlan]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteAuditorEvaluationPlan]';


GO
PRINT N'Actualizando Procedimiento [dbo].[DeleteAuditorEvaluationPlanByInteraction]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteAuditorEvaluationPlanByInteraction]';


GO
PRINT N'Actualizando Procedimiento [dbo].[DeleteEvaluationPlanInteractionByTypeAndId]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteEvaluationPlanInteractionByTypeAndId]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetAgentsFromHistoricEvaluationPlans]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAgentsFromHistoricEvaluationPlans]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetAuditorEvaluationPlanEvaluation]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAuditorEvaluationPlanEvaluation]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetAuditorsEvaluationPlan]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAuditorsEvaluationPlan]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetAuditorsFromEvaluationPlans]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAuditorsFromEvaluationPlans]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetAuditorsInteractions]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAuditorsInteractions]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetCampaignFulfillment]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetCampaignFulfillment]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetEvaluationPlans]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlans]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetEvaluationPlansExpired]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlansExpired]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetEvaluationResultsFromAuditorEvaluationPlan]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationResultsFromAuditorEvaluationPlan]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetEvaluationReviewCommitments]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationReviewCommitments]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetEvaluationsOfInteraction]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationsOfInteraction]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetInteractionsByType]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetInteractionsByType]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetInteractionsEvaluationPlanWithoutFilters]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetInteractionsEvaluationPlanWithoutFilters]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetInteractionTypes]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetInteractionTypes]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetTeamPerformanceFilters]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetTeamPerformanceFilters]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetTopAgents]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetTopAgents]';


GO
PRINT N'Actualizando Procedimiento [dbo].[ReportByDetailAgent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[ReportByDetailAgent]';


GO
PRINT N'Actualizando Procedimiento [dbo].[ReportBySummaryAgent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[ReportBySummaryAgent]';


GO
PRINT N'Actualizando Procedimiento [dbo].[RestoreEvaluationResultDraftBackup]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[RestoreEvaluationResultDraftBackup]';


GO
PRINT N'Actualizando Procedimiento [dbo].[SaveAuditorEvPlanResult]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveAuditorEvPlanResult]';


GO
PRINT N'Actualizando Procedimiento [dbo].[SaveEvaluationPlanCompleted]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveEvaluationPlanCompleted]';


GO
PRINT N'Actualizando Procedimiento [dbo].[SaveEvaluationStatus]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveEvaluationStatus]';


GO
PRINT N'Actualizando Procedimiento [dbo].[SaveEvaluationTipificationBaseResult]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveEvaluationTipificationBaseResult]';


GO
PRINT N'Actualizando Procedimiento [dbo].[SaveI6InteractionAsyncInteractionForEvaluationPlan]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveI6InteractionAsyncInteractionForEvaluationPlan]';


GO
PRINT N'Actualizando Procedimiento [dbo].[SaveI6InteractionSyncInteractionForEvaluationPlan]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveI6InteractionSyncInteractionForEvaluationPlan]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetEvaluationReview]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationReview]';


GO
PRINT N'Actualizando Procedimiento [dbo].[BulkTipificationInteraction]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkTipificationInteraction]';


GO
PRINT N'Actualizando Procedimiento [dbo].[SaveI6InteractionAsyncInteraction]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveI6InteractionAsyncInteraction]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetCognitiveInteractionIntents]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetCognitiveInteractionIntents]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetEvaluationPlanByInteractionId]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlanByInteractionId]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetI6InteractionMessages]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetI6InteractionMessages]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetInteractionsEvaluationPlan]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetInteractionsEvaluationPlan]';


GO
PRINT N'Actualizando Procedimiento [dbo].[SaveEvaluationEfectivitySample]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveEvaluationEfectivitySample]';


GO
PRINT N'Actualizando Procedimiento [dbo].[SaveInteractionEvaluationPlan]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveInteractionEvaluationPlan]';


GO
PRINT N'Actualizando Procedimiento [dbo].[SaveInteractionEvaluationPlanSample]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveInteractionEvaluationPlanSample]';


GO
PRINT N'Actualizando Procedimiento [dbo].[BulkProgress]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkProgress]';


GO
PRINT N'Actualizando Procedimiento [dbo].[SaveI6InteractionAudio]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveI6InteractionAudio]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetFiltersFromEvaluation]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetFiltersFromEvaluation]';


GO
PRINT N'Actualización completada.';


GO
