GO
PRINT N'Modificando [dbo].[GetAbilitys]...';


GO
ALTER PROCEDURE [dbo].[GetAbilitys] (
	@Instance VARCHAR(50) = NULL, 
	@SearchCriteria VARCHAR(50) = NULL, 
	@SearchExpression VARCHAR(50) = NULL, 
	@Disabled BIT = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	SELECT A.[ID]								'id',
			A.[Title]							'title',
			A.[Detail]							'detail',
			A.[Type]							'type',
			A.[CalificationType]				'calificationType',
			A.[Binary]							'binary',
			A.[NotApply]						'notApply',
			A.[AcceptComments]					'acceptComments',
			A.[Enabled]							'enabled',
			A.[Query]							'query',
			A.[Queryname]						'queryName',
			N.[Culture]							'culture',
			A.[CreatedDate]						'createdDate',
			A.[CreatedByUserId]					'createdByUserId',
			A.[LastModifiedDate]  				'lastModifiedDate',
			A.[LastModifiedByUserId]			'lastModifiedByUserId'
		FROM Ability a (NOLOCK)
		LEFT JOIN [dbo].[NLU] N (NOLOCK)
			ON N.[VCC] = A.[Instance]
				AND N.[Name] = SUBSTRING(A.[Query], 0, CHARINDEX('|', A.[Query]))
		WHERE a.Instance = @Instance
			AND ISNULL(a.ID, '') LIKE CASE WHEN @SearchCriteria = 'id' THEN '%' + @SearchExpression + '%' ELSE '%' END
			AND ISNULL(a.Title, '') LIKE CASE WHEN @SearchCriteria = 'title' THEN '%' + @SearchExpression + '%' COLLATE Latin1_General_CI_AI ELSE '%' END
			AND ISNULL(a.Detail, '') LIKE CASE WHEN @SearchCriteria = 'detail' THEN '%' + @SearchExpression + '%' COLLATE Latin1_General_CI_AI ELSE '%' END
			AND (ISNULL(@Disabled, 0) = 1 OR (ISNULL(@Disabled, 0) = 0 AND ISNULL(@Disabled, 0) <> [Enabled]))
		ORDER BY a.[Title]

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetEvaluationFormats]...';


GO
ALTER PROCEDURE [dbo].[GetEvaluationFormats] (
	@Instance Varchar(50) = NULL, 
	@SearchCriteria Varchar(50) = NULL, 
	@SearchExpression Varchar(50) = NULL, 
	@Disabled bit = NULL
) AS
BEGIN
	SET NOCOUNT ON;

	-- CREAMOS LAS CTE QUE USAREMOS PARA RECUPERAR LOS MODELOS DE LOS FORMATOS
	WITH CTE_FORMAT_NLUS AS (
		SELECT DISTINCT EF.[Instance]
						, EF.[TemplateId]
						, N.[AppID]
						, N.[Name]
						, N.[Culture]
			FROM [dbo].[EvaluationFormat] EF (NOLOCK)
			INNER JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
				ON AEF.[Instance] = EF.[Instance]
					AND AEF.[IdEvaluationFormat] = EF.[ID]
			INNER JOIN [dbo].[Ability] A (NOLOCK)
				ON A.[Instance] = EF.[Instance]
					AND A.[ID] = AEF.[IdAbility]
			INNER JOIN [dbo].[NLU] N (NOLOCK) 
				ON N.[VCC] = EF.[Instance] 
					AND N.[Name] = SUBSTRING(A.[Query], 0, CHARINDEX('|', A.[Query]))
			WHERE EF.[Instance] = @Instance
				-- EF.[templateId] = 'qty-tmpl-c8d4ba51-be20-4364-a677-76367bd0c694'
				AND A.[QueryName] IS NOT NULL
				AND A.[Query] LIKE '%|%'
	)

	SELECT
		e.ID																	'id',
		e.Description															'description',
		e.EnvironmentType														'environmentType',
		e.Type																	'type',
		e.MinQualificationAcceptable											'minQualificationAcceptable',
		STUFF((
			SELECT ',' + CTN_INNER.[Culture]
				FROM CTE_FORMAT_NLUS CTN_INNER (NOLOCK)
				WHERE CTN_INNER.[TemplateId] = e.[templateId]
		FOR XML PATH(''), TYPE).value('.', 'NVARCHAR(MAX)'), 1, 1, '')			'modelLanguages',
		e.CreatedDate															'createdDate',
		e.CreatedByUserId														'createdByUserId',
		e.LastModifiedDate														'lastModifiedDate',
		e.LastModifiedByUserId													'lastModifiedByUserId',
		e.[Enabled]																'enabled',
		e.[templateId]															'templateId'
	FROM EvaluationFormat e (NOLOCK)
	WHERE e.Instance = @Instance
		AND ISNULL(e.ID, '') LIKE CASE WHEN @SearchCriteria = 'id' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(e.Description, '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' COLLATE Latin1_General_CI_AI ELSE '%' END
		AND (ISNULL(@Disabled, 0) = 1 OR (ISNULL(@Disabled, 0) = 0 AND ISNULL(@Disabled, 0) <> [Enabled]))

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetGroups]...';


GO
ALTER PROCEDURE [dbo].[GetGroups] (
	@Instance Varchar(50) = NULL, @SearchCriteria Varchar(50) = NULL, @SearchExpression Varchar(50) = NULL, @Disabled bit = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	SELECT
		g.ID							'id',
		g.Description					'description',
		g.CreatedDate					'createdDate',
		g.CreatedByUserId				'createdByUserId',
		g.LastModifiedDate				'lastModifiedDate',
		g.LastModifiedByUserId			'lastModifiedByUserId',
		g.[Enabled]						'enabled'
	FROM [Group] g
	WHERE g.Instance = @Instance
		AND ISNULL(g.ID, '') LIKE CASE WHEN @SearchCriteria = 'id' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(g.Description, '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' COLLATE Latin1_General_CI_AI ELSE '%' END
		AND (ISNULL(@Disabled, 0) = 1 OR (ISNULL(@Disabled, 0) = 0 AND ISNULL(@Disabled, 0) <> [Enabled]))
	ORDER BY g.Description ASC

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetSubGroups]...';


GO
ALTER PROCEDURE [dbo].[GetSubGroups] (
	@Instance Varchar(50) = NULL, @SearchCriteria Varchar(50) = NULL, @SearchExpression Varchar(50) = NULL, @Disabled bit = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	SELECT
		s.ID							'id',
		s.Description					'description',
		s.CreatedDate					'createdDate',
		s.CreatedByUserId				'createdByUserId',
		s.LastModifiedDate				'lastModifiedDate',
		s.LastModifiedByUserId			'lastModifiedByUserId',
		s.[Enabled]						'enabled'
	FROM SubGroup s (NOLOCK)
	WHERE s.Instance = @Instance
		AND ISNULL(s.ID, '') LIKE CASE WHEN @SearchCriteria = 'id' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(s.Description, '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' COLLATE Latin1_General_CI_AI ELSE '%' END
		AND (ISNULL(@Disabled, 0) = 1 OR (ISNULL(@Disabled, 0) = 0 AND ISNULL(@Disabled, 0) <> [Enabled]))
	ORDER BY s.Description ASC

	SET NOCOUNT OFF
END
GO
PRINT N'Actualización completada.';


GO
