-- ARCHIVO CON LAS ACTUALIZACIONES DE DATA DE SQL PARA MIGRAR AL NUEVO BUILD DEL NOMBRE DE LA CARPETA
-- DECLARAMOS DOS VARIABLES, UNA CON LA VERSION DE LA QUE PARTIMOS Y OTRA CON LA NUEVA VERSION QUE ESTAMOS APUNTANDO
DECLARE @OLD_DATABASE_BUILD_VERSION VARCHAR(50) = '0.21.0'
DECLARE @NEW_DATABASE_BUILD_VERSION VARCHAR(50) = '0.22.0'

-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
BEGIN TRY
    -- VALIDAMOS QUE LA VERSION EXISTENTE COINCIDE CON NUESTRA NEW_DATABASE_BUILD_VERSION
    IF NOT EXISTS (
        SELECT 1 
            FROM [dbo].[Version] V 
            WHERE V.[BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    )	
        -- LANZAMOS UN MENSAJE DE ERROR INDICANDO QUE LA VERSION ACTUAL NO COINCIDE CON LA OLD_DATABASE_BUILD_VERSION
        RAISERROR('DATABASE_ERROR_INCORRECT_TARGET_VERSION', 16, 16)
        
    -- INICIAMOS LA TRANSACCION
    BEGIN TRANSACTION





    -- AQUI EMPIEZA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION


    -- DECLARAMOS UNA VARIABLE PARA ALMACENAR LOS VCC QUE ACTUALIZAREMOS
    DECLARE RECURRENT_CURSOR CURSOR 
    LOCAL STATIC READ_ONLY FORWARD_ONLY
        FOR 
        -- SELECCIONAMOS LOS VCC EXISTENTES
        SELECT [VCC]
			FROM [dbo].[VCC] (NOLOCK) 

    -- DECLARARAMOS UNA VARIABLE PARA INDICAR EL CAMPO ACTUAL QUE ESTAMOS ACTUALIZANDO
    DECLARE @CURRENT_VCC_TO_UPDATE VARCHAR(50) = ''

    -- ABRIMOS Y RECORREMOS EL ARRAY DE CAMPOS A ACTUALIZAR
    OPEN RECURRENT_CURSOR
    FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_VCC_TO_UPDATE
    WHILE @@FETCH_STATUS = 0
    BEGIN 

        -- EJECUTAMOS EL SCRIPT DE INSERT/UPDATE/DELETE PARA CADA VCC EN LA VARIABLE @CURRENT_VCC_TO_UPDATE

        -- AGREGAMOS LA NUEVA CATEGORIA DE PERMISOS (TODOS LOS PERMISOS SE AGREGARAN AL INIT_DATA AL CIERRE DEL BRANCH)
        INSERT [dbo].[CategoryPermissions] ([VCC], [Category], [Position], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'CATEG_GROUP_DICTIONARY', 20, GETUTCDATE())
            
        -- AGREGAMOS LOS GRUPOS DE PERMISOS CORRESPONDIENTES
        INSERT [dbo].[RolePermissionsGroup] ([VCC], [GroupId], [Category], [TimeStamp], [Type]) VALUES (@CURRENT_VCC_TO_UPDATE, N'PERM_GROUP_DICTIONARY_VIEW', N'CATEG_GROUP_DICTIONARY', GETUTCDATE(), N'SHARED')
        INSERT [dbo].[RolePermissionsGroup] ([VCC], [GroupId], [Category], [TimeStamp], [Type]) VALUES (@CURRENT_VCC_TO_UPDATE, N'PERM_GROUP_WORD_VIEW', N'CATEG_GROUP_DICTIONARY', GETUTCDATE(), N'SHARED')
        INSERT [dbo].[RolePermissionsGroup] ([VCC], [GroupId], [Category], [TimeStamp], [Type]) VALUES (@CURRENT_VCC_TO_UPDATE, N'PERM_GROUP_WORD_ADD', N'CATEG_GROUP_DICTIONARY', GETUTCDATE(), N'SHARED')
        INSERT [dbo].[RolePermissionsGroup] ([VCC], [GroupId], [Category], [TimeStamp], [Type]) VALUES (@CURRENT_VCC_TO_UPDATE, N'PERM_GROUP_WORD_EDIT', N'CATEG_GROUP_DICTIONARY', GETUTCDATE(), N'SHARED')
        INSERT [dbo].[RolePermissionsGroup] ([VCC], [GroupId], [Category], [TimeStamp], [Type]) VALUES (@CURRENT_VCC_TO_UPDATE, N'PERM_GROUP_WORD_DELETE', N'CATEG_GROUP_DICTIONARY', GETUTCDATE(), N'SHARED')
                
        -- AGREGAMOS LAS RELACIONES ROL-PERMISO CORRESPONDIENTES
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'administrator', N'PERM_GROUP_DICTIONARY_VIEW', GETUTCDATE())
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'administrator', N'PERM_GROUP_WORD_VIEW', GETUTCDATE())
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'administrator', N'PERM_GROUP_WORD_ADD', GETUTCDATE())
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'administrator', N'PERM_GROUP_WORD_EDIT', GETUTCDATE())
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'administrator', N'PERM_GROUP_WORD_DELETE', GETUTCDATE())
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'quality_admin', N'PERM_GROUP_DICTIONARY_VIEW', GETUTCDATE())
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'quality_admin', N'PERM_GROUP_WORD_VIEW', GETUTCDATE())
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'quality_admin', N'PERM_GROUP_WORD_ADD', GETUTCDATE())
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'quality_admin', N'PERM_GROUP_WORD_EDIT', GETUTCDATE())
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'quality_admin', N'PERM_GROUP_WORD_DELETE', GETUTCDATE())
        
        -- AGREGAMOS LOS PERMISOS PARA EL NUEVO MODULO
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_DICTIONARY_VIEW', N'speechanalytic/provisioning/dictionary', N'client', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_DICTIONARY_VIEW', N'api/dictionary/get_dictionaries', N'api', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_WORD_VIEW', N'speechanalytic/provisioning/dictionary/view/', N'client', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_WORD_VIEW', N'api/dictionary/get_dictionary', N'api', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_WORD_VIEW', N'api/dictionary/word/get_dictionary_words', N'api', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_WORD_ADD', N'speechanalytic/provisioning/dictionary/word/add/', N'client', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_WORD_ADD', N'api/dictionary/word/create_word', N'api', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_WORD_EDIT', N'speechanalytic/provisioning/dictionary/word/edit/', N'client', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_WORD_EDIT', N'api/dictionary/word/get_dictionary_word', N'api', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_WORD_EDIT', N'api/dictionary/word/save_word', N'api', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_WORD_DELETE', N'api/dictionary/get_dictionary_usage', N'api', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_WORD_DELETE', N'api/dictionary/word/delete_word', N'api', GETUTCDATE())
        
        -- REGISTROS POR DEFECTO PARA DICCIONARIO
		INSERT [dbo].[Dictionary] ([VCC], [Name], [Description], [Language], [IsSystemDictionary], [CreatedDate], [CreatedByUserId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'dictionary-es', N'DICTIONARY_LANGUAGE_ES', N'es', 1, GETUTCDATE(), N'system', GETUTCDATE())
		INSERT [dbo].[Dictionary] ([VCC], [Name], [Description], [Language], [IsSystemDictionary], [CreatedDate], [CreatedByUserId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'dictionary-en', N'DICTIONARY_LANGUAGE_EN', N'en', 1, GETUTCDATE(), N'system', GETUTCDATE())
		INSERT [dbo].[Dictionary] ([VCC], [Name], [Description], [Language], [IsSystemDictionary], [CreatedDate], [CreatedByUserId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'dictionary-pt', N'DICTIONARY_LANGUAGE_PT', N'pt', 1, GETUTCDATE(), N'system', GETUTCDATE())
		INSERT [dbo].[Dictionary] ([VCC], [Name], [Description], [Language], [IsSystemDictionary], [CreatedDate], [CreatedByUserId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'dictionary-fr', N'DICTIONARY_LANGUAGE_FR', N'fr', 1, GETUTCDATE(), N'system', GETUTCDATE())
        
        -- FIN DEL SCRIPT DE INSERT/UPDATE/DELETE PARA CADA VCC EN LA VARIABLE @CURRENT_VCC_TO_UPDATE

        FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_VCC_TO_UPDATE
    END
    CLOSE RECURRENT_CURSOR
    DEALLOCATE RECURRENT_CURSOR
    
    
    --ACTUALIZAR DeleteDataDays A 360 PARA TODOS LOS VCCS
    UPDATE [dbo].[VCC] SET [DeleteDataDays] = 360
    

                                      
    -- AQUI TERMINA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION



    

    -- TERMINAMOS LA ACTUALIZACION DE DATA ACTUALIZANDO EL BUILDVERSION
    UPDATE [dbo].[Version] 
        SET [BuildVersion] = @NEW_DATABASE_BUILD_VERSION, 
            [IsRegistered] = 0,
            [TimeStamp] = GETUTCDATE() 
        WHERE [BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    PRINT 'UPDATED_DATABASE_BUILD_VERSION'

    -- COMPLETAMOS LA TRANSACCION
    COMMIT TRANSACTION
END TRY
BEGIN CATCH
    IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

    DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
    DECLARE @Severity integer = ERROR_SEVERITY()
    DECLARE @State integer = ERROR_STATE()

    RAISERROR(@Message, @Severity, @State)
    --RETURN -1
END CATCH



