PRINT N'Quitando [dbo].[GetAllegroFilterInteractions]...';


GO
DROP PROCEDURE [dbo].[GetAllegroFilterInteractions];


GO
PRINT N'Quitando [dbo].[GetAllegroSummaryInteractions]...';


GO
DROP PROCEDURE [dbo].[GetAllegroSummaryInteractions];


GO
PRINT N'Iniciando recompilación de la tabla [dbo].[User]...';


GO
BEGIN TRANSACTION;

SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;

SET XACT_ABORT ON;

CREATE TABLE [dbo].[tmp_ms_xx_User] (
    [VCC]                  VARCHAR (50)  NOT NULL,
    [ID]                   VARCHAR (50)  NOT NULL,
    [Email]                VARCHAR (100) NULL,
    [Firstname]            VARCHAR (100) NULL,
    [Lastname]             VARCHAR (100) NULL,
    [Password]             VARCHAR (100) NULL,
    [Role]                 VARCHAR (50)  NULL,
    [Country]              VARCHAR (50)  NULL,
    [Language]             VARCHAR (50)  NULL,
    [TimeZone]             VARCHAR (50)  NULL,
    [Preferences]          VARCHAR (200) NULL,
    [IsSystemUser]         BIT           NULL,
    [IsExternalSupervisor] BIT           CONSTRAINT [DF_User_IsExternalSupervisor] DEFAULT ((0)) NULL,
    [IsExternalAgent]      BIT           CONSTRAINT [DF_User_IsExternalAgent] DEFAULT ((0)) NULL,
    [LimitClients]         BIT           NULL,
    [API]                  BIT           NULL,
    [CreatedDate]          DATETIME      NULL,
    [CreatedByUserId]      VARCHAR (50)  NULL,
    [LastModifiedDate]     DATETIME      NULL,
    [LastModifiedByUserId] VARCHAR (50)  NULL,
    [TimeStamp]            DATETIME      NULL,
    CONSTRAINT [tmp_ms_xx_constraint_PK_User1] PRIMARY KEY CLUSTERED ([VCC] ASC, [ID] ASC)
);

IF EXISTS (SELECT TOP 1 1 
           FROM   [dbo].[User])
    BEGIN
        INSERT INTO [dbo].[tmp_ms_xx_User] ([VCC], [ID], [Email], [Firstname], [Lastname], [Password], [Role], [Country], [Language], [TimeZone], [Preferences], [IsSystemUser], [LimitClients], [API], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp])
        SELECT   [VCC],
                 [ID],
                 [Email],
                 [Firstname],
                 [Lastname],
                 [Password],
                 [Role],
                 [Country],
                 [Language],
                 [TimeZone],
                 [Preferences],
                 [IsSystemUser],
                 [LimitClients],
                 [API],
                 [CreatedDate],
                 [CreatedByUserId],
                 [LastModifiedDate],
                 [LastModifiedByUserId],
                 [TimeStamp]
        FROM     [dbo].[User]
        ORDER BY [VCC] ASC, [ID] ASC;
    END

DROP TABLE [dbo].[User];

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_User]', N'User';

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_constraint_PK_User1]', N'PK_User', N'OBJECT';

COMMIT TRANSACTION;

SET TRANSACTION ISOLATION LEVEL READ COMMITTED;


GO
PRINT N'Creando [dbo].[EvaluationReview]...';


GO
CREATE TABLE [dbo].[EvaluationReview] (
    [VCC]                VARCHAR (50)  NOT NULL,
    [Id]                 VARCHAR (50)  NOT NULL,
    [EvaluationPlanId]   VARCHAR (50)  NOT NULL,
    [InteractionId]      VARCHAR (250) NOT NULL,
    [SupervisorId]       VARCHAR (50)  NOT NULL,
    [Review]             VARCHAR (500) NULL,
    [CreatedDate]        DATETIME      NULL,
    [CreatedUserId]      VARCHAR (50)  NULL,
    [LastModifiedDate]   DATETIME      NULL,
    [LastModifiedUserId] VARCHAR (50)  NULL,
    [Timestamp]          DATETIME      NULL
);


GO
PRINT N'Creando [dbo].[EvaluationReviewCommitment]...';


GO
CREATE TABLE [dbo].[EvaluationReviewCommitment] (
    [VCC]                VARCHAR (50)  NOT NULL,
    [EvaluationReviewId] VARCHAR (50)  NOT NULL,
    [LargeInteractionId] VARCHAR (255) NOT NULL,
    [AgentId]            VARCHAR (50)  NOT NULL,
    [Commitment]         VARCHAR (50)  NULL,
    [CreatedDate]        DATETIME      NULL,
    [CreatedUserId]      VARCHAR (50)  NULL,
    [LastModifiedDate]   DATETIME      NULL,
    [LastModifiedUserId] VARCHAR (50)  NULL,
    [Timestamp]          DATETIME      NULL
);


GO
PRINT N'Modificando [dbo].[GetAuditors]...';


GO


ALTER PROCEDURE [dbo].[GetAuditors] (
	@Instance Varchar(50) = NULL, @SearchCriteria Varchar(50) = NULL, @SearchExpression Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON
 	SELECT T.ID								'id',
			U.lastname + ' ' + U.Firstname	'name',
			U.Firstname						'firstname',
			U.lastname						'lastname',
			U.email							'email',
			U.[IsExternalSupervisor]		'isExternalSupervisor',
			U.[IsExternalAgent]				'isExternalAgent',
			T.CreatedDate					'createdDate',
			T.CreatedByUserId				'createdByUserId',
			T.LastModifiedDate				'lastModifiedDate',
			T.LastModifiedByUserId			'lastModifiedByUserId'
		FROM [dbo].[Auditor] T (NOLOCK)
		INNER JOIN [dbo].[User] U (NOLOCK)
			ON U.[VCC] = T.[Instance]
				AND U.[ID] = T.[ID]
		WHERE T.Instance = @Instance
			AND ISNULL(t.ID, '') LIKE CASE WHEN @SearchCriteria = 'id' THEN '%' + @SearchExpression + '%' ELSE '%' END
 	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetAuditorsInteractions]...';


GO
ALTER PROCEDURE [dbo].[GetAuditorsInteractions] (
	@Instance Varchar(50) = NULL, @SearchCriteria Varchar(50) = NULL, @SearchExpression Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

 	SELECT t.ID								'id',
			u.lastname + ' ' + u.Firstname		'name',
			u.Firstname							'firstname',
			u.lastname							'lastname',
			u.email								'email',
			U.[IsExternalSupervisor]			'isExternalSupervisor',
			U.[IsExternalAgent]					'isExternalAgent',
			t.CreatedDate						'createdDate',
			t.CreatedByUserId					'createdByUserId',
			t.LastModifiedDate					'lastModifiedDate',
			t.LastModifiedByUserId				'lastModifiedByUserId',
			count(1) - sum(CASE WHEN a.Completed=0 THEN 0 ELSE 1 END) 'uncompleteInteractions',
			ISNULL(sum(a.InteractionDuration),0)	'interactionTimeSum'
		FROM Auditor t
		FULL JOIN [user] u ON (t.Instance = u.VCC AND t.id = u.ID)
		FULL OUTER JOIN AuditorEvaluationPlan a ON ( t.Instance = a.Instance AND t.ID = a.IdAuditor)
		WHERE t.Instance = @Instance
			AND ISNULL(t.ID, '') LIKE CASE WHEN @SearchCriteria = 'id' THEN '%' + @SearchExpression + '%' ELSE '%' END

			-- SE AGREGA LA VERIFICACION DE QUE EL USER NO SEA NULL PORQUE AL NO EXISTIR EL USUARIO EN LA TABLA USER MUESTRA FILAS CON NULL. SE PRUEBA EN LOS ENDPOINTS: SAVE_USER, DELETE_USER Y EN GET_AUDITORS_INTERACTIONS.
			AND u.[Firstname] IS NOT NULL
			AND u.[LastName] IS NOT NULL
		GROUP BY
			t.ID,
			u.lastname + ' ' + u.Firstname,
			u.Firstname,
			u.lastname,
			u.email,
			U.[IsExternalSupervisor],
			U.[IsExternalAgent],
			t.CreatedDate,
			t.CreatedByUserId,
			t.LastModifiedDate,
			t.LastModifiedByUserId

 	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetUser]...';


GO
ALTER PROCEDURE [dbo].[GetUser] (
	@VCC Varchar(50) = NULL, @UserId Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	SELECT
		[ID]								'id',
		[Email] 							'email',
		[Firstname] 						'firstname',
		[Lastname] 							'lastname',
		[Role] 								'role',
		[Country] 							'country',
		[Language] 							'language',
		[TimeZone] 							'timeZone',
		[Preferences] 						'preferences',
		[IsSystemUser] 						'isSystemUser',
		[IsExternalSupervisor]				'isExternalSupervisor',
		[IsExternalAgent]					'isExternalAgent',
		[LimitClients] 						'limitClients',
		[API]								'api',
		[CreatedDate]						'createdDate',
		[CreatedByUserId]					'createdByUserId',
		[LastModifiedDate]					'lastModifiedDate',
		[LastModifiedByUserId]				'lastModifiedByUserId'
	FROM [User] (NOLOCK)
	WHERE [VCC] = @VCC
	AND [ID] = @UserId
	
	EXEC [GetUserClient] @VCC, @UserId
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[SaveUser]...';


GO
ALTER PROCEDURE [dbo].[SaveUser] (
	@VCC Varchar(50) = NULL, 					@ID Varchar(50) = NULL, 				@Email Varchar(50) = NULL,
	@Firstname Varchar(50) = NULL, 				@Lastname Varchar(50) = NULL, 			@Password Varchar(50) = NULL,
	@Role Varchar(50) = NULL, 					@Country Varchar(50) = NULL, 			@Language Varchar(50) = NULL,
	@TimeZone Varchar(50) = NULL,				@Preferences Varchar(200) = NULL, 		@IsSystemUser Bit = NULL,
	@IsExternalSupervisor BIT = 0,				@IsExternalAgent BIT =0,				@LimitClients Bit = NULL,					
	@CreatedDate Datetime = NULL,				@CreatedByUserId Varchar(50) = NULL,	@LastModifiedDate Datetime = NULL,			
	@LastModifiedByUserId Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	UPDATE [User]
	SET [Email] = @Email,
		[Firstname] = @Firstname,
		[Lastname] = @Lastname,
		[Password] = CASE WHEN @Password IS NULL OR @Password = '' THEN [Password] ELSE @Password END,
		[Role] = @Role,
		[Country] = @Country,
		[Language] = @Language,
		[TimeZone] = @TimeZone,
		[Preferences] = @Preferences,
		[IsSystemUser] = @IsSystemUser,
		[IsExternalSupervisor] = @IsExternalSupervisor,
		[IsExternalAgent] = @IsExternalAgent,
		[LimitClients] = @LimitClients,
		[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
		[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
		[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[TimeStamp] = GETUTCDATE()
	WHERE [VCC] = @VCC
	AND [ID] = @ID
    
    IF @@ROWCOUNT = 0
		INSERT INTO [User] (
			[VCC], [ID], [Email],
			[Firstname], [Lastname], [Password],
			[Role], [Country], [Language],
			[TimeZone], [Preferences], [IsSystemUser],
			[IsExternalSupervisor], [IsExternalAgent], [LimitClients], 
			[CreatedDate], [CreatedByUserId],
			[LastModifiedDate], [LastModifiedByUserId],
			[TimeStamp]
			)
		VALUES (
			@VCC, @ID, @Email,
			@Firstname, @Lastname, @Password,
			@Role, @Country, @Language,
			@TimeZone, @Preferences, @IsSystemUser,
			@IsExternalSupervisor, @IsExternalAgent, @LimitClients, 
			@CreatedDate, @CreatedByUserId,
			@LastModifiedDate, @LastModifiedByUserId,
			GETUTCDATE()
		)
		
    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[BulkProcessInteraction]...';


GO

ALTER PROCEDURE [dbo].[BulkProcessInteraction]
AS
BEGIN
	/*
	-- ACTUALIZAMOS LOS AUDIOS CON EL RESULTADO EN LA TABLA
	UPDATE [dbo].[Audio] SET
		[dbo].[Audio].[Format] = [dbo].[#ProcessInteractionTemp].[Format],
		[dbo].[Audio].[MediaInfoTime] = [dbo].[#ProcessInteractionTemp].[MediaInfoTime],
		[dbo].[Audio].[DurationLinguisticTime] = [dbo].[#ProcessInteractionTemp].[DurationLinguisticTime],
		[dbo].[Audio].[IsDiariced] = [dbo].[#ProcessInteractionTemp].[IsDiariced],
		[dbo].[Audio].[ChannelsChanged] = [dbo].[#ProcessInteractionTemp].[ChannelsChanged],
		[dbo].[Audio].[ValidChar] = ISNULL([dbo].[#ProcessInteractionTemp].[ValidChar], [dbo].[Audio].[ValidChar]),
		[dbo].[Audio].[ValidWords] = ISNULL([dbo].[#ProcessInteractionTemp].[ValidWords], [dbo].[Audio].[ValidWords]),
		[dbo].[Audio].[TotalPhrases] = [dbo].[#ProcessInteractionTemp].[TotalPhrases],
		[dbo].[Audio].[CharsPerPhrase] = [dbo].[#ProcessInteractionTemp].[CharsPerPhrase],
		[dbo].[Audio].[IsTranscribed] = [dbo].[#ProcessInteractionTemp].[IsTranscribed],
		[dbo].[Audio].[IsCancel] = [dbo].[#ProcessInteractionTemp].[IsCancel],
		[dbo].[Audio].[FileName] = [dbo].[#ProcessInteractionTemp].[FileName],
		[dbo].[Audio].[ErrorMessage] = [dbo].[#ProcessInteractionTemp].[ErrorMessage],
		[dbo].[Audio].[LastModifiedDate] = GETUTCDATE()
	FROM [dbo].[#ProcessInteractionTemp]
	WHERE
		[dbo].[Audio].[VCC] = [dbo].[#ProcessInteractionTemp].[VCC]
		AND [dbo].[Audio].[ID] = [dbo].[#ProcessInteractionTemp].[ID]
		AND [dbo].[Audio].[Section] = [dbo].[#ProcessInteractionTemp].[Section]
		AND [dbo].[Audio].[Part] = [dbo].[#ProcessInteractionTemp].[Part]
		AND [dbo].[#ProcessInteractionTemp].[Channel] = 'CALL'
	*/

	-- ACTUALIZAMOS LOS AUDIOS CON EL RESULTADO EN LA TABLA
	UPDATE A
		SET A.[Format] = PIT.[Format],
			A.[MediaInfoTime] = PIT.[MediaInfoTime],
			A.[DurationLinguisticTime] = PIT.[DurationLinguisticTime],
			A.[IsDiariced] = PIT.[IsDiariced],
			A.[ChannelsChanged] = PIT.[ChannelsChanged],
			A.[ValidChar] = ISNULL(PIT.[ValidChar], A.[ValidChar]),
			A.[ValidWords] = ISNULL(PIT.[ValidWords], A.[ValidWords]),
			A.[TotalPhrases] = PIT.[TotalPhrases],
			A.[CharsPerPhrase] = PIT.[CharsPerPhrase],
			A.[IsTranscribed] = PIT.[IsTranscribed],
			A.[IsCancel] = PIT.[IsCancel],
			A.[FileName] = PIT.[FileName],
			A.[ErrorMessage] = PIT.[ErrorMessage],
			A.[LastModifiedDate] = GETUTCDATE()
		FROM [dbo].[Audio] A
		INNER JOIN [dbo].[#ProcessInteractionTemp] PIT
			ON PIT.[VCC] = PIT.[VCC]
				AND A.[ID] = PIT.[ID]
				AND A.[Section] = PIT.[Section]
				AND A.[Part] = PIT.[Part]
		WHERE PIT.[Channel] = 'CALL'

	-- ACTUALIZAMOS LOS TEXT CON EL RESULTADO DE LA TABLA
	UPDATE [dbo].[AsyncInteraction] 
		SET [dbo].[AsyncInteraction].[ValidChar] = ISNULL([dbo].[#ProcessInteractionTemp].[ValidChar], [dbo].[AsyncInteraction].[ValidChar]),
			[dbo].[AsyncInteraction].[ValidWords] = ISNULL([dbo].[#ProcessInteractionTemp].[ValidWords], [dbo].[AsyncInteraction].[ValidWords]),
			[dbo].[AsyncInteraction].[TotalPhrases] = [dbo].[#ProcessInteractionTemp].[TotalPhrases],
			[dbo].[AsyncInteraction].[CharsPerPhrase] = [dbo].[#ProcessInteractionTemp].[CharsPerPhrase],
			[dbo].[AsyncInteraction].[IsTranscribed] = [dbo].[#ProcessInteractionTemp].[IsTranscribed],
			[dbo].[AsyncInteraction].[IsCancel] = [dbo].[#ProcessInteractionTemp].[IsCancel],
			[dbo].[AsyncInteraction].[FileName] = [dbo].[#ProcessInteractionTemp].[FileName],
			[dbo].[AsyncInteraction].[ViewFileName] = [dbo].[#ProcessInteractionTemp].[ViewFileName],
			[dbo].[AsyncInteraction].[ErrorMessage] = [dbo].[#ProcessInteractionTemp].[ErrorMessage],
			[dbo].[AsyncInteraction].[LastModifiedDate] = GETUTCDATE()
	FROM [dbo].[#ProcessInteractionTemp]
	WHERE [dbo].[AsyncInteraction].[VCC] = [dbo].[#ProcessInteractionTemp].[VCC]
		AND [dbo].[AsyncInteraction].[Campaign] = [dbo].[#ProcessInteractionTemp].[Campaign]
		AND [dbo].[AsyncInteraction].[Channel] = [dbo].[#ProcessInteractionTemp].[Channel]
		AND [dbo].[AsyncInteraction].[ID] = [dbo].[#ProcessInteractionTemp].[ID]
		AND [dbo].[AsyncInteraction].[Folder] = [dbo].[#ProcessInteractionTemp].[Folder]

	DROP TABLE [dbo].[#ProcessInteractionTemp]
END
GO
PRINT N'Modificando [dbo].[GetAllegroAgents]...';


GO
ALTER PROCEDURE [dbo].[GetAllegroAgents] (
	@Ip VARCHAR(50), 
	@VCC VARCHAR(50), 
	@Type INT, 
	@Campaigns VARCHAR(MAX) = NULL
) AS
BEGIN
	-- ESTE SP RETORNA LA LISTA DE AGENTES DEL VCC SEGUN LAS CAMPANAS

	-- DECLARAMOS VARIABLES PARA ARMAR LA CONSULTA
	DECLARE @SQL VARCHAR(MAX) = NULL
	DECLARE @TABLE_MMPRODAT VARCHAR(100) = NULL

	-- EL TYPE 0 INDICA QUE LAS TABLAS SE ENCUENTRAN EN UN SERVIDOR EXTERNO
	IF @Type = 0
	BEGIN  
		SET @TABLE_MMPRODAT = '[' + @Ip + ']' + '.[MMProDat].[dbo].'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @TABLE_MMPRODAT = '[MMProDat].[dbo].'
	END

	-- ARMAMOS LA QUERY
	SET @Sql = '
		SET NOCOUNT ON
		SELECT UC.[VCC]							''vcc'',
				UC.[CampaignId]						''campaignId'',
				UC.[UserId]							''userId'',
				U.[Name]							''userName'',
				A.[WorkgroupId]						''workGroupId''
			FROM ' + @TABLE_MMPRODAT + '[Agent]  A (NOLOCK)
			LEFT JOIN ' + @TABLE_MMPRODAT + '[User] U (NOLOCK)
				ON U.[VCC] = A.[VCC]
					AND U.[Id] = A.[UserId]
			LEFT JOIN ' + @TABLE_MMPRODAT + '[UserCampaign] UC (NOLOCK) 
				ON UC.VCC = A.VCC 
					AND UC.UserId = A.UserId
			WHERE UC.[VCC] = ''' + @VCC + ''''

		IF @Campaigns IS NOT NULL AND @Campaigns <> ''
			SET @Sql += 'AND UC.[CampaignId] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '

	SET @Sql += ' 
		SET NOCOUNT OFF'

	-- select @Sql
	EXEC (@Sql)

END
GO
PRINT N'Modificando [dbo].[GetAllegroRole]...';


GO
ALTER PROCEDURE [dbo].[GetAllegroRole]
(
	@IP				VARCHAR(50),
	@VCC			VARCHAR(50),
	@RoleId			VARCHAR(50),
	@Type			INT
)
AS
BEGIN
	DECLARE @SQL VARCHAR(MAX)
	
	IF(@Type = 0)
	BEGIN
		SET @SQL = '
		SELECT TOP 1 [VCC], [Id]
		FROM
			[' + @Ip + ']' + '.mmprodat.dbo.[Group] (NOLOCK)
		WHERE
			[VCC] = ''' + @VCC + '''
			AND [Id] = ''' + @RoleId + '''
		'
	END
	ELSE
	BEGIN
		SET @SQL = '
		SELECT TOP 1 [VCC], [Id]
		FROM
			mmprodat.dbo.[Group] (NOLOCK)
		WHERE
		[VCC] = ''' + @VCC + '''
		AND [Id] = ''' + @RoleId + '''
		'
	END
	EXEC(@SQL)
END
GO
PRINT N'Modificando [dbo].[GetCategoryPermissions]...';


GO
ALTER PROCEDURE [dbo].[GetCategoryPermissions] (
	@VCC Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	SELECT [Category]							'category',
			[Position] 							'position'
		FROM [CategoryPermissions] (NOLOCK)
		GROUP BY [Category],[Position]
		ORDER BY [Position] ASC
	
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetI6AsyncInteractions]...';


GO
-- ESTE SP RETORNA LAS INTERACCIONES ASINCRONAS 
ALTER PROCEDURE [dbo].[GetI6AsyncInteractions]
(
	@VCC					VARCHAR(50) = NULL,
	@IP						VARCHAR(50),						-- IP DEL SERVIDOR PARA LA BASE I6
	@Type					INT,								-- FLAG PARA INDICAR SI EL SERVIDOR I6 SE ENCUENTRA LOCAL O REMOTO
	@InteractionType		VARCHAR(50) = NULL,
	@StartDate				DATETIME = '1980-01-01T00:00:00',
    @EndDate				DATETIME = '2050-01-01T23:59:59',
	@StartHour				VARCHAR(50) = NULL,
	@EndHour				VARCHAR(50) = NULL,
	@Campaigns				VARCHAR(MAX) = NULL,
 	@Agents					VARCHAR(MAX) = NULL,
	@DispositionCodes		VARCHAR(MAX) = NULL,
	@Origins				VARCHAR(MAX) = NULL,
	@InteractionIds         VARCHAR(MAX) = NULL,
    @Evaluated              VARCHAR(MAX) = NULL,
	@UniqueIds				BIT = 0,							-- ESTE FLAG TIENE COMO PROPOSITO RETORNAR LA LISTA CONSOLIDAD POR IDS O EL TOTAL DEL LISTADO
	@ResultType				VARCHAR(50) = NULL					-- VARIABLE PARA DETERMINAR SI LA BUSQUEDA SERA SOBRE SOBRE DETALLES O ID (DETAILED, SUMMARIZED)
    
)
AS
BEGIN
	-- INFO: EN CHAT SE CREAN UN ID EN CADA INTERACCION(EJM: CHATS DE ATENCION EN LAS WEB DE BANCOS), LOS DEMAS CANALES ID + ENDDATE
	
	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NOT NULL AND @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NOT NULL AND @EndHour = '') SET @EndHour = '23:59:59'

	-- DECLARAMOS UNA VARIABLE PARA IDENTIFICAR SI EL SP ES LLAMADO DEL SISTEMA O POR OTRO SP
	DECLARE @IS_NESTED BIT = 0

	-- DECLARAMOASUN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
    DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = '';
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = '';
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = '';
	
	-- DECLARAMOS VARIABLES PARA NOS NOMBRES DE LAS TABLAS
	DECLARE @HISTORICAL_DATA_I6_BD NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_APPSTORE_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_CALL_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_CHAT_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_FACEBOOK_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_GOOGLEPLAY_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_INSTAGRAM_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_MAIL_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_TWITTER_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_WEBCONTACT_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_WHATSAPP_TABLE NVARCHAR(100)
	DECLARE @HISTORICAL_DATA_I6_YOUTUBE_TABLE NVARCHAR(100)

	-- DEFINIMOS EL NOMBRE DE LA BD
	SET @HISTORICAL_DATA_I6_BD = '[HistoricalDataI6_sq]' -- BD PARA DESARROLLO
	-- SET @HISTORICAL_DATA_I6_BD = '[HistoricalDataI6]'

	-- EL PARAMETRO TYPE DEFINE SI LA BD HISTORICALDATAI6 SE ENCUENTRA LOCAL O REMOTO
	IF (@Type = 0)  
	BEGIN  
		SET @HISTORICAL_DATA_I6_APPSTORE_TABLE =		'[' + @Ip + ']' + '.' + @HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Appstore]'
		SET @HISTORICAL_DATA_I6_CHAT_TABLE =			'[' + @Ip + ']' + '.' + @HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Call]'
		SET @HISTORICAL_DATA_I6_CHAT_TABLE =			'[' + @Ip + ']' + '.' + @HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Chat]'
		SET @HISTORICAL_DATA_I6_FACEBOOK_TABLE =		'[' + @Ip + ']' + '.' + @HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Facebook]'
		SET @HISTORICAL_DATA_I6_GOOGLEPLAY_TABLE =		'[' + @Ip + ']' + '.' + @HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Googleplay]'
		SET @HISTORICAL_DATA_I6_INSTAGRAM_TABLE =		'[' + @Ip + ']' + '.' + @HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Instagram]'
		SET @HISTORICAL_DATA_I6_MAIL_TABLE =			'[' + @Ip + ']' + '.' + @HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Mail]'
		SET @HISTORICAL_DATA_I6_TWITTER_TABLE =			'[' + @Ip + ']' + '.' + @HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Twitter]'
		SET @HISTORICAL_DATA_I6_WEBCONTACT_TABLE =		'[' + @Ip + ']' + '.' + @HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Webcontact]'
		SET @HISTORICAL_DATA_I6_WHATSAPP_TABLE =		'[' + @Ip + ']' + '.' + @HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Whatsapp]'
		SET @HISTORICAL_DATA_I6_YOUTUBE_TABLE =			'[' + @Ip + ']' + '.' + @HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Youtube]'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @HISTORICAL_DATA_I6_APPSTORE_TABLE =		@HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Appstore]'
		SET @HISTORICAL_DATA_I6_CHAT_TABLE =			@HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Call]'
		SET @HISTORICAL_DATA_I6_CHAT_TABLE =			@HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Chat]'
		SET @HISTORICAL_DATA_I6_FACEBOOK_TABLE =		@HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Facebook]'
		SET @HISTORICAL_DATA_I6_GOOGLEPLAY_TABLE =		@HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Googleplay]'
		SET @HISTORICAL_DATA_I6_INSTAGRAM_TABLE =		@HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Instagram]'
		SET @HISTORICAL_DATA_I6_MAIL_TABLE =			@HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Mail]'
		SET @HISTORICAL_DATA_I6_TWITTER_TABLE =			@HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Twitter]'
		SET @HISTORICAL_DATA_I6_WEBCONTACT_TABLE =		@HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Webcontact]'
		SET @HISTORICAL_DATA_I6_WHATSAPP_TABLE =		@HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Whatsapp]'
		SET @HISTORICAL_DATA_I6_YOUTUBE_TABLE =			@HISTORICAL_DATA_I6_BD + '.[dbo].[Detail_Youtube]'
	END  

	-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
	SET @SQL_SELECT += '
		SELECT '

	-- ARMAMOS LA PARTE BASE DE FILTROS
	SET @FILTERS_FIXED_PART = ' WHERE HDI6.[Vcc] = ''' + @VCC + ''''
	
	SET @FILTERS_OPTIONAL_PART  =' AND HDI6.[EndDate] BETWEEN '''
    SET @FILTERS_OPTIONAL_PART += (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) 
    SET @FILTERS_OPTIONAL_PART  +=''' AND '''  
    SET @FILTERS_OPTIONAL_PART  +=(SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + ''' '
    

	-- DEPENDIENDO SI LA HORA DE FIN ES MAYOR A LA DE INICIO O NO DAMOS FORMA AL FILTRO DE HORA
	IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(HDI6.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' ';
	IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(HDI6.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' ';
		
	IF (@Campaigns IS NOT NULL AND @Campaigns != '') SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[Campaign] IN (SELECT VALUE FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	
	IF (@DispositionCodes IS NOT NULL AND @DispositionCodes != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND (
								(HDI6.[DispositionTreePath] IN (SELECT VALUE FROM [dbo].[split](''' + @DispositionCodes + ''','',''))) 
								OR
								(HDI6.[DispositionCode] IN (SELECT VALUE FROM [dbo].[split](''' + @DispositionCodes + ''','','')))
							)'

	-- ARMAMOS EL ORDER BY
	SET @SQL_EXTRA += 'ORDER BY [ID], [EndDate] DESC'

	-- ARMAMOS EL SELECT PARA LOS DIFERENTES INTERACTION TYPES
	IF (@InteractionType = 'APPSTORE')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_APPSTORE_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_APPSTORE
		SET @SQL_SELECT += '
								Vcc														''vcc'', 
								ID														''id'', 
								CONVERT(VARCHAR, EndDate, 23)							''folder'',
								ExportedContent											''exportedContent'', 
								''APPSTORE''											''channel'',
								Campaign												''campaign'', 
								StartDate												''startDate'', 
								EndDate													''endDate'', 
								Account													''account'', 
								Initiative												''initiative'',
								SUBSTRING(ContactName, 0, 50)							''contactName'', 
								FirstAgent												''firstTakedAgent'', 
								NULL													''lastTakedAgent'', 
								NULL													''isTaken'',
								ISNULL(TRY_CAST(TotalMessages AS INT), 1)				''totalMessages'',
								CASE WHEN ISNUMERIC(DurationTime) = 0 
									THEN (LEFT(DurationTime, 2 ) * 3600 
											+ SUBSTRING(DurationTime, 4, 2) * 60 
											+ SUBSTRING(DurationTime, 7, 2))
									ELSE DurationTime END									''durationTime'', 
								CASE WHEN ISNUMERIC(AttentionTime) = 0 
									THEN (LEFT(AttentionTime, 2 ) * 3600 
											+ SUBSTRING(AttentionTime, 4, 2) * 60 
											+ SUBSTRING(AttentionTime, 7, 2))
									ELSE AttentionTime END									''attentionTime'', 
								DispositionCode											''dispositionCode'', 
								DispositionTreePath										''dispositionTreePath'',
								RawChar													''rawChar'' '

		-- POR LAS RESTRICCIONES DE SPEECH, FILTRAMOS SOLO INTERACCIONES QUE TENGA ID AGENTE DIFERENTE DE NULL
		SET @FILTERS_FIXED_PART += 'AND HDI6.[FirstAgent] IS NOT NULL '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
		
		-- PARA HACER EL FILTRO POR ORIGEN, REEMPLAZAMOS EN EL INPUT POR LOS VALORES DE LA TABLA
		IF (@Origins IS NOT NULL AND @Origins != '') 
		BEGIN
			SET @Origins = REPLACE(@Origins, 'E', 'INBOUND')
			SET @Origins = REPLACE(@Origins, 'S', 'OUTBOUND')
			SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[Initiative] IN (SELECT VALUE FROM [dbo].[split](''' + @Origins + ''','','')) '
		END
		
	END
	ELSE IF (@InteractionType = 'CALL')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_CALL_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_CHAT
		SET @SQL_SELECT += '
								[Vcc]														''vcc'',
								[Id] + ''_0_0''												''ID'',
								[Id]														''InteractionId'',
								0															''Section'',
								0															''Part'',
								''CALL''													''Channel'',
								[ContactAddress]											''Number'', 
								''''														''Gender'',
								ISNULL([HoldTime], 0)										''SilenceTime'',
								ISNULL([AttentionTime], 0)									''DurationTime'', -- ESTO SE DEBE CORREGIR
								ISNULL([AttentionTime], 0)									''AttentionTime'', -- SE AGREGO CAMPO PARA AMBOS EXISTAN
								[DispositionTreePath]										''Category1'',
								NULL														''Category2'',
								NULL														''Category3'',
								NULL														''Description'',
								[DispositionCode]											''DispositionCode'',
								[Campaign]													''Campaign'',
								[LastAgent]													''Agent'',
								NULL														''agentName'',
								CASE [Initiative] WHEN ''INBOUND'' THEN ''E''
													WHEN ''Inb.'' THEN ''E''
													WHEN ''OUTBOUND'' THEN ''S''
													WHEN ''Out.'' THEN ''S''
													ELSE NULL END							''Type'',
								CONVERT(VARCHAR, [StartDate], 120)							''StartDate'',
								CONVERT(VARCHAR, [EndDate], 120)							''EndDate'',
								''wav''														''Format'' '

		-- POR LAS RESTRICCIONES DE SPEECH, FILTRAMOS SOLO INTERACCIONES QUE TENGA ID AGENTE DIFERENTE DE NULL
		SET @FILTERS_FIXED_PART += '[IsTaken] = 1 '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[LastAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '

		-- PARA HACER EL FILTRO POR ORIGEN, REEMPLAZAMOS EN EL INPUT POR LOS VALORES DE LA TABLA
		IF (@Origins IS NOT NULL AND @Origins != '') 
		BEGIN
			SET @Origins = REPLACE(@Origins, 'E', 'INBOUND')
			SET @Origins = REPLACE(@Origins, 'S', 'OUTBOUND')
			SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[Initiative] IN (SELECT VALUE FROM [dbo].[split](''' + @Origins + ''','','')) '
		END
	END 
	ELSE IF (@InteractionType = 'CHAT')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_CHAT_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_CHAT
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''CHAT''													''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								''IN''														''initiative'', 
								-- ContactName												''contactName'', 
								SUBSTRING(ContactName, 0, 50)								''contactName'', 
								FirstTakeAgent												''firstTakedAgent'', 
								LastTakeAgent												''lastTakedAgent'', 
								IsTaken														''isTaken'',
								ISNULL(TRY_CAST(ChatMessages AS INT), 1)					''totalMessages'',
								CASE WHEN ISNUMERIC(DurationTime) = 0 
									THEN (LEFT(DurationTime, 2 ) * 3600 
											+ SUBSTRING(DurationTime, 4, 2) * 60 
											+ SUBSTRING(DurationTime, 7, 2))
									ELSE DurationTime END									''durationTime'', 
								CASE WHEN ISNUMERIC(AttentionTime) = 0 
									THEN (LEFT(AttentionTime, 2 ) * 3600 
											+ SUBSTRING(AttentionTime, 4, 2) * 60 
											+ SUBSTRING(AttentionTime, 7, 2))
									ELSE AttentionTime END									''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' ,
								RawChar														''rawChar'' '

		-- POR LAS RESTRICCIONES DE SPEECH, FILTRAMOS SOLO INTERACCIONES QUE TENGA ID AGENTE DIFERENTE DE NULL
		SET @FILTERS_FIXED_PART += 'AND (HDI6.[FirstTakeAgent] IS NOT NULL OR HDI6.[LastTakeAgent] IS NOT NULL) '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[LastTakeAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '

		-- PARA HACER EL FILTRO POR ORIGEN DE CHAT, SOLO ES VALIDO CUANDO EL INPUT INCLUYE IN
		IF (@Origins IS NOT NULL AND @Origins != '') SET @FILTERS_OPTIONAL_PART += 'AND ''E'' IN (SELECT VALUE FROM [dbo].[split](''' + @Origins + ''','','')) '
	END 
	ELSE IF (@InteractionType = 'FACEBOOK')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_FACEBOOK_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_FACEBOOK
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''FACEBOOK''												''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								CASE Initiative WHEN ''INBOUND'' THEN ''IN''
									WHEN ''OUTBOUND'' THEN ''OUT''
									ELSE NULL END											''initiative'', 
								SUBSTRING(ContactName, 0, 50)								''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								NULL														''isTaken'',
								ISNULL(TRY_CAST(TotalMessages AS INT), 1)					''totalMessages'',
								CASE WHEN ISNUMERIC(DurationTime) = 0 
									THEN (LEFT(DurationTime, 2 ) * 3600 
											+ SUBSTRING(DurationTime, 4, 2) * 60 
											+ SUBSTRING(DurationTime, 7, 2))
									ELSE DurationTime END									''durationTime'', 
								CASE WHEN ISNUMERIC(AttentionTime) = 0 
									THEN (LEFT(AttentionTime, 2 ) * 3600 
											+ SUBSTRING(AttentionTime, 4, 2) * 60 
											+ SUBSTRING(AttentionTime, 7, 2))
									ELSE AttentionTime END									''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' ,
								RawChar														''rawChar'' '
		
		-- POR LAS RESTRICCIONES DE SPEECH, FILTRAMOS SOLO INTERACCIONES QUE TENGA ID AGENTE DIFERENTE DE NULL
		SET @FILTERS_FIXED_PART += 'AND HDI6.[FirstAgent] IS NOT NULL '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
		
		-- PARA HACER EL FILTRO POR ORIGEN, REEMPLAZAMOS EN EL INPUT POR LOS VALORES DE LA TABLA
		IF (@Origins IS NOT NULL AND @Origins != '') 
		BEGIN
			SET @Origins = REPLACE(@Origins, 'E', 'INBOUND')
			SET @Origins = REPLACE(@Origins, 'S', 'OUTBOUND')
			SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[Initiative] IN (SELECT VALUE FROM [dbo].[split](''' + @Origins + ''','','')) '
		END
	END 
	ELSE IF (@InteractionType = 'GOOGLEPLAY')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_GOOGLEPLAY_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_GOOGLEPLAY
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''GOOGLEPLAY''												''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'',  
								Initiative													''initiative'', 
								SUBSTRING(ContactName, 0, 50)								''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								HasResponse													''isTaken'',
								ISNULL(TRY_CAST(TotalMessages AS INT), 1)					''totalMessages'',
								CASE WHEN ISNUMERIC(DurationTime) = 0 
									THEN (LEFT(DurationTime, 2 ) * 3600 
											+ SUBSTRING(DurationTime, 4, 2) * 60 
											+ SUBSTRING(DurationTime, 7, 2))
									ELSE DurationTime END									''durationTime'', 
								CASE WHEN ISNUMERIC(AttentionTime) = 0 
									THEN (LEFT(AttentionTime, 2 ) * 3600 
											+ SUBSTRING(AttentionTime, 4, 2) * 60 
											+ SUBSTRING(AttentionTime, 7, 2))
									ELSE AttentionTime END									''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' ,
								RawChar														''rawChar'' '

		-- POR LAS RESTRICCIONES DE SPEECH, FILTRAMOS SOLO INTERACCIONES QUE TENGA ID AGENTE DIFERENTE DE NULL
		SET @FILTERS_FIXED_PART += 'AND HDI6.[FirstAgent] IS NOT NULL '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '

		-- PARA HACER EL FILTRO POR ORIGEN, REEMPLAZAMOS EN EL INPUT POR LOS VALORES DE LA TABLA
		IF (@Origins IS NOT NULL AND @Origins != '') 
		BEGIN
			SET @Origins = REPLACE(@Origins, 'E', 'INBOUND')
			SET @Origins = REPLACE(@Origins, 'S', 'OUTBOUND')
			SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[Initiative] IN (SELECT VALUE FROM [dbo].[split](''' + @Origins + ''','','')) '
		END
	END
	ELSE IF (@InteractionType = 'INSTAGRAM')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_INSTAGRAM_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_INSTAGRAM
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''INSTAGRAM''												''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								CASE Initiative WHEN ''INBOUND'' THEN ''IN''
									WHEN ''OUTBOUND'' THEN ''OUT''
									ELSE NULL END											''initiative'', 
								SUBSTRING(ContactName, 0, 50)								''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								HasResponse													''isTaken'',
								ISNULL(TRY_CAST(TotalMessages AS INT), 1)					''totalMessages'',
								CASE WHEN ISNUMERIC(DurationTime) = 0 
									THEN (LEFT(DurationTime, 2 ) * 3600 
											+ SUBSTRING(DurationTime, 4, 2) * 60 
											+ SUBSTRING(DurationTime, 7, 2))
									ELSE DurationTime END									''durationTime'', 
								CASE WHEN ISNUMERIC(AttentionTime) = 0 
									THEN (LEFT(AttentionTime, 2 ) * 3600 
											+ SUBSTRING(AttentionTime, 4, 2) * 60 
											+ SUBSTRING(AttentionTime, 7, 2))
									ELSE AttentionTime END									''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' ,
								RawChar														''rawChar'' '

		-- POR LAS RESTRICCIONES DE SPEECH, FILTRAMOS SOLO INTERACCIONES QUE TENGA ID AGENTE DIFERENTE DE NULL
		SET @FILTERS_FIXED_PART += 'AND HDI6.[FirstAgent] IS NOT NULL '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '

		-- PARA HACER EL FILTRO POR ORIGEN, REEMPLAZAMOS EN EL INPUT POR LOS VALORES DE LA TABLA
		IF (@Origins IS NOT NULL AND @Origins != '') 
		BEGIN
			SET @Origins = REPLACE(@Origins, 'E', 'INBOUND')
			SET @Origins = REPLACE(@Origins, 'S', 'OUTBOUND')
			SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[Initiative] IN (SELECT VALUE FROM [dbo].[split](''' + @Origins + ''','','')) '
		END
	END  
	ELSE IF (@InteractionType = 'MAIL')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_MAIL_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_MAIL
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''MAIL''													''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								CASE Initiative WHEN ''INBOUND'' THEN ''IN''
									WHEN ''OUTBOUND'' THEN ''OUT''
									ELSE NULL END											''initiative'', 
								SUBSTRING(ContactName, 0, 50)								''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								MailHasResponse												''isTaken'',
								ISNULL(TRY_CAST(MailTotalMessages AS INT), 1)				''totalMessages'',
								CASE WHEN ISNUMERIC(DurationTime) = 0 
									THEN (LEFT(DurationTime, 2 ) * 3600 
											+ SUBSTRING(DurationTime, 4, 2) * 60 
											+ SUBSTRING(DurationTime, 7, 2))
									ELSE DurationTime END									''durationTime'', 
								CASE WHEN ISNUMERIC(AttentionTime) = 0 
									THEN (LEFT(AttentionTime, 2 ) * 3600 
											+ SUBSTRING(AttentionTime, 4, 2) * 60 
											+ SUBSTRING(AttentionTime, 7, 2))
									ELSE AttentionTime END									''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' ,
								RawChar														''rawChar'' '
								
		-- POR LAS RESTRICCIONES DE SPEECH, FILTRAMOS SOLO INTERACCIONES QUE TENGA ID AGENTE DIFERENTE DE NULL
		SET @FILTERS_FIXED_PART += 'AND HDI6.[FirstAgent] IS NOT NULL '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '

		-- PARA HACER EL FILTRO POR ORIGEN, REEMPLAZAMOS EN EL INPUT POR LOS VALORES DE LA TABLA
		IF (@Origins IS NOT NULL AND @Origins != '') 
		BEGIN
			SET @Origins = REPLACE(@Origins, 'E', 'INBOUND')
			SET @Origins = REPLACE(@Origins, 'S', 'OUTBOUND')
			SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[Initiative] IN (SELECT VALUE FROM [dbo].[split](''' + @Origins + ''','','')) '
		END
	END  
	ELSE IF (@InteractionType = 'TWITTER')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_TWITTER_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_TWITTER
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''TWITTER''													''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								CASE Initiative WHEN ''INBOUND'' THEN ''IN''
									WHEN ''OUTBOUND'' THEN ''OUT''
									ELSE NULL END											''initiative'', 
								SUBSTRING(ContactName, 0, 50)								''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								HasResponse													''isTaken'',
								ISNULL(TRY_CAST(TotalMessages AS INT), 1)					''totalMessages'',
								CASE WHEN ISNUMERIC(DurationTime) = 0 
									THEN (LEFT(DurationTime, 2 ) * 3600 
											+ SUBSTRING(DurationTime, 4, 2) * 60 
											+ SUBSTRING(DurationTime, 7, 2))
									ELSE DurationTime END									''durationTime'', 
								CASE WHEN ISNUMERIC(AttentionTime) = 0 
									THEN (LEFT(AttentionTime, 2 ) * 3600 
											+ SUBSTRING(AttentionTime, 4, 2) * 60 
											+ SUBSTRING(AttentionTime, 7, 2))
									ELSE AttentionTime END									''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' ,
								RawChar														''rawChar'' '
								
		-- POR LAS RESTRICCIONES DE SPEECH, FILTRAMOS SOLO INTERACCIONES QUE TENGA ID AGENTE DIFERENTE DE NULL
		SET @FILTERS_FIXED_PART += 'AND HDI6.[FirstAgent] IS NOT NULL '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '

		-- PARA HACER EL FILTRO POR ORIGEN, REEMPLAZAMOS EN EL INPUT POR LOS VALORES DE LA TABLA
		IF (@Origins IS NOT NULL AND @Origins != '') 
		BEGIN
			SET @Origins = REPLACE(@Origins, 'E', 'INBOUND')
			SET @Origins = REPLACE(@Origins, 'S', 'OUTBOUND')
			SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[Initiative] IN (SELECT VALUE FROM [dbo].[split](''' + @Origins + ''','','')) '
		END
	END  
	ELSE IF (@InteractionType = 'WEBCONTACT')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_WEBCONTACT_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_WEBCONTACT
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''WEBCONTACT''												''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								''IN''														''initiative'', 
								SUBSTRING(ContactName, 0, 50)								''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								HasResponse													''isTaken'',
								ISNULL(TRY_CAST(TotalResponses AS INT), 1)					''totalMessages'',
								CASE WHEN ISNUMERIC(DurationTime) = 0 
									THEN (LEFT(DurationTime, 2 ) * 3600 
											+ SUBSTRING(DurationTime, 4, 2) * 60 
											+ SUBSTRING(DurationTime, 7, 2))
									ELSE DurationTime END									''durationTime'', 
								CASE WHEN ISNUMERIC(AttentionTime) = 0 
									THEN (LEFT(AttentionTime, 2 ) * 3600 
											+ SUBSTRING(AttentionTime, 4, 2) * 60 
											+ SUBSTRING(AttentionTime, 7, 2))
									ELSE AttentionTime END									''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' ,
								RawChar														''rawChar'' '

		-- POR LAS RESTRICCIONES DE SPEECH, FILTRAMOS SOLO INTERACCIONES QUE TENGA ID AGENTE DIFERENTE DE NULL
		SET @FILTERS_FIXED_PART += 'AND HDI6.[FirstAgent] IS NOT NULL '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '

		-- PARA HACER EL FILTRO POR ORIGEN DE WEBCONTACT, SOLO ES VALIDO CUANDO EL INPUT INCLUYE IN
		IF (@Origins IS NOT NULL AND @Origins != '') SET @FILTERS_OPTIONAL_PART += 'AND ''E'' IN (SELECT VALUE FROM [dbo].[split](''' + @Origins + ''','','')) '
	END
	ELSE IF (@InteractionType = 'WHATSAPP')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_WHATSAPP_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_WHATSAPP
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''WHATSAPP''												''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								CASE Initiative WHEN ''In.'' THEN ''IN''
									WHEN ''Out.'' THEN ''OUT''
									ELSE NULL END											''initiative'', 
								SUBSTRING(ContactName, 0, 50)								''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								HasResponse													''isTaken'',
								ISNULL(TRY_CAST(WhatsappTotalMessages AS INT), 1)			''totalMessages'',
								CASE WHEN ISNUMERIC(DurationTime) = 0 
									THEN (LEFT(DurationTime, 2 ) * 3600 
											+ SUBSTRING(DurationTime, 4, 2) * 60 
											+ SUBSTRING(DurationTime, 7, 2))
									ELSE DurationTime END									''durationTime'', 
								CASE WHEN ISNUMERIC(AttentionTime) = 0 
									THEN (LEFT(AttentionTime, 2 ) * 3600 
											+ SUBSTRING(AttentionTime, 4, 2) * 60 
											+ SUBSTRING(AttentionTime, 7, 2))
									ELSE AttentionTime END									''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' ,
								RawChar															''rawChar'' '
								
		-- POR LAS RESTRICCIONES DE SPEECH, FILTRAMOS SOLO INTERACCIONES QUE TENGA ID AGENTE DIFERENTE DE NULL
		SET @FILTERS_FIXED_PART += 'AND HDI6.[FirstAgent] IS NOT NULL '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '
		
		-- PARA HACER EL FILTRO POR ORIGEN, REEMPLAZAMOS EN EL INPUT POR LOS VALORES DE LA TABLA
		IF (@Origins IS NOT NULL AND @Origins != '') 
		BEGIN
			SET @Origins = REPLACE(@Origins, 'E', 'INBOUND')
			SET @Origins = REPLACE(@Origins, 'S', 'OUTBOUND')
			SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[Initiative] IN (SELECT VALUE FROM [dbo].[split](''' + @Origins + ''','','')) '
		END
	END  
	ELSE IF (@InteractionType = 'YOUTUBE')
	BEGIN
		-- SETTEAMOS LA TABLA DE BUSQUEDA
		SET @HISTORICAL_DATA_I6_TABLE = @HISTORICAL_DATA_I6_YOUTUBE_TABLE

		-- ARMAMOS EL SELECT A LA TABLA DETAIL_YOUTUBE
		SET @SQL_SELECT += '
								Vcc															''vcc'', 
								ID															''id'', 
								CONVERT(VARCHAR, EndDate, 23)								''folder'',
								ExportedContent												''exportedContent'', 
								''YOUTUBE''													''channel'',
								Campaign													''campaign'', 
								StartDate													''startDate'', 
								EndDate														''endDate'', 
								Account														''account'', 
								CASE Initiative WHEN ''INBOUND'' THEN ''IN''
									WHEN ''OUTBOUND'' THEN ''OUT''
									ELSE NULL END											''initiative'', 
								SUBSTRING(ContactName, 0, 50)								''contactName'', 
								FirstAgent													''firstTakedAgent'', 
								NULL														''lastTakedAgent'', 
								HasResponse													''isTaken'',
								ISNULL(TRY_CAST(TotalMessages AS INT), 1)					''totalMessages'',
								CASE WHEN ISNUMERIC(DurationTime) = 0 
									THEN (LEFT(DurationTime, 2 ) * 3600 
											+ SUBSTRING(DurationTime, 4, 2) * 60 
											+ SUBSTRING(DurationTime, 7, 2))
									ELSE DurationTime END									''durationTime'', 
								CASE WHEN ISNUMERIC(AttentionTime) = 0 
									THEN (LEFT(AttentionTime, 2 ) * 3600 
											+ SUBSTRING(AttentionTime, 4, 2) * 60 
											+ SUBSTRING(AttentionTime, 7, 2))
									ELSE AttentionTime END									''attentionTime'', 
								DispositionCode												''dispositionCode'', 
								DispositionTreePath											''dispositionTreePath'' ,
								RawChar														''rawChar'' '
								
		-- POR LAS RESTRICCIONES DE SPEECH, FILTRAMOS SOLO INTERACCIONES QUE TENGA ID AGENTE DIFERENTE DE NULL
		SET @FILTERS_FIXED_PART += 'AND HDI6.[FirstAgent] IS NOT NULL '

		IF (@Agents IS NOT NULL AND @Agents != '') SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[FirstAgent] IN (SELECT VALUE FROM [dbo].[split](''' + @Agents + ''','','')) '

		-- PARA HACER EL FILTRO POR ORIGEN, REEMPLAZAMOS EN EL INPUT POR LOS VALORES DE LA TABLA
		IF (@Origins IS NOT NULL AND @Origins != '') 
		BEGIN
			SET @Origins = REPLACE(@Origins, 'E', 'INBOUND')
			SET @Origins = REPLACE(@Origins, 'S', 'OUTBOUND')
			SET @FILTERS_OPTIONAL_PART += 'AND HDI6.[Initiative] IN (SELECT VALUE FROM [dbo].[split](''' + @Origins + ''','','')) '
		END
	END

    IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
    BEGIN
        SET @FILTERS_OPTIONAL_PART = '';
	    SET @FILTERS_EXCLUDING_PART=' AND ID IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) ';
    END
		  
	-- AGREGAMOS EL CONTADOR DE FILAR AL SELECT
	SET @SQL_SELECT += '
								,RN = ROW_NUMBER() OVER(PARTITION BY [ID], CONVERT(VARCHAR, EndDate, 23) ORDER BY [EndDate] DESC) '

	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM ' + @HISTORICAL_DATA_I6_TABLE + ' HDI6 (NOLOCK) '

	-- UNIMOS LAS PARTES DEL QUERY
	SET @SQL_SELECT += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA

	-- VERIFICAMOS SI EXISTE LA TABLA TEMPORAL #TMP_HD_INTERACTIONS
	IF OBJECT_ID('TEMPDB..#TMP_HD_INTERACTIONS') IS NULL
	BEGIN
		-- CREAMOS UNA TABLA TEMPORAL PARA INSERTAR LOS REGISTROS DE LA HDI6
		CREATE TABLE #TMP_HD_INTERACTIONS
		(
			vcc VARCHAR(50), 
			id VARCHAR(250),  
			folder VARCHAR(50),
			exportedContent VARCHAR(250),  
			channel VARCHAR(50), 
			campaign VARCHAR(50), 
			startDate DATETIME,
			endDate DATETIME,
			account VARCHAR(50), 
			initiative VARCHAR(50), 
			contactName VARCHAR(250), 
			firstTakedAgent VARCHAR(50), 
			lastTakedAgent VARCHAR(50), 
			isTaken VARCHAR(50), 
			totalMessages INT,
			durationTime VARCHAR(50),  
			attentionTime VARCHAR(50), 
			dispositionCode VARCHAR(250), 
			dispositionTreePath VARCHAR(250), 
			rawChar INT,
			RN INT
		)

		-- REAFIRMAMOS QUE EL SP NO ESTA ANIDADO EN OTRO
		SET @IS_NESTED = 0

		-- PRINT 'SP NO ANIDADO'
	END
	ELSE
	BEGIN
		-- SI LA TABLA TEMPORAL YA EXISTIA, EL SP ESTA ANIDADO EN OTRO (P.E.: [dbo].[GetAsyncBillingInteractions])
		SET @IS_NESTED = 1

		-- PRINT 'SP ANIDADO'
	END 

	-- INSERTAMOS EL RESULTADO EN LA TABLA TEMPORAL
	INSERT INTO #TMP_HD_INTERACTIONS
		-- EJECUTAMOS LA CONSULTA
		EXEC (@SQL_SELECT)
   
    
    -- VARIABLES PARA TRABAJAR CON LA TABLA TEMPORAL AL FINAL DEL SP
    DECLARE @QUERY                  VARCHAR(MAX) = ''
    DECLARE @QUERY_FILTER           VARCHAR(MAX) = ''
    DECLARE @QUERY_JOIN             VARCHAR(MAX) = ''
	
	-- FILTRO POR INTERACCIONES EVALUADAS O NO
	IF (@Evaluated IS NOT NULL AND @Evaluated <> '')
	    BEGIN 
		DECLARE @EvaluatedTable TABLE (Val BIT)

		INSERT INTO @EvaluatedTable SELECT Value FROM [dbo].[split]( @Evaluated ,',')

		-- SOLAMENTE SI ES SI O NO
		IF ((SELECT COUNT(Val) FROM @EvaluatedTable) = 1 )
		BEGIN
			IF((SELECT Val FROM @EvaluatedTable WHERE Val = 1) IS NOT NULL) -- Si  es Si
			BEGIN 
				SET @QUERY_JOIN = ' JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) ON (AEP.[IdInteraction] = HDI.[id] AND AEP.[Completed]=1 ) '
			END
		ELSE  --Si es No
           BEGIN
               SET @QUERY_JOIN = ' LEFT JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) ON (AEP.[IdInteraction] = HDI.[id] AND AEP.[Completed]=1 ) '
               SET @QUERY_FILTER = ' AND AEP.[IdInteraction] IS NULL '
           END
       END
       
	 END
	-- FIN FILTRO INTERACCIONES EVALUADAS


	

	-- SI EL SP NO ESTA ANIDADO, HACEMOS SELECT AL RESULTADO A MOSTRAR
	IF @IS_NESTED = 0
	BEGIN
		-- HACEMOS EL SELECT SEGUN EL TIPO DE BUSQUEDA SETTEADO
		-- IF @UniqueIds = 1 -- ENFOCADO A INTERACCIONES
		-- BEGIN
			IF @ResultType = 'SUMMARIZED'
			BEGIN
				SET @QUERY = '
					SELECT HDI.[channel]										AS ''interactionType'',
							COUNT(DISTINCT (
								CASE WHEN '''+@InteractionType+''' = ''CALL'' 
								THEN HDI.[id] 
								ELSE HDI.[id] 
								-- ELSE CONCAT(HDI.[id], HDI.[endDate]) 
								END))											AS ''interactions'',
							COUNT(*)											AS ''details'',
							SUM(HDI.[rawChar])									AS ''rawChars''
						FROM #TMP_HD_INTERACTIONS HDI '
				SET @QUERY += @QUERY_JOIN
				SET @QUERY += ' WHERE HDI.[RN] = 1 ' + @QUERY_FILTER + ' GROUP BY HDI.[channel]'
				
			END
			/*
			ELSE IF @ResultType = 'DETAILED'
			BEGIN
				SET @QUERY = '
					SELECT HDI.[vcc]											AS ''vcc'',
							HDI.[channel]										AS ''interactionType'',
							HDI.[campaign]										AS ''campaign'',
							HDI.[id]											AS ''id'',
							HDI.[firstTakedAgent]								AS ''agent'',
							HDI.[initiative]									AS ''origin'',
							SUM(HDI.[rawChar])									AS ''rawChar''
						FROM #TMP_HD_INTERACTIONS HDI '
				SET @QUERY += @QUERY_JOIN
				
				SET @QUERY += ' WHERE HDI.[RN] = 1 ' + @QUERY_FILTER + '
					GROUP BY HDI.[vcc], HDI.[channel], HDI.[campaign], HDI.[id], HDI.[firstTakedAgent], HDI.[initiative]'
			END
			--EJECUTAR CONSULTA
			EXEC (@QUERY)
			
		END
		ELSE -- ENFOCADO A DETALLES
		BEGIN
			IF @ResultType = 'SUMMARIZED'
			BEGIN
			SET @QUERY = '
				SELECT HDI.[channel]											AS ''interactionType'',
						COUNT(DISTINCT (
							CASE WHEN '''+@InteractionType +'''= ''CALL'' 
							THEN HDI.[id] 
							ELSE CONCAT(HDI.[id], HDI.[endDate]) 
							END))												AS ''interactions'',
						COUNT(*)												AS ''details'',
						SUM(HDI.[rawChar])										AS ''rawChar''
					FROM #TMP_HD_INTERACTIONS HDI '
			SET @QUERY += @QUERY_JOIN
					
			SET @QUERY += '	WHERE HDI.[RN] = 1 ' + @QUERY_FILTER + ' GROUP BY HDI.[channel] '
			
			END
			*/
			ELSE IF @ResultType = 'DETAILED'
			BEGIN
			    SET @QUERY = ' SELECT HDI.* FROM #TMP_HD_INTERACTIONS HDI ' + @QUERY_JOIN +  ' WHERE HDI.[RN] = 1 ' + @QUERY_FILTER
			END 
			-- EJECUTAR CONSULTA
			EXEC (@QUERY)
		-- END
	END


	/*
	-- DECLARAMOS LAS CTE
	WITH CTE_AVAILABLE_BALANCE_REPORT AS (
		SELECT * FROM #TMP_HD_INTERACTIONS
	)
	select * from CTE_AVAILABLE_BALANCE_REPORT 
	*/
END
GO
PRINT N'Modificando [dbo].[ReportByDetailAgent]...';


GO


ALTER PROCEDURE [dbo].[ReportByDetailAgent] (
	@VCC varchar(50) = NULL, 
	@HistoricCampaign varchar(MAX) = NULL , 
	@Plan varchar(MAX) = NULL,
	@Format varchar(MAX), 
	@StartDate DateTime = NULL , 
	@EndDate DateTime = NULL , 
	@IdAuditor varchar(MAX) = NULL ,
	@IdAgente varchar(MAX) = NULL
) AS
  DECLARE @cols varchar(max) 
  DECLARE @query varchar(max)
  
  -- ReportByDetailAgent 'allegro','entrantes','Plan_2_nov01-0356','nov01-0356','20191001','20191201','isidoro','icagente3'
  SET NOCOUNT ON

  SELECT
    * INTO #TempEvaluationResult
  FROM (
	SELECT EP.[Instance]														'VCC',
			EP.Description														AS 'DescriptionPlan',
			EF.Description														AS 'DescriptionFormat',
			(
				GP.Description
				+ '-' 
				+ SGP.Description
				+ '-' 
				+ A.Title
			)																	AS 'Ability', --Collate SQL_Latin1_General_CP1253_CI_AI
			ER.AgentDescription,
			ER.CampaignDescription,
			ER.IdInteraction,
			ISNULL(ER.Qualification, 0)											AS 'Qualification',
			AEP.[AutomaticScore],
			AEP.[ManualScore],
			--Format(ER.EvaluationDate, 'dd/MM/yyyy hh:mm:ss')					AS 'EvaluationDate',
			--CAST(Format(AEP.[TimeStamp], 'yyyy-MM-dd hh:mm:ss') AS DATETIME)					AS 'EvaluationDate',
			AEP.[TimeStamp] AS 'EvaluationDate',
			ER.IdAuditor,
			EP.Evaluation_Mode	
		FROM EvaluationResult (NOLOCK) ER
		INNER JOIN HistoricEvaluationFormat EF
			ON EF.[VCC] = ER.[Instance]
				AND ER.IdEvaluationFormat = EF.ID 
				AND ER.IdEvaluationPlan = EF.EvaluationPlanId
		INNER JOIN HistoricAbility (NOLOCK) A
			ON A.[VCC] = ER.[Instance]
				AND ER.IdEvaluationPlan = A.EvaluationPlanId
				AND A.ID = ER.IdAbility 
		INNER JOIN EvaluationPlan (NOLOCK) EP
			ON EP.[Instance] = ER.[Instance]
				AND EP.ID = ER.IdEvaluationPlan
		INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			ON AEP.[Instance] = ER.[Instance]
				AND AEP.[IdEvaluationPlan] =  ER.[IdEvaluationPlan]
				AND AEP.[IdInteraction] = ER.[IdInteraction]
				AND AEP.[IdAuditor] =  ER.[IdAuditor]
		LEFT JOIN [HistoricGroup] (NOLOCK) GP
			ON GP.[VCC] = ER.[Instance]
				AND GP.EvaluationPlanId = EP.ID
				AND GP.ID = ER.IdGroup 
		LEFT JOIN HistoricSubGroup (NOLOCK) SGP
			ON SGP.[VCC] = ER.[Instance]
				AND SGP.EvaluationPlanId = EP.ID
				AND SGP.ID = ER.IdSubGroup 
		WHERE ER.Instance LIKE CASE WHEN @VCC IS NOT NULL THEN @VCC ELSE ER.Instance END
			AND EF.Description IN(SELECT [Value] FROM [dbo].[Split](IIF(@Format IS NULL,EF.Description,@Format),','))
			AND EP.Description IN(SELECT [Value] FROM [dbo].[Split](IIF(@Plan IS NULL,EP.Description,@Plan),','))
			AND ER.CampaignDescription IN(SELECT [Value] FROM [dbo].[Split](IIF(@HistoricCampaign IS NULL,ER.CampaignDescription,@HistoricCampaign),','))
			AND ER.AgentDescription IN(SELECT [Value] FROM [dbo].[Split](IIF(@IdAgente IS NULL,ER.AgentDescription,@IdAgente),','))
			AND ER.IdAuditor IN(SELECT [Value] FROM [dbo].[Split](IIF(@IdAuditor IS NULL,ER.IdAuditor,@IdAuditor),','))
			AND AEP.[TimeStamp] >=
                          CASE
                            WHEN @StartDate IS NOT NULL THEN @StartDate
                            ELSE '19800101'
                          END
			AND AEP.[TimeStamp] <
                         CASE
                           WHEN @EndDate IS NOT NULL THEN @EndDate + ' 23:59'
                           ELSE '20500101'
                         END
		  --AND EP.[Status] = 7
		  AND AEP.[Completed] = 1
		  AND AEP.StatusDescription NOT IN('INVALID')
	) a

	--select * from #TempEvaluationResult ORDER BY IdInteraction


  SET @cols = STUFF((SELECT DISTINCT
    ',' + QUOTENAME(Ability) 
  FROM #TempEvaluationResult
  FOR xml PATH (''), TYPE)
  .value('.', 'varchar(Max)')
  , 1, 1, '')

  --Select @cols
  IF @cols IS NOT NULL
  BEGIN

    DECLARE @type varchar(max)=(Select Top 1 Evaluation_Mode From #TempEvaluationResult)

    DECLARE @Total varchar(max) = STUFF((SELECT DISTINCT
      '+ ISNULL(' + QUOTENAME(Ability) + ',0)'
    FROM #TempEvaluationResult
    FOR xml PATH (''), TYPE)
    .value('.', 'varchar(Max)')
    , 1, 1, '')
    --SELECT @type
	If @type = 'M'
	BEGIN
    SET @query = ' 
				Select p.[VCC]							AS [VCC],
						p.DescriptionPlan				As [EVALUATION_PLAN],
						p.DescriptionFormat				As [EVALUATION_FORMAT],
						p.AgentDescription				As [AGENT],
  						p.CampaignDescription			As [CAMPAIGN],
						p.IdInteraction					As [INTERACTION],
						p.EvaluationDate				As [EVALUATION_DATE],
						p.IdAuditor						As [AUDITOR],
						InteractionDuration				as [DURATION_TIME], 
						null							As [PHONE],
						InteractionDateStart			As [START_DATE],
						null							As [CATEGORY],
						(' + @Total + ')				As COLUMN_TOTAL_SCORE, 
						p.[AutomaticScore]				AS COLUMN_AUTOMATIC_SCORE,
						p.[ManualScore]					AS COLUMN_MANUAL_SCORE,
						' + @cols + ' 
					from 
				( select VCC,
							DescriptionPlan,
						  DescriptionFormat,
						  Ability,
						  AgentDescription,
						  CampaignDescription,
						  IdInteraction,
						  EvaluationDate,
						  Qualification,
						  AutomaticScore,
						  ManualScore,
						  IdAuditor			
					from #TempEvaluationResult
			   ) x
				pivot 
				( 
					 max(Qualification)
					for Ability in (' + @cols + ')
				) p 
				Left Join (
				Select Distinct IdInteraction,InteractionDuration,InteractionDateStart From InteractionEvaluationPlan (Nolock) 
				) as A On
				A.IdInteraction = p.IdInteraction '
    END
	ELSE 
	BEGIN
    SET @query = ' 
				Select p.[VCC]							AS [VCC],
						p.DescriptionPlan				As [EVALUATION_PLAN],
						p.DescriptionFormat				As [EVALUATION_FORMAT],
						p.AgentDescription				As [AGENT],
  						p.CampaignDescription			As [CAMPAIGN] ,
						p.IdInteraction					As [INTERACTION] ,
						p.EvaluationDate				As [EVALUATION_DATE],
						p.IdAuditor						As [AUDITOR],
						A.DurationTime					as [DURATION_TIME],
						A.Number						As [PHONE] ,
						A.StartDate						As [START_DATE] ,
						A.Category1						As [CATEGORY] ,
						(' + @Total + ')				As COLUMN_TOTAL_SCORE,
						p.[AutomaticScore]				AS COLUMN_AUTOMATIC_SCORE,
						p.[ManualScore]					AS COLUMN_MANUAL_SCORE,
						' + @cols + ' 
					from ( 
						select VCC,
								DescriptionPlan,
								DescriptionFormat,
								Ability,
								AgentDescription,
								CampaignDescription,
								IdInteraction,
								EvaluationDate,
								Qualification,
								AutomaticScore,
								ManualScore,
								IdAuditor			
							from #TempEvaluationResult
					) x pivot 
					( 
						 max(Qualification)
						for Ability in (' + @cols + ')
					) p 
					LEFT Join Audio as A 
						On A.[VCC] = p.[VCC]
							AND A.ID = p.IdInteraction'
	END
	--Print(@query)
    EXECUTE (@query)
    DROP TABLE #TempEvaluationResult
  END
  ELSE
  BEGIN
    SELECT
						''				As [EVALUATION_PLAN],
						''				As [EVALUATION_FORMAT],
						''				As [AGENT],
  						''			    As [CAMPAIGN] ,
						''			 	As [INTERACTION] ,
						''				As [EVALUATION_DATE],
						''				As [AUDITOR]
  END
  
  SET NOCOUNT OFF
GO
PRINT N'Modificando [dbo].[SaveEvaluationFormat]...';


GO

ALTER PROCEDURE [dbo].[SaveEvaluationFormat] (
	@Instance Varchar(50) = NULL, 						
	@ID Varchar(50) = NULL,
	@Description Varchar(50) = NULL,
	@Type Varchar(50) = NULL,
	@EnvironmentType VARCHAR(50) = NULL,
	@CreatedDate Datetime = NULL,						
	@CreatedByUserId Varchar(50) = NULL,		
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL,			
	@MinQualificationAcceptable numeric(5,2),	
	@MinAutomaticQualification NUMERIC(5, 2),
	@ManagementFormURL varchar(1000) = NULL,
	@Enabled bit = NULL, 
	@templateId Varchar(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- Danny Jhonston:
	-- Inicio:
	-- Validar si el formato tiene al menos un plan asignado.
	-- Validar si el formato tiene un plan de evaluacion que tiene evaluaciones pendientes.

	-- DECLARE @ID VARCHAR(50)
	-- SET @ID = '183fedb7-9dbf-4b1c-8efd-b1164f33c8ba'

	-- Tabla temporal para almacenar resultado de consulta.
	DECLARE @EvaluationsData TABLE (
		[ID]						VARCHAR(50),
		[totalEvaluations]			INT,
		[completedEvaluations]		INT
	)
	INSERT INTO @EvaluationsData
	SELECT
		EP.[ID]									'id',
		COUNT(AEP.[IdInteraction])				'totalEvaluations',
		SUM(CAST(AEP.[Completed] AS INT))		'completedEvaluations'
	FROM
		[dbo].[EvaluationPlan] EP
		INNER JOIN [dbo].[AuditorEvaluationPlan] AEP ON EP.[ID] = AEP.[IdEvaluationPlan]
	WHERE
		EP.[Instance] = @Instance
		AND EP.[IdEvaluationFormat] = @ID
	GROUP BY EP.[ID]

	-- Contiene las evaluaciones de un formato.
	DECLARE @TotalEvaluations INT
	SET @TotalEvaluations = (SELECT COUNT([ID]) FROM @EvaluationsData WHERE (CAST([completedEvaluations] AS NUMERIC(18, 2)) / CAST([totalEvaluations] AS NUMERIC(18, 2))) * 100 > 0)
	-- SET @TotalEvaluations = (SELECT COUNT([ID]) FROM @EvaluationsData WHERE [totalEvaluations] > [completedEvaluations])

	--PRINT @TotalEvaluations
	IF(@TotalEvaluations > 0)
	BEGIN
		BEGIN
			-- Tiene evaluaciones asociadas que en al menos se esta evaluando un plan de evaluacion.
			SELECT CAST(-1 AS INT) 'idEvaluationFormat'
			PRINT @@ROWCOUNT
		END
	END
	ELSE
	-- Danny Jhonston:
	-- Fin:
	BEGIN
		-- No tiene evaluaciones asociadas.
		-- Debe continuar con el guardado.

		UPDATE [EvaluationFormat] SET
			[Description] = @Description,
			[Type] = @Type,
			[EnvironmentType] = @EnvironmentType,
			[MinQualificationAcceptable] = @MinQualificationAcceptable,
			[MinAutomaticQualification] = @MinAutomaticQualification,
			[ManagementFormURL] = @ManagementFormURL,
			[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
			[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
			[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
			[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
			[Enabled] = CASE WHEN @Enabled IS NULL THEN 1 ELSE @Enabled END,
			[TimeStamp] = GETUTCDATE(),
			[templateId] = @templateId
		WHERE [Instance] = @Instance
		AND [ID] = @ID

		

		IF @@ROWCOUNT = 0
			INSERT INTO [EvaluationFormat] (
				[Instance],[ID], [Description], [Type], 
				[EnvironmentType], [MinQualificationAcceptable], [MinAutomaticQualification], [ManagementFormURL],
				[CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId],
				[Enabled], [TimeStamp], [templateId]
				)
			VALUES (
				@Instance, @ID, @Description, @Type, 
				@EnvironmentType, @MinQualificationAcceptable, @MinAutomaticQualification, @ManagementFormURL,
				@CreatedDate, @CreatedByUserId, @LastModifiedDate, @LastModifiedByUserId,
				@Enabled, GETUTCDATE(), @templateId
			)

		SELECT CAST(Scope_Identity() AS INT) as 'idEvaluationFormat';
	END

	

    SET NOCOUNT OFF
END
GO
PRINT N'Creando [dbo].[GetAllegroSupervisor]...';


GO
CREATE PROCEDURE [dbo].[GetAllegroSupervisor]
(
	@IP				VARCHAR(50),
	@VCC			VARCHAR(50),
	@UserId			VARCHAR(50),
	@Type			BIT
)
AS
BEGIN
	-- ESTE SP RETORNA LA LISTA DE SUPERVISORES DE UN VCC DE TIPO ALLEGRO/OCC CON SUS WORKGROUPS DE AGENTES
	
	-- DECLARAMOS VARIABLES PARA ARMAR LA CONSULTA
	DECLARE @VCC_TYPE VARCHAR(25) = NULL
	DECLARE @SQL VARCHAR(MAX) = NULL
	DECLARE @TABLE_MMPRODAT VARCHAR(100) = NULL

	-- INDETIFICAMOS EL TIPO DE VCC
	SELECT @VCC_TYPE = V.[Type] 
		FROM [dbo].[VCC] V (NOLOCK) 
		WHERE V.[VCC] = @VCC

	-- EL TYPE 0 INDICA QUE LAS TABLAS SE ENCUENTRAN EN UN SERVIDOR EXTERNO
	IF @Type = 0
	BEGIN  
		SET @TABLE_MMPRODAT = '[' + @Ip + ']' + '.[MMProDat].[dbo].'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @TABLE_MMPRODAT = '[MMProDat].[dbo].'
	END
	
	--
	IF @VCC_TYPE = 'ALLEGRO'
	BEGIN
		-- ARMAMOS LA CONSULTA PRINCIPAL
		SET @SQL = '
			SELECT DISTINCT U.[VCC]					''vcc'',
							U.[Id]					''userId''
				FROM ' + @TABLE_MMPRODAT + '[SupervisorWorkgroup] SWG (NOLOCK)
				INNER JOIN ' + @TABLE_MMPRODAT + '[User] U (NOLOCK)
					ON U.[VCC] = SWG.[VCC]
						AND U.[Id] = SWG.[SupervisorId]
				WHERE SWG.[VCC] = ''' + @VCC + ''' '
	END
	ELSE IF @VCC_TYPE = 'OCC'
	BEGIN
		SET @SQL = '
			SELECT DISTINCT U.[VCC]					''vcc'',
							U.[Id]					''userId''
				FROM ' + @TABLE_MMPRODAT + '[User] U (NOLOCK) 
				INNER JOIN ' + @TABLE_MMPRODAT + '[GroupApplication] GA (NOLOCK)
					ON GA.[VCC] = U.[VCC]
						AND GA.[GroupId] = U.[UserGroup] 
				LEFT JOIN ' + @TABLE_MMPRODAT + '[UserCampaign] UC (NOLOCK) 
					ON UC.[VCC] = UC.[VCC]
						AND UC.[UserId] = U.[Id]
				LEFT JOIN ' + @TABLE_MMPRODAT + '[SupervisorWorkgroup] SW (NOLOCK)
					ON SW.[VCC] = U.[VCC]
						AND SW.[SupervisorId] = U.[Id]
						AND SW.[CampaignId] = UC.[CampaignId]
				WHERE GA.[VCC] = ''' + @VCC + '''
					AND GA.[ApplicationId] = ''supervisor''
				ORDER BY U.[Id] ASC, UC.[CampaignId] ASC 
		'
	END
	
	-- EJECUTAMOS LA CONSULTA
	EXEC(@SQL)
END
GO
PRINT N'Creando [dbo].[GetAllegroSupervisors]...';


GO
CREATE PROCEDURE [dbo].[GetAllegroSupervisors]
(
	@IP				VARCHAR(50),
	@VCC			VARCHAR(50),
	@Type			BIT
)
AS
BEGIN
	-- ESTE SP RETORNA LA LISTA DE SUPERVISORES DE UN VCC DE TIPO ALLEGRO/OCC CON SUS WORKGROUPS DE AGENTES

	-- DECLARAMOS VARIABLES PARA ARMAR LA CONSULTA
	DECLARE @VCC_TYPE VARCHAR(25) = NULL
	DECLARE @SQL VARCHAR(MAX) = NULL
	DECLARE @TABLE_MMPRODAT VARCHAR(100) = NULL

	-- INDETIFICAMOS EL TIPO DE VCC
	SELECT @VCC_TYPE = V.[Type] 
		FROM [dbo].[VCC] V (NOLOCK) 
		WHERE V.[VCC] = @VCC

	-- EL TYPE 0 INDICA QUE LAS TABLAS SE ENCUENTRAN EN UN SERVIDOR EXTERNO
	IF @Type = 0
	BEGIN  
		SET @TABLE_MMPRODAT = '[' + @Ip + ']' + '.[MMProDat].[dbo].'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @TABLE_MMPRODAT = '[MMProDat].[dbo].'
	END
	
	--
	IF @VCC_TYPE = 'ALLEGRO'
	BEGIN
		-- ARMAMOS LA CONSULTA PRINCIPAL
		SET @SQL = '
			SELECT U.[VCC]					''vcc'',
					U.[Id]					''userId'',
					U.[Name]				''userName'',
					SWG.[CampaignId]		''campaignId'',
					SWG.[WorkgroupId]		''workGroupId''
				FROM ' + @TABLE_MMPRODAT + '[SupervisorWorkgroup] SWG (NOLOCK)
				INNER JOIN ' + @TABLE_MMPRODAT + '[User] U (NOLOCK)
					ON U.[VCC] = SWG.[VCC]
						AND U.[Id] = SWG.[SupervisorId]
				WHERE SWG.[VCC] = ''' + @VCC + ''' '
	END
	ELSE IF @VCC_TYPE = 'OCC'
	BEGIN
		SET @SQL = '
			SELECT U.[VCC]					''vcc'',
					U.[Id]					''userId'',
					U.[Name]				''userName'',
					--U.[UserGroup],
					UC.[CampaignId]			''campaignId'',
					SW.[WorkgroupId]		''workGroupId''
				FROM ' + @TABLE_MMPRODAT + '[User] U (NOLOCK) 
				INNER JOIN ' + @TABLE_MMPRODAT + '[GroupApplication] GA (NOLOCK)
					ON GA.[VCC] = U.[VCC]
						AND GA.[GroupId] = U.[UserGroup] 
				LEFT JOIN ' + @TABLE_MMPRODAT + '[UserCampaign] UC (NOLOCK) 
					ON UC.[VCC] = UC.[VCC]
						AND UC.[UserId] = U.[Id]
				LEFT JOIN ' + @TABLE_MMPRODAT + '[SupervisorWorkgroup] SW (NOLOCK)
					ON SW.[VCC] = U.[VCC]
						AND SW.[SupervisorId] = U.[Id]
						AND SW.[CampaignId] = UC.[CampaignId]
				WHERE GA.[VCC] = ''' + @VCC + '''
					AND GA.[ApplicationId] = ''supervisor''
				ORDER BY U.[Id] ASC, UC.[CampaignId] ASC 
		'
	END
	
	-- EJECUTAMOS LA CONSULTA
	EXEC(@SQL)
END
GO
PRINT N'Creando [dbo].[GetEvaluationReview]...';


GO
CREATE PROCEDURE [dbo].[GetEvaluationReview] (
	@VCC Varchar(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(50) = NULL,
	@SupervisorId VARCHAR(50) = NULL,
	@AgentId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON
	
	-- SELECCIONAMOS LOS CAMPOS DE LA TABLA EVALUATION-REVIEW
	SELECT ER.[VCC]													'vcc',
			ER.[Id]													'id',
			ER.[EvaluationPlanId]									'evaluationPlanId',
			ER.[InteractionId]										'interactionId',
			ER.[SupervisorId]										'supervisorId',
			ER.[Review]												'review'
		FROM [dbo].[EvaluationReview] ER (NOLOCK) 
		WHERE ER.[VCC] = @VCC
			AND ER.[EvaluationPlanId] = @EvaluationPlanId
			AND ER.[InteractionId] = @InteractionId
			AND ER.[SupervisorId] = ISNULL(@SupervisorId, ER.[SupervisorId])

	-- SELECCIONAMOS LOS CAMPOS DE LA TABLA EVALUATION-REVIEW-COMMITMENT
	SELECT ERC.[LargeInteractionId]									'largeInteractionId',
			ERC.[AgentId]											'agentId',
			ERC.[Commitment]										'commitment'
		FROM [dbo].[EvaluationReviewCommitment] ERC (NOLOCK) 
		INNER JOIN [dbo].[EvaluationReview] ER (NOLOCK)
			ON ER.[VCC] = ERC.[VCC]
				AND ER.[Id] = ERC.[EvaluationReviewId]
		WHERE ER.[VCC] = @VCC
			AND ER.[EvaluationPlanId] = @EvaluationPlanId
			AND ER.[InteractionId] = @InteractionId
			AND ER.[SupervisorId] = ISNULL(@SupervisorId, ER.[SupervisorId])
			AND ERC.[AgentId] = ISNULL(@AgentId, ERC.[AgentId])
	
	SET NOCOUNT OFF
END
GO
PRINT N'Creando [dbo].[GetRoleCategories]...';


GO
CREATE PROCEDURE [dbo].[GetRoleCategories] (
	@VCC VARCHAR(50), 
	@RoleId VARCHAR(50) = NULL,
	@License Varchar(50) = NULL
) AS
BEGIN
	-- ESTE SP RETORNA LAS CATEGORIAS RELACIONADAS A UN USUARIO
	
	SELECT RPG.[Category]					'categoryId'
		FROM [dbo].[RolePermission] RP (NOLOCK)
		INNER JOIN [dbo].[RolePermissionsGroup] RPG (NOLOCK)
			ON RPG.[VCC] = RP.[VCC]
				AND RPG.[GroupId] = RP.[GroupId]
		WHERE RP.[VCC] = @VCC
			AND RP.[RoleId] = CASE WHEN ISNULL(@RoleId, '') = '' THEN rp.[RoleId] ELSE @RoleId END
			AND (@License IS NULL OR RPG.[Type] IN (@License, 'SHARED'))
		GROUP BY RP.[VCC], RPG.[Category] 
		ORDER BY RPG.[Category] ASC
	
END
GO
PRINT N'Creando [dbo].[SaveEvaluationReview]...';


GO
CREATE PROCEDURE [dbo].[SaveEvaluationReview] (
	@VCC VARCHAR(50) = NULL, 
	@EvaluationReviewId VARCHAR(50) = NULL,
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(50) = NULL,
	@SupervisorId VARCHAR(50) = NULL,
	@Review VARCHAR(500) = NULL,
	@SaveUserId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- ACTUALIZAMOS EL REGISTRO CORRESPONDIENTE A LA REVISION
	UPDATE [dbo].[EvaluationReview]
		SET [Review] = @Review,
			[LastModifiedDate] = GETUTCDATE(),
			[LastModifiedUserId] = @SaveUserId,
			[Timestamp] = GETUTCDATE()
		WHERE [VCC] = @VCC
			AND [EvaluationPlanId] = @EvaluationPlanId
			AND [InteractionId] = @InteractionId
			AND [SupervisorId] = @SupervisorId

	-- SI NO SE ACTUALIZO NINGUN REGISTRO, LO INSERTAMOS
	IF @@ROWCOUNT = 0
	BEGIN
		-- 
		INSERT INTO [dbo].[EvaluationReview] (
				[VCC],
				[Id],
				[EvaluationPlanId],
				[InteractionId],
				[SupervisorId],
				[Review],
				[CreatedDate],
				[CreatedUserId],
				[Timestamp]
			) VALUES (
				@VCC,
				@EvaluationReviewId,
				@EvaluationPlanId,
				@InteractionId,
				@SupervisorId,
				@Review,
				GETUTCDATE(),
				@SaveUserId,
				GETUTCDATE()
			)
	END

	-- RETORNAMOS EL REGISTRO INSERTADO/ACTUALIZADO
    SELECT ER.[VCC]													'vcc',
			ER.[Id]													'id',
			ER.[EvaluationPlanId]									'evaluationPlanId',
			ER.[InteractionId]										'interactionId',
			ER.[SupervisorId]										'supervisorId',
			ER.[Review]												'review'
		FROM [dbo].[EvaluationReview] ER (NOLOCK) 
		WHERE ER.[VCC] = @VCC
			AND ER.[EvaluationPlanId] = @EvaluationPlanId
			AND ER.[InteractionId] = @InteractionId
			AND ER.[SupervisorId] = ISNULL(@SupervisorId, ER.[SupervisorId])
	
	SET NOCOUNT OFF
END
GO
PRINT N'Creando [dbo].[SaveEvaluationReviewCommitment]...';


GO
create PROCEDURE [dbo].[SaveEvaluationReviewCommitment] (
	@VCC VARCHAR(50) = NULL, 
	@EvaluationReviewId VARCHAR(50) = NULL,
	@LargeInteractionId VARCHAR(255) = NULL,
	@AgentId VARCHAR(50) = NULL,
	@Commitment VARCHAR(500) = NULL,
	@SaveUserId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- ACTUALIZAMOS EL REGISTRO CORRESPONDIENTE A LA REVISION
	UPDATE [dbo].[EvaluationReviewCommitment]
		SET [Commitment] = @Commitment,
			[LastModifiedDate] = GETUTCDATE(),
			[LastModifiedUserId] = @SaveUserId,
			[Timestamp] = GETUTCDATE()
		WHERE [VCC] = @VCC
			AND [EvaluationReviewId] = @EvaluationReviewId
			AND [LargeInteractionId] = @LargeInteractionId
			AND [AgentId] = @AgentId

	-- SI NO SE ACTUALIZO NINGUN REGISTRO, LO INSERTAMOS
	IF @@ROWCOUNT = 0
	BEGIN
		-- 
		INSERT INTO [dbo].[EvaluationReviewCommitment] (
				[VCC],
				[EvaluationReviewId],
				[LargeInteractionId],
				[AgentId],
				[Commitment],
				[CreatedDate],
				[CreatedUserId],
				[Timestamp]
			) VALUES (
				@VCC,
				@EvaluationReviewId,
				@LargeInteractionId,
				@AgentId,
				@Commitment,
				GETUTCDATE(),
				@SaveUserId,
				GETUTCDATE()
			)
	END

	-- 
    SELECT 1 AS 'result'
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetRole]...';


GO
--exec [GetRole] 'bpo', NULL
ALTER PROCEDURE [dbo].[GetRole] (
	@VCC Varchar(50) = NULL, @RoleId Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON
	DECLARE @CountLicense INT, @License VARCHAR(50)
	

	SET @CountLicense = (SELECT COUNT(*) FROM VCCLicense (NOLOCK) WHERE [VCC] =@VCC AND [Status] = 1 )	

	SELECT
		[ID]							'id',
		[Description]					'description',
		[CreatedDate]					'createdDate',
		[CreatedByUserId]				'createdByUserId',
		[LastModifiedDate]				'lastModifiedDate',
		[LastModifiedByUserId]			'lastModifiedByUserId',
		[SystemRole]					'systemRole'
	FROM [Role] (NOLOCK)
	WHERE [VCC] = @VCC
	AND [ID] = CASE WHEN ISNULL(@RoleId, '') = '' THEN [ID] ELSE @RoleId END

	IF(@CountLicense>1)
	BEGIN
		EXEC [GetRolePermission] @VCC, @RoleId
		EXEC [GetRoleRoutePermission] @VCC, @RoleId
		EXEC [GetRoleSinglePermission] @VCC, @RoleId
		EXEC [dbo].[GetRoleCategories] @VCC, @RoleId
	END
	IF(@CountLicense=1)
	BEGIN
		SET @License = (SELECT Product FROM VCCLicense (NOLOCK) WHERE [VCC] =@VCC AND [Status] = 1)
		EXEC [GetRolePermission] @VCC, @RoleId, @License 
		EXEC [GetRoleRoutePermission] @VCC, @RoleId, @License
		EXEC [GetRoleSinglePermission] @VCC, @RoleId, @License
		EXEC [dbo].[GetRoleCategories] @VCC, @RoleId
	END
	IF(@CountLicense<1)
	BEGIN
		EXEC [GetRolePermission] 'empty', @RoleId
		EXEC [GetRoleRoutePermission] 'empty', @RoleId
		EXEC [GetRoleSinglePermission] 'empty', @RoleId
		EXEC [dbo].[GetRoleCategories] 'empty', @RoleId
	END

	
	
	SET NOCOUNT OFF
END
GO
PRINT N'Actualizando [dbo].[DeleteUser]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteUser]';


GO
PRINT N'Actualizando [dbo].[GetAgentsFromEvaluation]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAgentsFromEvaluation]';


GO
PRINT N'Actualizando [dbo].[GetCampaignsFromEvaluation]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetCampaignsFromEvaluation]';


GO
PRINT N'Actualizando [dbo].[GetDispositionCodesFromEvaluation]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetDispositionCodesFromEvaluation]';


GO
PRINT N'Actualizando [dbo].[GetEvaluationPlansAuditor]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlansAuditor]';


GO
PRINT N'Actualizando [dbo].[GetEvaluationResultsFromAuditorEvaluationPlan]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationResultsFromAuditorEvaluationPlan]';


GO
PRINT N'Actualizando [dbo].[GetEvaluationsOfInteraction]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationsOfInteraction]';


GO
PRINT N'Actualizando [dbo].[GetUsers]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetUsers]';


GO
PRINT N'Actualizando [dbo].[RollbackVcc]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[RollbackVcc]';


GO
PRINT N'Actualizando [dbo].[SaveIntegratedUser]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveIntegratedUser]';


GO
PRINT N'Actualizando [dbo].[SaveSpeechAnalyticAuditorUser]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveSpeechAnalyticAuditorUser]';


GO
PRINT N'Actualizando [dbo].[ValidateUserLogin]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[ValidateUserLogin]';


GO
PRINT N'Actualizando [dbo].[CreateVcc]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[CreateVcc]';


GO
PRINT N'Actualizando [dbo].[SaveVcc]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveVcc]';


GO
PRINT N'Actualizando [dbo].[GetAsyncBillingInteractions]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAsyncBillingInteractions]';


GO
PRINT N'Actualización completada.';


GO
