
PRINT N'Creating Table [dbo].[SentimentAnalysisResult]...';


GO
CREATE TABLE [dbo].[SentimentAnalysisResult] (
    [VCC]                  VARCHAR (50)    NOT NULL,
    [InteractionId]        VARCHAR (250)   NOT NULL,
    [InteractionSection]   NUMERIC (5)     NOT NULL,
    [InteractionPart]      NUMERIC (5)     NOT NULL,
    [InteractionType]      VARCHAR (50)    NOT NULL,
    [InteractionInterval]  NUMERIC (5)     NOT NULL,
    [AnalysisType]         VARCHAR (50)    NOT NULL,
    [SentimentId]          VARCHAR (50)    NOT NULL,
    [AppId]                VARCHAR (50)    NOT NULL,
    [Score]                NUMERIC (10, 5) NULL,
    [CreatedDate]          DATETIME        NULL,
    [CreatedByUserId]      VARCHAR (50)    NULL,
    [LastModifiedDate]     DATETIME        NULL,
    [LastModifiedByUserId] VARCHAR (50)    NULL,
    [TimeStamp]            DATETIME        NULL,
    PRIMARY KEY CLUSTERED ([VCC] ASC, [InteractionId] ASC, [InteractionSection] ASC, [InteractionPart] ASC, [InteractionType] ASC, [InteractionInterval] ASC, [AnalysisType] ASC, [SentimentId] ASC, [AppId] ASC)
);


GO
PRINT N'Altering Procedure [dbo].[CreateVcc]...';


GO
ALTER PROCEDURE [dbo].[CreateVcc] (
	@VCC Varchar(50) = NULL, 
	@ID Varchar(50) = NULL,
	@Description Varchar(50) = NULL,
	@Type VARCHAR(50) = NULL,
	@TranscriptionDefaultLanguage VARCHAR(25) = NULL,
	@CognitiveEngine VARCHAR(25) = NULL,
	@Country Varchar(50) = NULL,
	@Language Varchar(50) = NULL,
	@TimeZone Varchar(50) = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId   VARCHAR(50) = NULL,
	@DeleteDataDays         INT = 360
	)
AS
BEGIN
	SET NOCOUNT ON
	BEGIN TRY
    BEGIN TRANSACTION


	INSERT INTO [dbo].[VCC] (
			[VCC], 
			[ID], 
			[Description], 
			[Type], 
			[Country], 
			[TranscriptionDefaultLanguage], 
			[CognitiveEngine], 
			[Language],
			[TimeZone], 
			[CreatedDate], 
			[CreatedByUserId], 
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[DeleteDataDays], 
			[TimeStamp]
			)
	VALUES (
			@VCC, 
			@ID, 
			@Description, 
			@Type, 
			@Country, 
			@TranscriptionDefaultLanguage, 
			@CognitiveEngine, 
			@Language, 
			@TimeZone, 
			@CreatedDate,  
			@CreatedByUserId, 
			@LastModifiedDate, 
			@LastModifiedByUserId, 
			@DeleteDataDays,
			GETUTCDATE()
		)
	
	DECLARE @VCC_SYSTEM       VARCHAR(50) = 'system'

    --INSERTAR ROLES
	
	DECLARE @ROLES TABLE(
    [ID]            VARCHAR(50),
    [Description]   VARCHAR(50),
	[CreatedDate]   DATETIME,
    [CreatedByUserId] VARCHAR(50),
    [LastModifiedDate] DATETIME,
    [LastModifiedByUserId] VARCHAR(50),
	[SystemRole]    BIT,
    [Type]                 VARCHAR(50)
	)
	INSERT INTO @ROLES EXEC [dbo].[GetRoles] @VCC_SYSTEM,'name',''

	IF(EXISTS(SELECT [ID] FROM @ROLES))
	BEGIN
			INSERT INTO [dbo].[Role] (
					[VCC],
					[ID], 
					[Description],
					[CreatedDate], 
					[CreatedByUserId], 
					[LastModifiedDate],
					[LastModifiedByUserId],
					[SystemRole],
					[Type],
					[TimeStamp]
					)
			SELECT @VCC,
				   [ID],
				   [Description],
				   GETUTCDATE(), 
				   [CreatedByUserId],
				   GETUTCDATE(),
				   [LastModifiedByUserId],
				   [SystemRole],
				   [Type],
				   GETUTCDATE()
			FROM @ROLES
     END
	 ELSE
	 BEGIN
	       RAISERROR('SERVER_ERROR_ROLES_NOT_FOUND', 16, 16)
	 END

	--INSERTAR PERMISOS PARA LOS ROLES

	DECLARE @CountLicense INT = 0
	DECLARE @License      VARCHAR(50)
	
	DECLARE @ROLE_PERMISSIONS TABLE(
	 [ID]      VARCHAR(50),
	 [GroupId] VARCHAR(200)
	)
	DECLARE @ROUTE_PERMISSIONS TABLE(
	 [ID]      VARCHAR(50),
	 [Route]   VARCHAR(250),
	 [Level]   VARCHAR(50),
	 [GroupId] VARCHAR(200)
	)

	SET @CountLicense = (SELECT COUNT(*) FROM [dbo].[VCCLicense] (NOLOCK) WHERE [VCC] = @VCC AND [Status] = 1)
	
	IF(@CountLicense>1)
	BEGIN
	    INSERT INTO @ROLE_PERMISSIONS EXEC [dbo].[GetRolePermission] @VCC_SYSTEM,''
		INSERT INTO @ROUTE_PERMISSIONS EXEC [dbo].[GetRoleRoutePermission] @VCC_SYSTEM
	END

	IF(@CountLicense=1)
	BEGIN
	    SET @License = (SELECT Product FROM [dbo].[VCCLicense] (NOLOCK) WHERE [VCC] = @VCC AND [Status] = 1)
	    INSERT INTO @ROLE_PERMISSIONS EXEC [dbo].[GetRolePermission] @VCC_SYSTEM,'', @License
		INSERT INTO @ROUTE_PERMISSIONS EXEC [dbo].[GetRoleRoutePermission] @VCC_SYSTEM,'', @License
	END
	
	INSERT INTO [dbo].[RolePermission] (
			    [VCC], 
				[RoleId], 
				[GroupId],
			    [TimeStamp]
			    ) 
				SELECT 
				@VCC,
				[ID],
				[GroupId],
			    GETUTCDATE()
				FROM @ROLE_PERMISSIONS

	INSERT INTO [dbo].[RoutePermission] (
			[VCC], 
			[ID], 
			[GroupId],
			[Route], 
			[Level], 
			[TimeStamp]
			)
			SELECT 
			@VCC,
			[ID],
			[GroupId],
			[Route],
			[Level],
			GETUTCDATE()
			FROM @ROUTE_PERMISSIONS


    --INSERTAR GRUPOS DE PERMISOS PARA LOS ROLES
	DECLARE @ROLE_PERMISSIONS_GROUP TABLE(
	 [Category] VARCHAR(50),
	 [GroupId]  VARCHAR(200),
	 [Type]     VARCHAR(50)
	)

	INSERT INTO @ROLE_PERMISSIONS_GROUP EXEC [dbo].[GetRolePermissionsGroups] @VCC_SYSTEM

	INSERT INTO [dbo].[RolePermissionsGroup] (
			                              [VCC], 
										  [GroupId], 
										  [Category], 
										  [Type], 
										  [TimeStamp]
										  )
		                                 SELECT 
										 @VCC, 
										 GroupId,
										 Category,
										 [Type], 
										 GETUTCDATE()	
										 FROM @ROLE_PERMISSIONS_GROUP

    --INSERTAR FEELINGS
	INSERT INTO [dbo].[Feeling] (
			                   [VCC], 
							   [Name], 
							   [Description],
							   [CreatedDate], 
							   [CreatedByUserId], 
							   [LastModifiedDate], 
							   [LastModifiedByUserId], 
							   [TimeStamp]
							   )
							   SELECT
							   @VCC,
							   [Name],
							   [Description],
							   GETUTCDATE(),
							   [CreatedByUserId],
							   GETUTCDATE(),
							   [LastModifiedByUserId],
							   GETUTCDATE()	
							   FROM [dbo].[Feeling] (NOLOCK)
							   WHERE [VCC] = @VCC_SYSTEM

    --INSERTAR PROGRAMACION NEUROLINGUISTICA
	INSERT INTO [dbo].[NeuroLinguisticProgramming] (
								[VCC],
								[Name],
								[Description],
								[CreatedDate],
								[CreatedByUserId],
								[LastModifiedDate], 
								[LastModifiedByUserId],
								[TimeStamp]
								)
								SELECT 
								@VCC,
								[Name],
								[Description],
								GETUTCDATE(),
								[CreatedByUserId],
								GETUTCDATE(),
								[LastModifiedByUserId],
								GETUTCDATE()
								FROM [dbo].[NeuroLinguisticProgramming] (NOLOCK)
								WHERE [VCC] = @VCC_SYSTEM
		
   --INSERTAR PALABRAS

   IF(EXISTS(SELECT [Name] FROM [dbo].[Word] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
   BEGIN
		   INSERT INTO [dbo].[Word](
					[VCC],
					[NeuroLinguisticProgrammingId],
					[Name],
					[ProcessId],
					[Language],
					[Type],
					[CreatedDate],
					[CreatedByUserId],
					[LastModifiedDate],
					[LastModifiedByUserId],
					[TimeStamp]
					)
				SELECT
				@VCC,
				[NeuroLinguisticProgrammingId],
				[Name],
				[ProcessId],
				[Language],
				[Type],
				GETUTCDATE(),
				[CreatedByUserId],
				GETUTCDATE(),
				[LastModifiedByUserId],
				GETUTCDATE()
			   FROM [dbo].[Word] (NOLOCK)
			   WHERE [VCC] = @VCC_SYSTEM
   END
   ELSE
   BEGIN
	       RAISERROR('SERVER_ERROR_WORD_NOT_FOUND', 16, 16)
   END

   --INSERTAR CATEGORIAS
   INSERT INTO [dbo].[Category] (
			[VCC], 
			[Name], 
			[Description],
			[CreatedDate], 
			[CreatedByUserId], 
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp]
			)
		SELECT 
		@VCC,
		[Name],
		[Description],
		GETUTCDATE(),
		[CreatedByUserId],
		GETUTCDATE(),
		[LastModifiedByUserId],
		GETUTCDATE()
	FROM [dbo].[Category] (NOLOCK)
	WHERE [VCC] = @VCC_SYSTEM

	--INSERTAR AMBIENTES
	IF(@Type <> 'OTHER')
	BEGIN
		DECLARE @NAME VARCHAR(100)
		SELECT @NAME = [Word] FROM [dbo].[WordsByLanguage] (NOLOCK) WHERE [Language] = @Language AND [Label] = 'ENVIRONMENT' 
		
		-- DECLARAMOS UNA VARIABLE PARA SETTEAR EL TIPO DE AMBIENTE INTEGRADO PARA EL VCC
		DECLARE @VCC_TYPE VARCHAR(25) = NULL
		IF (@Type = 'ALLEGRO' OR @Type = 'OCC') SET @VCC_TYPE = 'allegro'
		ELSE IF @Type = 'I6' SET @VCC_TYPE = 'i6'
		
		INSERT INTO [dbo].[Environment] (
			[VCC], 
			[Name], 
			[Type],
			[Description],
			[FTPDirectory],
			[ApiHost],
			[ApiPort],
			[ApiUser],
			[DbDisabled],
			[DbServer],
			[DbPort],
			[DbUser], 
			[PbxDisabled],
			[PbxServer],
			[PbxPort],
			[PbxUser],
			[ApiPassword],
			[DbPassword],
			[PbxPassword],
			[CreatedDate],
			[CreatedByUserId],
			[TimeStamp]
		)
			SELECT @VCC,
					@NAME,
					[Type],
					@NAME,
					[FTPDirectory],
					[ApiHost],
					[ApiPort],
					[ApiUser],
					[DbDisabled],
					[DbServer],
					[DbPort],
					[DbUser],
					[PbxDisabled],
					[PbxServer]	,
					[PbxPort],
					[PbxUser],
					[ApiPassword],
					[DbPassword],
					[PbxPassword],
					GETUTCDATE(),
					[CreatedByUserId],
					GETUTCDATE()
				FROM [dbo].[Environment] (NOLOCK)
				WHERE [VCC] = @VCC_SYSTEM
					AND [Type] = @VCC_TYPE

	END


	--INSERTAR PERMISOS PARA CATEGORIAS

	INSERT INTO [dbo].[CategoryPermissions](
			[VCC], 
			[Category], 
			[Position], 
			[TimeStamp]
			)
			SELECT
			@VCC,
		    [Category],
			[Position],
			GETUTCDATE()
			FROM [dbo].[CategoryPermissions] (NOLOCK) 
			WHERE [VCC] = @VCC_SYSTEM
			GROUP BY [Category],[Position]
		  

   --INSERTAR TENANT

   DECLARE @TENANT TABLE(
    [TenantId]     VARCHAR(50),
    [ClientId]     VARCHAR(50),
    [ClientSecret] VARCHAR(50),
    [Resource]     VARCHAR(50)
	)
	
	INSERT INTO @TENANT EXEC [dbo].[GetTenantVCCByVCC] @VCC_SYSTEM
	IF(EXISTS(SELECT [TenantId] FROM @TENANT))
	BEGIN

		INSERT INTO [dbo].[TenantVCC](
		[VCC], 
		[TenantId], 
		[ClientId], 
		[ClientSecret], 
		[Resource], 
		[CreatedDate], 
		[CreatedByUserId], 
		[TimeStamp])
		SELECT 
		@VCC,
		[TenantId],
		[ClientId],
		[ClientSecret],
		[Resource],
		GETUTCDATE(),
		@CreatedByUserId,
		GETUTCDATE()
		FROM @TENANT

	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_TENANT_NOT_FOUND', 16, 16)
	END

	--INSERTAR NLU

	IF(EXISTS(SELECT [Name] FROM [dbo].[NLU] WHERE [IsSystemApp]=1 AND [VCC] = @VCC_SYSTEM))
	BEGIN
		INSERT INTO [dbo].[NLU] (
					[VCC], 
					[Name], 
					[Culture],
					[Description], 
					[AppId], 
					[SubscriptionKey],
					[IsSystemApp], 
					[CreatedDate], 
					[CreatedByUserId], 
					[LastModifiedDate], 
					[LastModifiedByUserId], 
					[TimeStamp],
					[CognitiveEngine]
					)
					SELECT
					@VCC,
					[Name], 
					[Culture],
					[Description], 
					CONCAT(@VCC,'::',[Name]), 
					[SubscriptionKey],
					[IsSystemApp], 
					GETUTCDATE(), 
					[CreatedByUserId], 
					GETUTCDATE(), 
					[LastModifiedByUserId], 
					GETUTCDATE(),
					'RASA'
					FROM [dbo].[NLU]
					WHERE [IsSystemApp]=1 AND [VCC] = @VCC_SYSTEM

        INSERT INTO [dbo].[Intent](
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
			)
			SELECT
			@VCC,
			'Agent',
			'Agent',
			CONCAT(@VCC,'::',[Name]),
			GETUTCDATE(),
			@CreatedByUserId,
			GETUTCDATE(),
			@CreatedByUserId,
			GETUTCDATE(),
			1,
			'AVAILABLE'
			FROM [dbo].[NLU]
					WHERE [IsSystemApp]=1 AND [VCC] = @VCC_SYSTEM AND [Name] LIKE 'diarization-%'

		 INSERT INTO [dbo].[Intent](
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[Color],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
			)
			SELECT
			@VCC,
			'Positive',
			'Positive',
			CONCAT(@VCC,'::',[Name]),
			'far fa-smile',
			GETUTCDATE(),
			@CreatedByUserId,
			GETUTCDATE(),
			@CreatedByUserId,
			GETUTCDATE(),
			1,
			'AVAILABLE'
			FROM [dbo].[NLU]
					WHERE [IsSystemApp]=1 AND [VCC] = @VCC_SYSTEM AND [Name] LIKE 'sentiment-%'
		 
		  INSERT INTO [dbo].[Intent](
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[Color],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
			)
			SELECT
			@VCC,
			'Negative',
			'Negative',
			CONCAT(@VCC,'::',[Name]),
			'far fa-frown',
			GETUTCDATE(),
			@CreatedByUserId,
			GETUTCDATE(),
			@CreatedByUserId,
			GETUTCDATE(),
			1,
			'AVAILABLE'
			FROM [dbo].[NLU]
					WHERE [IsSystemApp]=1 AND [VCC] = @VCC_SYSTEM AND [Name] LIKE 'sentiment-%'
		
		 INSERT INTO [dbo].[Intent](
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[Color],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
			)
			SELECT
			@VCC,
			'Neutral',
			'Neutral',
			CONCAT(@VCC,'::',[Name]),
			'far fa-meh',
			GETUTCDATE(),
			@CreatedByUserId,
			GETUTCDATE(),
			@CreatedByUserId,
			GETUTCDATE(),
			1,
			'AVAILABLE'
			FROM [dbo].[NLU]
					WHERE [IsSystemApp]=1 AND [VCC] = @VCC_SYSTEM AND [Name] LIKE 'sentiment-%'
	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_SYSTEM_APPS_SAVING_FAILED', 16, 16)
	END

	--INSERTAR DICCIONARIOS

	IF(EXISTS(SELECT [Name] FROM [dbo].[Dictionary] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
	BEGIN 
	INSERT INTO [dbo].[Dictionary] (
			[VCC], 
			[Name], 
			[Description], 
			[Language], 
			[IsSystemDictionary], 
			[CreatedDate], 
			[CreatedByUserId], 
			[TimeStamp]
		)
		SELECT
		    @VCC,
		    [Name],
			[Description],
			[Language],
			[IsSystemDictionary],
			GETUTCDATE(),
			[CreatedByUserId],
			GETUTCDATE()
		FROM [dbo].[Dictionary] (NOLOCK)
		WHERE [VCC] = @VCC_SYSTEM
	END
	ELSE
	BEGIN
	    RAISERROR('SERVER_ERROR_SYSTEM_DICTIONARIES_SAVING_FAILED',16,16)
	END

	--INSERTAR TIPOS DE INTERACCIONES
	IF(EXISTS(SELECT [ID] FROM [dbo].[InteractionType] WHERE [Instance] = @VCC_SYSTEM ))
	BEGIN
	INSERT INTO [dbo].[InteractionType] (
			[Instance],
			[ID],
			[Description]
			)
			SELECT
			@VCC,
			[ID],
		    [Description]
			FROM InteractionType  (NOLOCK)
			WHERE [Instance] = @VCC_SYSTEM
	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_INTERACTION_TYPE_NOT_FOUND',16,16) 
	END

	--INSERTAR GENERIC QUERY

	IF(EXISTS(SELECT [Name] FROM [dbo].[GenericQuery] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
	BEGIN
	INSERT INTO [dbo].[GenericQuery]
		(
			[VCC],
			[Name],
			[Description],
			[Query],
			[RawData],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId],
			[Version],
			[TimeStamp]
		)
		SELECT
		@VCC,
		[Name],--REPLACE([Name], @Language+'_', ''),
		[Description],
		[Query],
		[RawData],
		GETUTCDATE(),
		[CreatedByUserId],
		GETUTCDATE(),
		[LastModifiedByUserId],
		[Version],
		GETUTCDATE()
		FROM [dbo].[GenericQuery] (NOLOCK)
		WHERE [VCC] = @VCC_SYSTEM --AND [Name] LIKE @Language + '%'
	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_GENERIC_QUERY_NOT_FOUND',16,16) 
	END

	--INSERTAR  USUARIO AUDITOR SPEECH
	EXEC [dbo].[SaveSpeechAnalyticAuditorUser] @VCC

	--INSERTAR REPORTES
	IF(EXISTS(SELECT [ID] FROM  [dbo].[Report] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
	BEGIN
	INSERT INTO [Report] (
			[VCC], 
			[ID], 
			[Description],
			[Type],
            [Procedure], 
			[StartDate],
			[EndDate],
            [Frecuency],
			[HourSpace],
			[ExactTime],
            [Weekday],
			[DayMonth],
			[Summary],
            [Filter], 
			[Email], 
			[CreatedDate],
            [CreatedByUserId],
			[LastModifiedDate],
			[LastModifiedByUserId],
            [TimeStamp]
        )
		SELECT
		        @VCC,
				[ID],
				[Description],
				[Type],
				[Procedure],
				[StartDate],
				[EndDate],
				[Frecuency],
				[HourSpace],
				[ExactTime],
				[Weekday],
				[DayMonth],
				[Summary],
				[Filter],
				[Email],
				GETUTCDATE(),
				@CreatedByUserId,
				GETUTCDATE(),
				@CreatedByUserId,
				GETUTCDATE()
			FROM [dbo].[Report] (NOLOCK)
			WHERE [VCC] = @VCC_SYSTEM

	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_REPORT_NOT_FOUND',16,16) 
	END

	COMMIT TRANSACTION

    END TRY

    BEGIN CATCH

    IF @@TRANCOUNT > 0 
	BEGIN
		ROLLBACK TRANSACTION
		--ELIMINAR LOS REGISTROS SI HA FALLADO
		EXEC [dbo].[RollbackVcc] @VCC
	END

    DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
    DECLARE @Severity integer = ERROR_SEVERITY()
    DECLARE @State integer = ERROR_STATE()

    RAISERROR(@Message, @Severity, @State)
  
    END CATCH
    SET NOCOUNT OFF
END
GO
PRINT N'Altering Procedure [dbo].[GetAudiosProcess]...';


GO
-- [dbo].[GetAudiosProcess] 5, 1, 'allegro', 'proceso1', '', '2019-04-11 00:00:00.000', '2019-06-06 04:59:59.997', 22, 26, 23, 59, 'entrantes,PruebasJair,VideoCall', 'icagente', NULL, 'allegro', '', ''
ALTER PROCEDURE [dbo].[GetAudiosProcess]
(
	@PageSize				INT,
	@PageNumber				INT,
	@VCC					VARCHAR(50),
	@ProcessId				VARCHAR(50),
	@ID						VARCHAR(250),
	@StartDate				DATETIME = NULL,
	@EndDate				DATETIME = NULL,
	@StartHour				INT,
	@StartMinute			INT,
	@EndHour				INT,
	@EndMinute				INT,
	@Campaign				VARCHAR(MAX),
	@Agent					VARCHAR(MAX),
	@ResultCode				VARCHAR(MAX),
	@Type					VARCHAR(50),
	@IdathaResults			NVARCHAR(MAX),
	@TotalIdathaResults		INT,
	@InteractionType		VARCHAR(50),
	@InteractionIds         VARCHAR(MAX) = NULL,
	@Folder					VARCHAR(50),
	@ContactAddress			VARCHAR(300) = NULL,
	@SentimentIds			VARCHAR(MAX) = NULL
	
)
AS
BEGIN
	SET NOCOUNT ON
	  --RESULTADOS DE ANALYSIS DE SENTIMIENTOS
   CREATE TABLE #SentimentAnalysisResult
   (
   VCC VARCHAR(50),
   InteractionId VARCHAR(250),
   InteractionSection NUMERIC(5,0),
   InteractionPart NUMERIC(5,0), 
   SentimentId VARCHAR(50),	
   MaxScore NUMERIC(10,5)
   )
	;WITH SentimentInteractionTemp AS(
	SELECT VCC,InteractionId,InteractionSection, InteractionPart,InteractionInterval,max(Score) as MaxScore 
	FROM SentimentAnalysisResult 
	GROUP BY VCC,InteractionId,InteractionSection, InteractionPart, InteractionInterval, AnalysisType),
	SentimentAnalysisSummary as(
	SELECT SAR.VCC,SAR.InteractionId,SAR.InteractionSection,SAR.InteractionPart,SAR.SentimentId, MaxScore 
	FROM SentimentInteractionTemp SIT
	INNER JOIN SentimentAnalysisResult SAR ON 
	SIT.VCC = SAR.VCC AND
	SIT.InteractionId = SAR.InteractionId AND
	SIT.InteractionSection = SAR.InteractionSection AND
	SIT.InteractionPart = SAR.InteractionPart AND
	SIT.InteractionInterval = SAR.InteractionInterval AND	
	SIT.MaxScore = SAR.Score AND
	SAR.AnalysisType = 'general'
	INNER JOIN ProcessAudio PA ON 
	SIT.VCC = PA.VCC AND
	SIT.InteractionId = PA.AudioId AND
	SIT.InteractionSection = PA.Section AND
	SIT.InteractionPart = PA.Part AND
	PA.VCC = @VCC AND
	PA.ProcessId = @ProcessId
	)
	INSERT INTO  #SentimentAnalysisResult
	SELECT * FROM SentimentAnalysisSummary
	
	-- DEFINIMOS UNA TABLE TEMPORAL PARA DEPOSITAR LA TODOS LAS INTERACCIONES DEL PROCESS
	CREATE TABLE #PROCESS_INTERACTIONS(
		vcc VARCHAR(50),
		interactionType VARCHAR(100),
		id VARCHAR(250),
		section VARCHAR(5),
		part VARCHAR(5),
		processId VARCHAR(100),
		number VARCHAR(100),
		name VARCHAR(100),
		silenceTime INT,
		durationTime INT,
		durationLinguisticTime INT,
		category1 VARCHAR(100),
		category2 VARCHAR(100),
		category3 VARCHAR(100),
		agent VARCHAR(100),
		agentName VARCHAR(150),
		description VARCHAR(100),
		environment VARCHAR(100),
		isTranscribed VARCHAR(100),
		errorMessage VARCHAR(MAX),
		createdDate DATETIME,
		endDate DATETIME,
		campaign VARCHAR(50),
		dispositionCode VARCHAR(250),
		folder VARCHAR(50),
		contactAddress varchar(300),
		sentimentResult varchar(50)
	)

	-- INSERTAMOS LOS REGISTROS CALL
	INSERT INTO #PROCESS_INTERACTIONS
		SELECT A.[VCC]														'vcc',
				'CALL'														'interactionType',
				A.[ID]														'id',
				A.[Section]													'section',
				A.[Part]													'part',
				PA.[ProcessId]												'processId',
				A.[Number]													'number',
				P.[Name]													'name',
				A.[SilenceTime]												'silenceTime',
				A.[DurationTime]											'durationTime',
				A.[DurationLinguisticTime]									'durationLinguisticTime',
				A.[Category1]												'category1',
				A.[Category2]												'category2',
				A.[Category3]												'category3',
				A.[Agent]													'agent',
				A.[AgentName]												'agentName',
				A.[Description]												'description',
				P.[Environment]												'environment',
				A.[IsTranscribed]											'isTranscribed',
				A.[ErrorMessage]											'errorMessage',
				A.[CreatedDate]												'createdDate',
				A.[EndDate]													'endDate',
				A.[Campaign]												'campaign',
				A.[DispositionCode]											'dispositionCode',
				NULL														'folder',
				A.[ContactAddress]											'contactAddress',
				SAR.SentimentId												'sentimentResult'
			FROM [dbo].[Audio] A (NOLOCK)
			INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
				ON A.[VCC] = PA.[VCC]
					AND A.ID = PA.AudioId 
					AND A.Section = PA.Section 
					AND A.Part = PA.Part
			INNER JOIN [dbo].[Process] P (NOLOCK) 
				ON P.[VCC] = PA.[VCC]
					AND PA.[ProcessId] = P.[Name]
			LEFT JOIN  #SentimentAnalysisResult SAR 
			ON A.[VCC] = SAR.[VCC]
					AND A.ID = SAR.InteractionId 
					AND A.Section = SAR.InteractionSection 
					AND A.Part = SAR.InteractionPart				
			WHERE A.[VCC] = @VCC
				AND PA.[ProcessId] = @ProcessId
				AND P.[Type] = 'SPEECH'
				
	-- INSERTAMOS LOS REGISTROS DE INTERACCIONES DE OTROS CANALES
	INSERT INTO #PROCESS_INTERACTIONS
		SELECT AI.[VCC]																'vcc',
				AI.[Channel]														'interactionType',
				AI.[ID]																'id',
				NULL																'section',
				NULL																'part',
				PAI.[ProcessId]														'processId',
				AI.[ContactName]													'number',
				PAI.[ProcessId]														'name',
				NULL																'silenceTime',
				CASE WHEN TRY_CAST(AI.[DurationTime] AS INT) IS NULL THEN
					CAST(SUBSTRING(AI.[DurationTime], 1, CHARINDEX(':', AI.[DurationTime], 1) - 1) AS INT) * 3600
					+
					CAST(SUBSTRING(AI.[DurationTime], CHARINDEX(':', AI.[DurationTime], 1) + 1, 2) AS INT) * 60
					+
					CAST(SUBSTRING(AI.[DurationTime], CHARINDEX(':', AI.[DurationTime], CHARINDEX(':', AI.[DurationTime], 1) + 1) + 1, 2) AS INT)
				ELSE AI.[DurationTime]
				END																	'durationTime',
				NULL																'durationLinguisticTime',
				NULL																'category1',
				NULL																'category2',
				NULL																'category3',
				AI.[FirstTakedAgent]												'agent',
				ISNULL(AI.[LastTakedAgentName], AI.[LastTakedAgentName])			'agentName',
				AI.[DispositionCode]												'description',
				'I6'																'environment',
				AI.[IsTranscribed]													'isTranscribed',
				AI.[ErrorMessage]													'errorMessage',
				AI.[CreatedDate]													'createdDate',
				AI.[EndDate]														'endDate',
				AI.[Campaign]														'campaign',
				AI.[DispositionTreePath]											'dispositionCode',
				AI.[Folder]															'folder',
				AI.[ContactAddress]													'contactAddress',
				NULL																'sentimentResult'
			FROM [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
			INNER JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
				ON AI.[VCC] = PAI.[VCC]
					--AND AI.[Campaign] = PAI.[Campaign]
					AND AI.[Channel] = PAI.[InteractionType]
					AND AI.[ID] = PAI.[InteractionId]
					AND AI.[Folder] = PAI.[FormattedEndDate]
			INNER JOIN [dbo].[Process] P (NOLOCK) 
				ON P.[VCC] = PAI.[VCC]
					AND P.[Name] = PAI.[ProcessId]
			WHERE PAI.[VCC] = @VCC
				AND PAI.[ProcessId] = @ProcessId
				AND P.[Type] = 'SPEECH'
   
 

   

   
		
	-- DECLARAMOS VARIABLE PARA LA CONSULTA ACUMULADA QUE LANZAREMOS
	DECLARE @SQL NVARCHAR(MAX) = ''
	DECLARE @SQL_WHERE_IDATHA NVARCHAR(MAX) = ''
    DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
	DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX )= ''
	DECLARE @FILTERS_OPTIONAL_SENTIMENT VARCHAR(MAX) = ''
	
	
	SET @SQL_WHERE_IDATHA = ''

	-- HACEMOS EL PRIMER QUERY PARA SACAR EL NUMERO DE REGISTROS DEL PROCESS
	SET @SQL = ' SET NOCOUNT ON
	DECLARE @rows INT
	DECLARE @SYNC_INTERACTIONS INT
	DECLARE @ASYNC_INTERACTIONS INT
	DECLARE @maxDurationTime Numeric(12,3)

	SELECT @SYNC_INTERACTIONS = COUNT(*) FROM #PROCESS_INTERACTIONS PI WHERE PI.[interactionType] = ''CALL''
	SELECT @ASYNC_INTERACTIONS = COUNT(*) FROM #PROCESS_INTERACTIONS PI WHERE PI.[interactionType] <> ''CALL''
	SELECT @maxDurationTime = MAX([durationTime]) FROM #PROCESS_INTERACTIONS 
	'

	SET @SQL += '
		SET @rows = (
			SELECT COUNT(PI.[id])
				FROM #PROCESS_INTERACTIONS PI (NOLOCK)
				WHERE PI.[vcc] = ''' + @VCC + ''' 
					'
	IF (@ProcessId IS NOT NULL) 
			SET @SQL += 'AND PI.[ProcessId]= ''' + @ProcessId + ''' 
						'

	IF(@Type = 'query')
	BEGIN
		SET @SQL_WHERE_IDATHA += 'AND ((CONCAT(PI.[id], ''_'', PI.[section], ''_'', PI.[part]) IN (''' + @IdathaResults + '''))
						OR (PI.[id] IN (''' + @IdathaResults + ''')))
					'
	
		SET @SQL += @SQL_WHERE_IDATHA

	END
	ELSE IF(@Type = 'allegro' OR @Type = 'i6' OR @Type = 'ftp' OR @Type = 'sftp' OR @Type = 'fileSystem')
	BEGIN
		IF (@ID IS NOT NULL) 
			SET @FILTERS_OPTIONAL_PART += 'AND ((CONCAT(PI.[id], ''_'', PI.[section], ''_'', PI.[part]) LIKE ''%' + @ID + '%'')
						OR (PI.[id] = ''' + @ID + '''))
					'
		
		IF (@Campaign IS NOT NULL AND LEN(@Campaign) > 0) 
			SET @FILTERS_OPTIONAL_PART += 'AND PI.[campaign] IN (''' + @Campaign + ''')
						'
		
		IF (@Agent IS NOT NULL AND LEN(@Agent) > 0) 
			SET @FILTERS_OPTIONAL_PART += 'AND (
									(PI.[agent] IN (''' + @Agent + '''))
									OR 
									(PI.[agent] IS NULL)
								)
						'
		
		--CORREGIR
		-- (CONCAT(PI.campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), PI.[dispositionCode]), '''') IN (''' + @ResultCode + '''))
		IF (@ResultCode IS NOT NULL AND LEN(@ResultCode) > 0) 
			SET @FILTERS_OPTIONAL_PART += 'AND (
									(CONCAT(PI.campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), PI.[dispositionCode]), ''X'')) IN (''' + @ResultCode + '''))
									OR 
									--(CONCAT(PI.campaign, ''_'', ISNULL(PI.[dispositionCode], ''X'')) IN (''' + @ResultCode + '''))
									(CONCAT(PI.campaign, ISNULL(REPLACE(PI.[dispositionCode], ''/'', ''_''), ''_'')) IN (''' + @ResultCode + '''))
									) '
		
		IF (@InteractionType IS NOT NULL AND LEN(@InteractionType) > 0) 
			SET @FILTERS_OPTIONAL_PART += 'AND PI.[interactionType] = ''' + @InteractionType + ''' 
						'

		IF (@Folder IS NOT NULL AND LEN(@Folder) > 0) 
			SET @FILTERS_OPTIONAL_PART += 'AND PI.[folder] = ''' + @Folder + ''' 
						'

		IF (@Folder IS NOT NULL AND LEN(@Folder) > 0) 

		IF (@StartDate IS NOT NULL AND @EndDate IS NOT NULL) 
			SET @FILTERS_OPTIONAL_PART += 'AND PI.[endDate] BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' 
						AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
						'
		
		IF (@StartHour IS NOT NULL AND @EndHour IS NOT NULL) 
			SET @FILTERS_OPTIONAL_PART += 'AND DATEPART(HOUR, PI.[endDate]) >= ' + CONVERT(VARCHAR, @StartHour) + ' 
						AND DATEPART(HOUR, PI.[endDate]) <= ' + CONVERT(VARCHAR, @EndHour) + '
						'
		
		IF (@StartMinute IS NOT NULL AND @EndMinute IS NOT NULL) 
			SET @FILTERS_OPTIONAL_PART += 'AND DATEPART(MINUTE, PI.[endDate]) >= ' + CONVERT(VARCHAR, @StartMinute) + ' 
						AND DATEPART(MINUTE, PI.[endDate]) <= ' + CONVERT(VARCHAR, @EndMinute) + '
						'

		IF(@ContactAddress IS NOT NULL AND @ContactAddress <> '')
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND ContactAddress LIKE ''%' + @ContactAddress + '%''
			'
		END	
		
		IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
        BEGIN
			SET @FILTERS_OPTIONAL_PART = ''
			-- SET @FILTERS_EXCLUDING_PART = ' AND PI.[id] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) 
			--			'
			SET @FILTERS_EXCLUDING_PART = ' AND (
						(CONCAT(PI.[id], ''_'', PI.[section], ''_'', PI.[part]) IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')))
						OR 
						(PI.[id] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')))
						)
						'
	    END

		IF (@SentimentIds IS NOT NULL AND @SentimentIds <> '')
        BEGIN		
			
			SET @FILTERS_OPTIONAL_PART += ' AND 
						 PI.[sentimentResult] IN ('+''''+ @SentimentIds +''''+ ')						
						'
	    END
		
	END

	SET @SQL += @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART
	SET @SQL += ') '
	SET @SQL += 'SELECT @rows AS total, 
						@maxDurationTime AS maxDurationTime,
						@ASYNC_INTERACTIONS AS asyncDetails, 
						@SYNC_INTERACTIONS AS audios '

	-- SECCION DE QUERY PARA RESUMEN DE CANALES
	SET @SQL += '
		SELECT PI.[interactionType]			''interactionType'',
				COUNT(*)					''interactions'' 
			FROM #PROCESS_INTERACTIONS PI 
			WHERE PI.[vcc] = ''' + @VCC + ''' 
	'

	IF(@ProcessId IS NOT NULL) 
		SET @SQL += '
				AND PI.[processId] = ''' + @ProcessId + ''' '
		
	SET @SQL += '
		GROUP BY  PI.[interactionType] '

	-- SECCION DE QUERY PARA RESUMEN DE CAMPANAS
	SET @SQL += '
		SELECT PI.[campaign]			''campaign''
			FROM #PROCESS_INTERACTIONS PI 
			WHERE PI.[vcc] = ''' + @VCC + ''' 
	'

	IF(@ProcessId IS NOT NULL) 
		SET @SQL += '
				AND PI.[processId] = ''' + @ProcessId + ''' '
		
	SET @SQL += '
		GROUP BY  PI.[campaign] '

	-- SECCION DE QUERY PARA LISTADO DE DETALLES(AUDIOS/TEXTOS)
	SET @SQL += '
		SELECT PI.[interactionType],
				PI.[id],
				PI.[section],
				PI.[part],
				PI.[processId],
				PI.[folder],
				PI.[campaign],
				PI.[number],
				PI.[name],
				PI.[silenceTime],
				PI.[durationTime],
				PI.[durationLinguisticTime],
				PI.[category1],
				PI.[category2],
				PI.[category3],
				PI.[agent],
				PI.[agentName],
				PI.[description],
				PI.[environment],
				PI.[isTranscribed],
				PI.[errorMessage],
				PI.[createdDate],
				PI.[endDate]
			FROM #PROCESS_INTERACTIONS PI
			WHERE PI.[vcc] = ''' + @VCC + ''' 
				'

	IF(@ProcessId IS NOT NULL) SET @SQL += 'AND PI.[processId] = ''' + @ProcessId + ''' '
			
	SET @SQL += ' '

	SET @SQL += @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART
	SET @SQL += @SQL_WHERE_IDATHA
	SET @SQL += 'ORDER BY PI.[ID], 
						PI.[ProcessId], 
						PI.[Agent], 
						PI.[AgentName], 
						PI.[Description], 
						PI.[Environment], 
						PI.[DurationTime], 
						PI.[CreatedDate]
			OFFSET ' + CONVERT(VARCHAR(50), @PageSize) + ' * (' + CONVERT(VARCHAR(50), @PageNumber) + ' - 1) ROWS
			FETCH NEXT ' + CONVERT(VARCHAR(50), @PageSize) + ' ROWS ONLY
			'

	SET @SQL += ' SET NOCOUNT OFF'
	print (@SQL)
	EXEC(@SQL)
	
	DROP TABLE #PROCESS_INTERACTIONS
	DROP TABLE #SentimentAnalysisResult
END
GO
PRINT N'Altering Procedure [dbo].[GetAudiosTranscriptions]...';


GO
ALTER PROCEDURE [dbo].[GetAudiosTranscriptions]
( 
	@PageSize				INT,
	@PageNumber				INT,
	@VCC					VARCHAR(50),
	@ProcessId				VARCHAR(50),
	@ID						VARCHAR(50),
	@StartDate				DATETIME = NULL,
	@EndDate				DATETIME = NULL,
	@StartHour				INT,
	@StartMinute			INT,
	@EndHour				INT,
	@EndMinute				INT,
	@Campaign				VARCHAR(MAX),
	@Agent					VARCHAR(MAX),
	@ResultCode				VARCHAR(MAX),
    @InteractionIds         VARCHAR(MAX) = NULL,
	@ContactAddress		    VARCHAR(300) =	NULL,
	@SentimentIds			VARCHAR(MAX) = NULL
)
AS
BEGIN

  --RESULTADOS DE ANALYSIS DE SENTIMIENTOS
   CREATE TABLE #SentimentAnalysisResult
   (
   VCC VARCHAR(50),
   InteractionId VARCHAR(250),
   InteractionSection NUMERIC(5,0),
   InteractionPart NUMERIC(5,0), 
   SentimentId VARCHAR(50),	
   MaxScore NUMERIC(10,5)
   )
	;WITH SentimentInteractionTemp AS(
	SELECT VCC,InteractionId,InteractionSection, InteractionPart,InteractionInterval,max(Score) as MaxScore 
	FROM SentimentAnalysisResult 
	GROUP BY VCC,InteractionId,InteractionSection, InteractionPart, InteractionInterval, AnalysisType),
	SentimentAnalysisSummary as(
	SELECT SAR.VCC,SAR.InteractionId,SAR.InteractionSection,SAR.InteractionPart,SAR.SentimentId, MaxScore 
	FROM SentimentInteractionTemp SIT
	INNER JOIN SentimentAnalysisResult SAR ON 
	SIT.VCC = SAR.VCC AND
	SIT.InteractionId = SAR.InteractionId AND
	SIT.InteractionSection = SAR.InteractionSection AND
	SIT.InteractionPart = SAR.InteractionPart AND
	SIT.InteractionInterval = SAR.InteractionInterval AND	
	SIT.MaxScore = SAR.Score AND
	SAR.AnalysisType = 'general'
	INNER JOIN ProcessAudio PA ON 
	SIT.VCC = PA.VCC AND
	SIT.InteractionId = PA.AudioId AND
	SIT.InteractionSection = PA.Section AND
	SIT.InteractionPart = PA.Part AND
	PA.VCC = @VCC AND
	PA.ProcessId = @ProcessId
	)
	INSERT INTO  #SentimentAnalysisResult
	SELECT * FROM SentimentAnalysisSummary
	---------------

	DECLARE @SQL                    NVARCHAR(MAX);
    DECLARE @FILTERS_OPTIONAL_PART  VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = ''

	SET @SQL = 'SET NOCOUNT ON
	DECLARE @rows INT
	SET @rows = (SELECT COUNT(A.ID)
		FROM [dbo].[Audio] A (NOLOCK)
		INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
			ON PA.[VCC] = A.[VCC]
				AND A.ID = PA.AudioId 
				AND A.Section = PA.Section 
				AND A.Part = PA.Part
		LEFT JOIN  #SentimentAnalysisResult SAR 
			ON A.[VCC] = SAR.[VCC]
					AND A.ID = SAR.InteractionId 
					AND A.Section = SAR.InteractionSection 
					AND A.Part = SAR.InteractionPart
		LEFT JOIN [dbo].[Process] P (NOLOCK)
			-- ON P.[Description] = PA.[ProcessId]
			ON P.[VCC] = A.[VCC]
				AND P.[Name] = PA.[ProcessId]
		WHERE A.[VCC] = ''' + @VCC + ''' 
			AND A.[IsTranscribed] = 1 
			AND P.[TYPE] = ''SPEECH'' '
			IF(@ProcessId IS NOT NULL)
			BEGIN
				SET @SQL += '
				AND PA.[ProcessId]= ''' + @ProcessId + ''' '
			END
	
	BEGIN
		IF(@ID IS NOT NULL)
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND CONCAT(A.[ID], ''_'', A.[Section], ''_'', A.[Part]) LIKE ''%' + @ID + '%''
			'
		END
		IF(@Campaign IS NOT NULL AND LEN(@Campaign) > 0)
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND A.[Campaign] IN(''' + @Campaign + ''')
			'
		END
		IF(@Agent IS NOT NULL AND LEN(@Agent) > 0)
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND A.[Agent] IN(''' + @Agent + ''')
			'
		END
		IF(@ResultCode IS NOT NULL AND LEN(@ResultCode) > 0)
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND CONCAT(A.Campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), A.[DispositionCode]), '''')) IN (''' + @ResultCode + ''')
			'
		END
		IF(@StartDate IS NOT NULL AND @EndDate IS NOT NULL)
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND A.[EndDate] BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
			'
		END
		IF(@StartHour IS NOT NULL AND @EndHour IS NOT NULL)
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND DATEPART(HOUR, A.[EndDate]) >= ' + CONVERT(VARCHAR, @StartHour) + ' AND DATEPART(HOUR, A.[EndDate]) <= ' + CONVERT(VARCHAR, @EndHour) + '
			'
		END
		IF(@StartMinute IS NOT NULL AND @EndMinute IS NOT NULL)
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND DATEPART(MINUTE, A.[EndDate]) >= ' + CONVERT(VARCHAR, @StartMinute) + ' AND DATEPART(MINUTE, A.[EndDate]) <= ' + CONVERT(VARCHAR, @EndMinute) + '
			'
		END
		IF(@ContactAddress IS NOT NULL)
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND A.ContactAddress LIKE ''%' + @ContactAddress + '%''
			'
		END

	
		IF (@SentimentIds IS NOT NULL AND @SentimentIds <> '')
        BEGIN		
			
			SET @FILTERS_OPTIONAL_PART += ' AND 
						 SAR.[SentimentId] IN ('+''''+ @SentimentIds +''''+ ')						
						'
	    END
		
		IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
        BEGIN 
            SET @FILTERS_OPTIONAL_PART = '';
	        SET @FILTERS_EXCLUDING_PART=' AND A.[ID] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) '
        END

		
	
	END
	SET @SQL += @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART
	SET @SQL += ') '
	SET @SQL += ' SELECT @rows AS total '
	
	SET @SQL += '
		SELECT
			A.[ID]						''id'',
			A.[Section]					''section'',
			A.[Part]					''part'',
			PA.[ProcessId]				''processId'',
			A.[Number]					''number'',
			B.[Name]					''name'',
			A.[SilenceTime]				''silenceTime'',
			A.[DurationTime]			''durationTime'',
			A.[DurationLinguisticTime]	''durationLinguisticTime'',
			A.[Category1]				''category1'',
			A.[Category2]				''category2'',
			A.[Category3]				''category3'',
			A.[Agent]					''agent'',
			A.[AgentName]				''agentName'',
			A.[Description]				''description'',
			B.[Environment]				''environment'',
			E.[Type]					''environmentType'',
			A.[IsTranscribed]			''isTranscribed'',
			COUNT(UT.[Text])		    ''isSubrayed'',
			A.[CreatedDate]				''createdDate'',
			A.[EndDate]					''endDate'',
			SAR.[SentimentId]			''sentimentResult''
		FROM [dbo].[Audio] A (NOLOCK)
		INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
			ON PA.[VCC] = A.[VCC]
				AND A.ID = PA.AudioId 
				AND A.Section = PA.Section 
				AND A.Part = PA.Part
		LEFT JOIN  #SentimentAnalysisResult SAR 
			ON A.[VCC] = SAR.[VCC]
					AND A.ID = SAR.InteractionId 
					AND A.Section = SAR.InteractionSection 
					AND A.Part = SAR.InteractionPart
		INNER JOIN [dbo].[Process] B (NOLOCK) 
			ON B.[VCC] = PA.[VCC]
				AND PA.[ProcessId] = B.[Name]
		INNER JOIN [dbo].[Environment] E (NOLOCK) 
			ON E.[VCC] = B.[VCC]
				AND B.[Environment] = E.[Name] 
				AND B.VCC = E.VCC
		LEFT JOIN [dbo].[Underlined] U (NOLOCK) 
			ON U.[VCC] = A.[VCC]
				AND A.ID = U.AudioId 
				AND A.Section = U.Section 
				AND A.Part = U.Part
	    LEFT JOIN [dbo].[Utterance] UT (NOLOCK)
	        ON UT.[VCC] = U.[VCC]
	           AND U.[UtteranceId] = UT.[Id]
		WHERE
			A.[VCC] = ''' + @VCC + ''' AND A.[IsTranscribed] = 1 '
			IF(@ProcessId IS NOT NULL)
			BEGIN
				SET @SQL += '
				AND PA.[ProcessId] = ''' + @ProcessId + ''' '
			END
			SET @SQL += '
	'

	SET @SQL += @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART
	
	SET @SQL += '
		AND B.[TYPE] = ''SPEECH''
		GROUP BY A.[ID], A.[Section], A.[Part], PA.[ProcessId], A.[Number],
				B.[Name], A.[SilenceTime], A.[DurationTime], A.[DurationLinguisticTime], A.[Category1],     
				A.[Category2], A.[Category3], A.[Agent], A.[AgentName], A.[Description], 
				B.[Environment], E.[Type], A.[IsTranscribed], A.[CreatedDate], A.[EndDate], SAR.[SentimentId]
		ORDER BY A.[ID], PA.[ProcessId], A.[Agent], A.[Description], B.[Environment], A.[DurationTime], A.[CreatedDate]
		OFFSET ' + CONVERT(VARCHAR(50), @PageSize) + ' * (' + CONVERT(VARCHAR(50), @PageNumber) + ' - 1) ROWS
		FETCH NEXT ' + CONVERT(VARCHAR(50), @PageSize) + ' ROWS ONLY;
	'
	print @SQL
	SET @SQL += ' SET NOCOUNT OFF'	
	EXEC(@SQL)
END
GO
PRINT N'Altering Procedure [dbo].[GetCognitiveInteractionIntents]...';


GO
ALTER PROCEDURE [dbo].[GetCognitiveInteractionIntents]
(
@IdInteraction VARCHAR(100),
@Section VARCHAR(50),
@Part VARCHAR(50),
@Vcc VARCHAR(50),
@TypeProcessResult VARCHAR(50),
@ProcessResult VARCHAR(50)
)
AS
BEGIN

	IF (@TypeProcessResult = 'EvaluationPlan')
	BEGIN
		SELECT DISTINCT
		NI.[VCC]				'vcc',
		NI.[Name]				'intentName',
		NI.[IntentId]			'intentId',
		NI.[AppId]				'appId',
		NI.[CognitiveEngine]	'cognitiveEngine',
		NI.[nluId]				'modelName'

		FROM InteractionEvaluationPlan  IEP 
		INNER JOIN EvaluationResult ER ON IEP.Instance = ER.Instance AND IEP.IdInteraction = ER.IdInteraction
		INNER JOIN EvaluationPlan EP ON IEP.IdEvaluationPlan = EP.ID
		INNER JOIN EvaluationFormat EF ON EP.IdEvaluationFormat = EF.ID
		INNER JOIN AbilityEvaluationFormat AEF ON EF.ID = AEF.IdEvaluationFormat
		INNER JOIN AbilityQuery AQ ON AEF.IdAbility = AQ.AbilityId
		INNER JOIN (
		SELECT DISTINCT
						INNER_N.[VCC]								'vcc'
						,INNER_N.[Name] + '|'+ INNER_I.[Name]		'cognitiveId'
						,INNER_N.[Name]								'nluId'
						,INNER_N.[AppId]							'appId'
						,INNER_I.[IntentId]							'intentId'
						,INNER_I.[Name]
						,INNER_N.[CognitiveEngine]					'cognitiveEngine'	

					FROM [dbo].[NLU] INNER_N (NOLOCK)
					INNER JOIN [dbo].[Intent] INNER_I (NOLOCK) 
					ON INNER_N.[VCC] = INNER_I.[VCC]
							AND INNER_N.AppId = INNER_I.[AppId] 
					WHERE INNER_N.[VCC] = @Vcc
		) NI ON NI.vcc =AQ.VCC AND NI.cognitiveId =AQ.QueryContent

		WHERE IEP.IdInteraction = @IdInteraction and
		IEP.InteractionSection =  @Section and
		IEP.InteractionPart = @Part and 
		IEP.instance = @Vcc and 
		IEP.IdEvaluationPlan = @ProcessResult

	END

	ELSE --Es un estudio
	BEGIN
	SELECT DISTINCT	
	            TTI.[VCC]											'vcc',	
				NI.[Name]											'intentName',
				NI.[intentId]										'intentId',
				TTI.[VCC]+'::'+ NI.[nluId]							'appId',			
				NI.[cognitiveEngine]								'cognitiveEngine',
				NI.[nluId]											'modelName'	
				
				FROM StudyResultSummary SR 
				INNER JOIN StudyResultSummaryDetail SRD ON SR.StudyId =SRD.StudyId
				INNER JOIN TemplateTheme TT ON SR.TemplateId = TT.TemplateId
				INNER JOIN TemplateThemeItem TTI ON TT.TemplateId = TTI.TemplateId
				INNER JOIN (
				SELECT DISTINCT
						INNER_N.[VCC]								'vcc'
						,INNER_N.[Name] + '|'+ INNER_I.[Name]		'cognitiveId'
						,INNER_N.[Name]								'nluId'
						,INNER_N.[AppId]							'appId'
						,INNER_I.[IntentId]							'intentId'
						,INNER_I.[Name]
						,INNER_N.[CognitiveEngine]					'cognitiveEngine'	

					FROM [dbo].[NLU] INNER_N (NOLOCK)
					INNER JOIN [dbo].[Intent] INNER_I (NOLOCK) 
					ON INNER_N.[VCC] = INNER_I.[VCC]
							AND INNER_N.AppId = INNER_I.[AppId] 
					WHERE INNER_N.[VCC] = @Vcc
				) NI ON NI.[vcc] = TT.[VCC] AND NI.[cognitiveId] = TTI.[ID]
				WHERE 
				SR.StudyId = @ProcessResult AND
				SR.VCC = @Vcc AND
				SRD.TranscriptionId = @IdInteraction +'_'+@Section+'_'+@part	
		
	END

END
GO
PRINT N'Altering Procedure [dbo].[GetEvaluations]...';


GO
ALTER PROCEDURE [dbo].[GetEvaluations] (
	@Instance Varchar(50) = NULL,
	@IdAuditor VARCHAR(MAX) = NULL,
	@IdAgent Varchar(MAX) = NULL,
   	@IdCampaign VARCHAR(MAX) = NULL,
	@IdEvaluationPlan VARCHAR(MAX) = NULL,
 	@EvaluationDateFrom VARCHAR(50) = '1980-01-01T00:00:00',
    @EvaluationDateTo VARCHAR(50) = '2050-01-01T23:59:59',
	@EvaluationHourFrom VARCHAR(50) = '00:00:00',
    @EvaluationHourTo VARCHAR(50) = '23:59:59',
	@InteractionMinDuration Int = 0,
    @InteractionMaxDuration Int = 86400,
    @InteractionOrigins Varchar(50) = NULL,
	@InteractionResults Varchar(MAX) = NULL,
	@EvaluationTypes Varchar(MAX) = NULL,
	@InteractionTags Varchar(MAX) = NULL,
	@InteractionFormats Varchar(50) = NULL,
	@InteractionCoached VARCHAR(50) = NULL,
	@InteractionIds     VARCHAR(MAX) = NULL,
	@EvaluationsLimit Int = 0,
	@ContactAddress Varchar(300) = NULL,
	@SentimentIds varchar(max) = NULL
)
AS
BEGIN
	SET NOCOUNT ON
	--RESULTADOS DE ANALYSIS DE SENTIMIENTOS	
	CREATE TABLE #SentimentAnalysisResult
   (
   VCC VARCHAR(50),
   InteractionId VARCHAR(250),
   InteractionSection NUMERIC(5,0),
   InteractionPart NUMERIC(5,0), 
   SentimentId VARCHAR(50),
   EvaluationPlanId VARCHAR(50),
   MaxScore NUMERIC(10,5)
   )
	;WITH SentimentInteractionTemp AS(
	SELECT VCC,InteractionId,InteractionSection, InteractionPart,InteractionInterval,max(Score) as MaxScore 
	FROM SentimentAnalysisResult 
	GROUP BY VCC,InteractionId,InteractionSection, InteractionPart, InteractionInterval, AnalysisType),
	SentimentAnalysisSummary as(
	SELECT SAR.VCC,SAR.InteractionId,SAR.InteractionSection,SAR.InteractionPart,SAR.SentimentId,IEP.IdEvaluationPlan, MaxScore 
	FROM SentimentInteractionTemp SIT
	INNER JOIN SentimentAnalysisResult SAR ON 
	SIT.VCC = SAR.VCC AND
	SIT.InteractionId = SAR.InteractionId AND
	SIT.InteractionSection = SAR.InteractionSection AND
	SIT.InteractionPart = SAR.InteractionPart AND
	SIT.InteractionInterval = SAR.InteractionInterval AND	
	SIT.MaxScore = SAR.Score AND
	SAR.AnalysisType = CASE WHEN @InteractionOrigins = NULL OR @InteractionOrigins ='' OR @InteractionOrigins ='IN,OUT' THEN 'general'
							WHEN @InteractionOrigins = 'OUT' THEN 'agent'
							WHEN @InteractionOrigins = 'IN' THEN 'client'  END

	INNER JOIN InteractionEvaluationPlan IEP ON 
	SIT.VCC = IEP.Instance AND
	SIT.InteractionId = IEP.IdInteraction AND	
	SIT.InteractionSection = IEP.InteractionSection AND
	SIT.InteractionPart = IEP.InteractionPart AND
	IEP.Instance = @Instance 	
	)
	INSERT INTO  #SentimentAnalysisResult
	SELECT * FROM SentimentAnalysisSummary
	--FIN ANALISIS DE SENTIMIENTOS

	IF (@EvaluationHourFrom = '') SET @EvaluationHourFrom = '00:00:00';
	IF (@EvaluationHourTo = '') SET @EvaluationHourTo = '23:59:59';
	
	-- SI ORIGINS TIENE DOS VALORES, IGNORAMOS EL FILTRO
	IF (SELECT COUNT(*) FROM [dbo].[split](@InteractionOrigins, ',')) = 2 SET @InteractionOrigins = ''
	
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
	DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = ''

	-- EMULAMOS UNA NUEVA TABLA EN BASE A INTERACTIONEVALUATIONPLAN
	SET @SQL_SELECT_1 += '
		;WITH CTE AS (
			SELECT ER.[Instance],
					ER.[IdEvaluationPlan],
					ER.[IdInteraction], 
					ER.[IdAgent],
					IEP.[AgentName],
					SAR.[SentimentId],
					RN = ROW_NUMBER() OVER(PARTITION BY IEP.[Instance], IEP.[IdEvaluationPlan], IEP.[IdInteraction] ORDER BY IEP.[CreatedDate] ASC)
				FROM [dbo].[EvaluationResult] ER (NOLOCK) 
				INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
					ON EP.[Instance] = ER.[Instance]
						AND EP.[Id] =  ER.[IdEvaluationPlan]
				INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
					ON (AEP.[Instance] = ER.[Instance] 
						AND AEP.[IdAuditor] = ER.[IdAuditor] 
						AND AEP.[IdInteraction] = ER.[IdInteraction] 
						AND AEP.[InteractionType] = ER.[InteractionType] 
						AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]) 
				INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
					ON IEP.[Instance] = ER.[Instance] 
						AND IEP.[IdEvaluationPlan] = EP.[ID]
						AND IEP.[IdInteraction] = ER.[IdInteraction]
						AND IEP.[IdAgent] = ER.[IdAgent]
				LEFT JOIN #SentimentAnalysisResult SAR
				ON IEP.[Instance] = SAR.[VCC] 
						AND IEP.[IdEvaluationPlan] = SAR.[EvaluationPlanId]
						AND IEP.[IdInteraction] = SAR.[InteractionId]
						AND IEP.[InteractionSection] = SAR.[InteractionSection]
						AND IEP.[InteractionPart] = SAR.[InteractionPart]
				WHERE ER.[Instance] = ''' + @Instance + '''
					AND ER.[EvaluationDate] BETWEEN ''' + @EvaluationDateFrom + '''AND ''' + @EvaluationDateTo + '''
					AND EP.[Status] = CASE EP.[Evaluation_Mode] WHEN ''A'' THEN 7 ELSE EP.[Status] END 
					AND AEP.[Completed] = 1
		),
		SUMMARIZED_CTE AS (
			SELECT [Instance],
					[IdEvaluationPlan],
					[IdInteraction], 
					[IdAgent],
					[AgentName],
					[SentimentId]
				FROM CTE
				WHERE RN = 1
		) '

	SET @SQL_SELECT_1 += '
		SELECT '

	SET @SQL_SELECT_1 += '
				AEP.Completed						''completed'',
				AEP.[StatusDescription]             ''statusDescription'',
				A.[ErrorMessage]                    ''errorMessage'',
    			AEP.score							''qualification'',
    			AEP.IdAuditor						''idAuditor'',
    			U.FirstName + '' '' + U.LastName	''auditorName'',
    			MAX(ER.EvaluationDate)				''evaluationDate'',
    			AEP.IdEvaluationPlan				''idEvaluationPlan'',
				EP.Description						''evaluationPlan'',
				EP.[Evaluation_Mode]				''evaluationType'',
    			AEP.idAgent							''idAgent'',
    			C.[AgentName]						''agentName'',							-- NOMBRE DEL AGENTE
				AEP.idInteraction					''idInteraction'',
				AEP.InteractionDate					''interactionDate'',
    			AEP.InteractionType					''interactionType'',
    			AEP.IdCampaign						''idCampaign'',
				E.[Type]							''environmentType'',
				IIF (
					ERV.[InteractionId] IS NULL,
					CAST(0 AS BIT),
					CAST(1 AS BIT)
				)									''review'',
				COUNT(ERC.[Id])						''commitments'',
				C.SentimentId						''sentimentResult '' '

	SET @SQL_FROM += '
			FROM EvaluationResult ER (NOLOCK) 
			INNER JOIN SUMMARIZED_CTE C (NOLOCK) 
				ON C.[Instance] = ER.[Instance]
					AND C.[IdEvaluationPlan] = ER.[IdEvaluationPlan]
					AND C.[IdInteraction] = ER.[IdInteraction] 
					AND C.[IdAgent] = ER.[IdAgent] 
			INNER JOIN [EvaluationPlan] EP (NOLOCK) 
				ON (EP.[Instance] = ER.[Instance] 
					AND EP.[ID] = ER.IdEvaluationPlan) 
			LEFT JOIN [AuditorEvaluationPlan] AEP (NOLOCK) 
				ON (AEP.[Instance] = ER.[Instance] 
					AND AEP.[IdAuditor] = ER.[IdAuditor] 
					AND AEP.[IdInteraction] = ER.[IdInteraction] 
					AND AEP.[InteractionType] = ER.[InteractionType] 
					AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]) 
			LEFT JOIN [dbo].[EvaluationReview] ERV (NOLOCK)
				ON ERV.[VCC] = AEP.[Instance]
					AND ERV.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
					AND ERV.[InteractionId] = AEP.[IdInteraction]
			LEFT JOIN [dbo].[EvaluationReviewCommitment] ERC (NOLOCK)
				ON ERC.[VCC] = AEP.[Instance] 
					AND ERC.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
					AND ERC.[InteractionId] = AEP.[IdInteraction]
					-- AND ERC.[SupervisorId] = AEP.[IdAuditor] 
					AND ERC.[AgentId] = AEP.[idAgent]
			LEFT JOIN [dbo].[Audio] A (NOLOCK)
			    ON A.[VCC] = AEP.[Instance]
			        AND A.[ID] = AEP.[IdInteraction]			
			LEFT JOIN [dbo].[Environment] E (NOLOCK)
				ON E.[VCC] = ER.[Instance]
					AND E.[Name] = EP.[EnvironmentId]
			LEFT JOIN [User] U (NOLOCK) 
				ON (U.[VCC] = ER.[Instance] 
					AND U.ID = AEP.IdAuditor) '

	SET @FILTERS_FIXED_PART = '
			WHERE ER.[Instance] = ''' + @Instance + '''
				AND ER.[EvaluationDate] >= ''' + @EvaluationDateFrom + '''
				AND ER.[EvaluationDate] <= ''' + @EvaluationDateTo + '''
				AND EP.[Status] = CASE EP.[Evaluation_Mode] WHEN ''A'' THEN 7 ELSE EP.[Status] END 
				AND AEP.[Completed] = 1 ' -- LINEA PARA FILTRAR EVALUACIONES COMPLETADAS

	IF (@IdAuditor IS NOT NULL AND @IdAuditor != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAuditor] IN (SELECT Value FROM [dbo].[split](''' + @IdAuditor + ''','','')) '
	IF (@IdAgent IS NOT NULL AND @IdAgent != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgent + ''','','')) '
	IF (@IdCampaign IS NOT NULL AND @IdCampaign != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaign + ''','','')) '
	IF (@IdEvaluationPlan IS NOT NULL AND @IdEvaluationPlan != '') SET @FILTERS_OPTIONAL_PART += 'AND EP.[ID] IN (SELECT Value FROM [dbo].[split](''' + @IdEvaluationPlan + ''','','')) '
	IF (CAST(@EvaluationHourFrom AS TIME) <= CAST(@EvaluationHourTo AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ER.[EvaluationDate] AS TIME) BETWEEN ''' + @EvaluationHourFrom + ''' AND ''' + @EvaluationHourTo + ''' '
	IF (CAST(@EvaluationHourFrom AS TIME) > CAST(@EvaluationHourTo AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ER.[EvaluationDate] AS TIME) NOT BETWEEN ''' + @EvaluationHourTo + ''' AND ''' + @EvaluationHourFrom + ''' '
	IF (@InteractionMinDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionDuration] >= ' + (SELECT CONVERT(varchar(10), @InteractionMinDuration)) + ' '
	IF (@InteractionMaxDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionDuration] <= ' + (SELECT CONVERT(varchar(10), @InteractionMaxDuration))+ ' '
	IF (@InteractionOrigins IS NOT NULL AND @InteractionOrigins != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionOrigin] IN (SELECT Value FROM [dbo].[split](''' + @InteractionOrigins + ''','','')) '
	--IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') SET @FILTERS_OPTIONAL_PART += 'AND CONCAT(AEP.[IdCampaign], ''_'', AEP.[ManagementResult]) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')) '
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND (
								(CONCAT(AEP.[IdCampaign], ISNULL(REPLACE(AEP.[ManagementResult], ''/'', ''_''), ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(CONCAT(AEP.[IdCampaign], ''_'', ISNULL(AEP.[ManagementResult], ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(AEP.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
							)'
	
	IF (@EvaluationTypes IS NOT NULL AND @EvaluationTypes != '') 
	BEGIN
		SET @FILTERS_OPTIONAL_PART += '
				AND EP.[Evaluation_Mode] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationTypes + ''','',''))  '
	END

	IF(@ContactAddress <> '')
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND AEP.[ContactAddress] LIKE ''%' + @ContactAddress + '%''
			'
	END	
	IF (@SentimentIds IS NOT NULL AND @SentimentIds <> '')
        BEGIN            
	        SET @FILTERS_OPTIONAL_PART=' AND C.[SentimentId] IN (SELECT Value FROM [dbo].[split](''' + @SentimentIds + ''','','')) '
        END
	
	IF (@InteractionTags IS NOT NULL AND @InteractionTags != '') 
	BEGIN
		SET @SQL_FROM += '
			LEFT JOIN [Tag] T (NOLOCK) 
				ON (T.[VCC] = ER.[Instance] 
					AND T.[Tag] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTags + ''','',''))) '
		SET @FILTERS_OPTIONAL_PART += '
				AND T.[AudioId] LIKE CONCAT(AEP.[IdInteraction], ''%'') 
				AND T.[AudioId] IS NOT NULL '
	END
	
	--IF (@InteractionFormats IS NOT NULL AND @InteractionFormats != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionFormat] IN (SELECT Value FROM [dbo].[split](''' + @InteractionFormats + ''','','')) '

	IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
    BEGIN
        SET @FILTERS_OPTIONAL_PART = ''
	    SET @FILTERS_EXCLUDING_PART += ' AND AEP.[IdInteraction] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) '
	END

	SET @SQL_EXTRA += '
			GROUP BY AEP.Completed,
						AEP.[StatusDescription],
						A.[ErrorMessage],
						AEP.score,
						AEP.IdAuditor,
						U.FirstName + '' '' + U.LastName,
						AEP.IdEvaluationPlan,
						EP.Description,
						EP.[Evaluation_Mode],
						AEP.idAgent,
						C.[AgentName],
						AEP.idInteraction,
						AEP.InteractionDate,
						AEP.InteractionType,
						AEP.IdCampaign, 
						E.[Type],
						ERV.[InteractionId],
						C.SentimentId'

	IF @InteractionCoached IS NOT NULL AND @InteractionCoached != ''
	BEGIN
		IF @InteractionCoached = 'true'
			SET @SQL_EXTRA += '
				HAVING COUNT(ERC.[Id]) >= 1 '
		ELSE 
			SET @SQL_EXTRA += '
				HAVING COUNT(ERC.[Id]) = 0 '
	END

	SET @SQL_EXTRA += '
			ORDER BY MAX(ER.EvaluationDate) DESC '

	SET @SQL_SELECT_1 += @SQL_FROM  + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA 
	print(@SQL_SELECT_1)
	-- SELECT @SQL_SELECT_1
	EXEC (@SQL_SELECT_1)
	
END
GO
PRINT N'Creating Procedure [dbo].[SaveSentimentAnalysisResult]...';


GO
CREATE PROCEDURE [dbo].[SaveSentimentAnalysisResult] (
	@VCC varchar(50),
	@InteractionId varchar(250),
	@InteractionSection numeric(5,0),
	@InteractionPart numeric(5,0),
	@InteractionType varchar(50),
	@InteractionInterval numeric(5,0),
	@AnalysisType varchar(50),
	@SentimentId varchar(50),
	@AppId varchar(50),
	@Score numeric(10,5),
	@CreatedDate datetime,
	@CreatedByUserId varchar(50),
	@LastModifiedDate datetime,
	@LastModifiedByUserId varchar(50)
	)
AS
BEGIN
	SET NOCOUNT ON
	UPDATE [SentimentAnalysisResult]
	SET [VCC] = @VCC,
		[InteractionId] = @InteractionId,
		[InteractionSection] = @InteractionSection,
		[InteractionPart] = @InteractionPart,
		[InteractionType] = @InteractionType,
		[InteractionInterval] = @InteractionInterval,
		[AnalysisType] = @AnalysisType,
		[SentimentId] = @SentimentId,
		[AppId] = @AppId,
		[Score] = @Score,		
		[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
		[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
		[LastModifiedDate] = GETUTCDATE(),
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[TimeStamp] = GETUTCDATE()
		
	WHERE [VCC] = @VCC
    AND [InteractionId] = @InteractionId
	AND [InteractionSection] = @InteractionSection
	AND	[InteractionPart] = @InteractionPart
	AND [InteractionType] = @InteractionType
	AND [InteractionInterval] = @InteractionPart
	AND [AnalysisType] = @AnalysisType
	AND [SentimentId] = @SentimentId
	AND [AppId] = @AppId

    IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [SentimentAnalysisResult] (
			[VCC], 
			[InteractionId],
			[InteractionSection],
			[InteractionPart],
			[InteractionType],
			[InteractionInterval],
			[AnalysisType],
			[SentimentId],
			[AppId],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate],
			[LastModifiedByUserId],
			[TimeStamp]

			)
		VALUES (
			@VCC,
			@InteractionId,
			@InteractionSection,
			@InteractionPart,
			@InteractionType,
			@InteractionInterval,
			@AnalysisType,
			@SentimentId,
			@AppId,
			GETUTCDATE(),
			@CreatedByUserId,
			GETUTCDATE(),
			@LastModifiedByUserId,
			GETUTCDATE()
		)
	END
	
	

    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
PRINT N'Refreshing Procedure [dbo].[SaveVcc]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveVcc]';


GO
PRINT N'Update complete.';


GO