-- ARCHIVO CON LAS ACTUALIZACIONES DE DATA DE SQL PARA MIGRAR AL NUEVO BUILD DEL NOMBRE DE LA CARPETA
-- DECLARAMOS DOS VARIABLES, UNA CON LA VERSION DE LA QUE PARTIMOS Y OTRA CON LA NUEVA VERSION QUE ESTAMOS APUNTANDO
DECLARE @OLD_DATABASE_BUILD_VERSION VARCHAR(50) = '3.4.0'
DECLARE @NEW_DATABASE_BUILD_VERSION VARCHAR(50) = '3.4.0'

-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
BEGIN TRY
    -- VALIDAMOS QUE LA VERSION EXISTENTE COINCIDE CON NUESTRA NEW_DATABASE_BUILD_VERSION
    IF NOT EXISTS (
        SELECT 1 
            FROM [dbo].[Version] V 
            WHERE V.[BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    )	
        -- LANZAMOS UN MENSAJE DE ERROR INDICANDO QUE LA VERSION ACTUAL NO COINCIDE CON LA OLD_DATABASE_BUILD_VERSION
        RAISERROR('DATABASE_ERROR_INCORRECT_TARGET_VERSION', 16, 16)
        
    -- INICIAMOS LA TRANSACCION
    BEGIN TRANSACTION




    -- AQUI EMPIEZA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION



        -- INSERTAMOS LOS GRUPOS Y SUBGRUPOS POR DEFECTO PARA EL VCC SYSTEM
        INSERT INTO [dbo].[Group] ([Instance], [ID], [Description], [CreatedDate], [CreatedByUserId], [TimeStamp], [Enabled]) VALUES (N'system', NEWID(), N'DEFAULT_COPC_GROUP_CRITICAL_ERROR', GETUTCDATE(), N'system', GETUTCDATE(), 1)
        INSERT INTO [dbo].[Group] ([Instance], [ID], [Description], [CreatedDate], [CreatedByUserId], [TimeStamp], [Enabled]) VALUES (N'system', NEWID(), N'DEFAULT_COPC_GROUP_NOT_CRITICAL_ERROR', GETUTCDATE(), N'system', GETUTCDATE(), 1)
        INSERT INTO [dbo].[SubGroup] ([Instance], [ID], [Description], [CreatedDate], [CreatedByUserId], [TimeStamp], [Enabled]) VALUES (N'system', NEWID(), N'DEFAULT_COPC_SUBGROUP_FINAL_USER_CRITICAL_ERROR', GETUTCDATE(), N'system', GETUTCDATE(), 1)
        INSERT INTO [dbo].[SubGroup] ([Instance], [ID], [Description], [CreatedDate], [CreatedByUserId], [TimeStamp], [Enabled]) VALUES (N'system', NEWID(), N'DEFAULT_COPC_SUBGROUP_BUSINESS_CRITICAL_ERROR', GETUTCDATE(), N'system', GETUTCDATE(), 1)
        INSERT INTO [dbo].[SubGroup] ([Instance], [ID], [Description], [CreatedDate], [CreatedByUserId], [TimeStamp], [Enabled]) VALUES (N'system', NEWID(), N'DEFAULT_COPC_SUBGROUP_COMPLIANCE_CRITICAL_ERROR', GETUTCDATE(), N'system', GETUTCDATE(), 1)
        INSERT INTO [dbo].[SubGroup] ([Instance], [ID], [Description], [CreatedDate], [CreatedByUserId], [TimeStamp], [Enabled]) VALUES (N'system', NEWID(), N'DEFAULT_COPC_SUBGROUP_NOT_CRITICAL_ERROR', GETUTCDATE(), N'system', GETUTCDATE(), 1)

        -- INSERTAMOS TRADUCCIONES PARA LA TABLA
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_GROUP_CRITICAL_ERROR',N'es',N'Error crítico')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_GROUP_CRITICAL_ERROR',N'en',N'Not critical error')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_GROUP_CRITICAL_ERROR',N'fr',N'Error crítico')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_GROUP_CRITICAL_ERROR',N'pt',N'Error crítico')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_GROUP_NOT_CRITICAL_ERROR',N'es',N'Error no crítico')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_GROUP_NOT_CRITICAL_ERROR',N'en',N'Not critical error')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_GROUP_NOT_CRITICAL_ERROR',N'fr',N'Error no crítico')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_GROUP_NOT_CRITICAL_ERROR',N'pt',N'Error no crítico')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_SUBGROUP_FINAL_USER_CRITICAL_ERROR',N'es',N'Error crítico - Usuario final (ECU)')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_SUBGROUP_FINAL_USER_CRITICAL_ERROR',N'en',N'Critical error - Final user (CEU)')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_SUBGROUP_FINAL_USER_CRITICAL_ERROR',N'fr',N'Error crítico - Usuario final (ECU)')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_SUBGROUP_FINAL_USER_CRITICAL_ERROR',N'pt',N'Error crítico - Usuario final (ECU)')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_SUBGROUP_BUSINESS_CRITICAL_ERROR',N'es',N'Error crítico - Negocio (ECU)')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_SUBGROUP_BUSINESS_CRITICAL_ERROR',N'en',N'Critical error - Business (CEB)')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_SUBGROUP_BUSINESS_CRITICAL_ERROR',N'fr',N'Error crítico - Negocio (ECU)')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_SUBGROUP_BUSINESS_CRITICAL_ERROR',N'pt',N'Error crítico - Negocio (ECU)')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_SUBGROUP_COMPLIANCE_CRITICAL_ERROR',N'es',N'Error crítico - Cumplimiento (ECC)')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_SUBGROUP_COMPLIANCE_CRITICAL_ERROR',N'en',N'Critical error - Compliance (CEC)')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_SUBGROUP_COMPLIANCE_CRITICAL_ERROR',N'fr',N'Error crítico - Cumplimiento (ECC)')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_SUBGROUP_COMPLIANCE_CRITICAL_ERROR',N'pt',N'Error crítico - Cumplimiento (ECC)')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_SUBGROUP_NOT_CRITICAL_ERROR',N'es',N'Error no crítico')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_SUBGROUP_NOT_CRITICAL_ERROR',N'en',N'Not critical error')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_SUBGROUP_NOT_CRITICAL_ERROR',N'fr',N'Error no crítico')
        INSERT [dbo].[WordsByLanguage] ([Label],[Language],[Word]) VALUES(N'DEFAULT_COPC_SUBGROUP_NOT_CRITICAL_ERROR',N'pt',N'Error no crítico')

        -- INSERTAMOS PERMISOS QUE PODRIAN FALTAR EN LAS PLATAFORMAS INSTALADAS POR PRIMERA VEZ CON EL BUILD 0.16.0, EN CASO YA EXISTAN NO SE INSERTAN
        DECLARE RECURRENT_CURSOR CURSOR 
        LOCAL STATIC READ_ONLY FORWARD_ONLY
        FOR 
        -- SELECCIONAMOS LOS VCC EXISTENTES
        SELECT [VCC], [Language]
            FROM [dbo].[VCC] (NOLOCK) 

        -- DECLARARAMOS UNA VARIABLE PARA INDICAR EL CAMPO ACTUAL QUE ESTAMOS ACTUALIZANDO
        DECLARE @CURRENT_VCC_TO_UPDATE VARCHAR(50) = ''
        DECLARE @CURRENT_LANGUAGE_TO_UPDATE VARCHAR(50) = ''

        -- ABRIMOS Y RECORREMOS EL ARRAY DE CAMPOS A ACTUALIZAR
        OPEN RECURRENT_CURSOR

        FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_VCC_TO_UPDATE, @CURRENT_LANGUAGE_TO_UPDATE
        WHILE @@FETCH_STATUS = 0
        BEGIN 
            -- INSERTAMOS LOS GRUPOS POR DEFECTO PARA COPC
            INSERT INTO [dbo].[Group] ([Instance], [ID], [Description], [CreatedDate], [CreatedByUserId], [TimeStamp], [Enabled])
                SELECT @CURRENT_VCC_TO_UPDATE,
                        G.[Description],
                        WBL.[Word],
                        GETUTCDATE(),
                        'system',
                        GETUTCDATE(),
                        1
                    FROM [dbo].[Group] G (NOLOCK)
                    INNER JOIN [dbo].[WordsByLanguage] WBL (NOLOCK)
                        ON WBL.[Label] = G.[Description]
                    WHERE G.[Instance] = 'system'
                        AND WBL.[Language] = @CURRENT_LANGUAGE_TO_UPDATE

            -- INSERTAMOS LOS SUBGRUPOS POR DEFECTO PARA COPC
            INSERT INTO [dbo].[SubGroup] ([Instance], [ID], [Description], [CreatedDate], [CreatedByUserId], [TimeStamp], [Enabled])
                SELECT @CURRENT_VCC_TO_UPDATE,
                        SG.[Description],
                        WBL.[Word],
                        GETUTCDATE(),
                        'system',
                        GETUTCDATE(),
                        1
                    FROM [dbo].[SubGroup] SG (NOLOCK)
                    INNER JOIN [dbo].[WordsByLanguage] WBL (NOLOCK)
                        ON WBL.[Label] = SG.[Description]
                    WHERE SG.[Instance] = 'system'
                        AND WBL.[Language] = @CURRENT_LANGUAGE_TO_UPDATE

            -- FIN DEL SCRIPT DE INSERT/UPDATE/DELETE PARA CADA VCC EN LA VARIABLE @CURRENT_VCC_TO_UPDATE

            FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_VCC_TO_UPDATE, @CURRENT_LANGUAGE_TO_UPDATE
        END
        CLOSE RECURRENT_CURSOR
        DEALLOCATE RECURRENT_CURSOR

        
    -- AQUI TERMINA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION


    

    -- TERMINAMOS LA ACTUALIZACION DE DATA ACTUALIZANDO EL BUILDVERSION
    UPDATE [dbo].[Version] 
        SET [BuildVersion] = @NEW_DATABASE_BUILD_VERSION, 
            [IsRegistered] = 0,
            [TimeStamp] = GETUTCDATE() 
        WHERE [BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    PRINT 'UPDATED_DATABASE_BUILD_VERSION'

    -- COMPLETAMOS LA TRANSACCION
    COMMIT TRANSACTION
END TRY
BEGIN CATCH
    IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

    DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
    DECLARE @Severity integer = ERROR_SEVERITY()
    DECLARE @State integer = ERROR_STATE()

    RAISERROR(@Message, @Severity, @State)
    --RETURN -1
END CATCH
