-- ARCHIVO CON LAS ACTUALIZACIONES DE DATA DE SQL PARA MIGRAR AL NUEVO BUILD DEL NOMBRE DE LA CARPETA
-- DECLARAMOS DOS VARIABLES, UNA CON LA VERSION DE LA QUE PARTIMOS Y OTRA CON LA NUEVA VERSION QUE ESTAMOS APUNTANDO
DECLARE @OLD_DATABASE_BUILD_VERSION VARCHAR(50) = '3.5.6'
DECLARE @NEW_DATABASE_BUILD_VERSION VARCHAR(50) = '3.5.6'

-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
BEGIN TRY
    -- VALIDAMOS QUE LA VERSION EXISTENTE COINCIDE CON NUESTRA NEW_DATABASE_BUILD_VERSION
    IF NOT EXISTS (
        SELECT 1 
            FROM [dbo].[Version] V 
            WHERE V.[BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    )	
        -- LANZAMOS UN MENSAJE DE ERROR INDICANDO QUE LA VERSION ACTUAL NO COINCIDE CON LA OLD_DATABASE_BUILD_VERSION
        RAISERROR('DATABASE_ERROR_INCORRECT_TARGET_VERSION', 16, 16)
        
    -- INICIAMOS LA TRANSACCION
    BEGIN TRANSACTION




    -- AQUI EMPIEZA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION

        -- INSERTAMOS PERMISOS QUE PODRIAN FALTAR EN LAS PLATAFORMAS INSTALADAS POR PRIMERA VEZ CON EL BUILD 0.16.0, EN CASO YA EXISTAN NO SE INSERTAN
        DECLARE RECURRENT_CURSOR CURSOR 
        LOCAL STATIC READ_ONLY FORWARD_ONLY
        FOR 
        -- SELECCIONAMOS LOS VCC EXISTENTES
        SELECT [VCC]
            FROM [dbo].[VCC] (NOLOCK) 

        -- DECLARARAMOS UNA VARIABLE PARA INDICAR EL CAMPO ACTUAL QUE ESTAMOS ACTUALIZANDO
        DECLARE @CURRENT_VCC_TO_UPDATE VARCHAR(50) = ''

        -- ABRIMOS Y RECORREMOS EL ARRAY DE CAMPOS A ACTUALIZAR
        OPEN RECURRENT_CURSOR

        FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_VCC_TO_UPDATE
        WHILE @@FETCH_STATUS = 0
        BEGIN 
            -- DASHBOARD (Auditor no debería ver el dashboard de speech)
            -- INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_SPEECH_DASHBOARD', N'api/schedule/get_scheduled_template_results_summary', N'api', GETUTCDATE())
            -- INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_SPEECH_DASHBOARD', N'api/idatha_auth/get_idatha_auth_by_realm ', N'api', GETUTCDATE())

            -- INBOX
            INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_AUDITOR_INBOX', N'api/schedule/get_template_schedules', N'api', GETUTCDATE())
            INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_AUDITOR_INBOX', N'api/intent/get_intents/', N'api', GETUTCDATE())            
            INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_EVALUATION_VIEW', N'api/intent/get_intents/', N'api', GETUTCDATE())
            INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_EVALUATIONPLAN_VIEW', N'api/intent/get_intents/', N'api', GETUTCDATE())

            -- FIN DEL SCRIPT DE INSERT/UPDATE/DELETE PARA CADA VCC EN LA VARIABLE @CURRENT_VCC_TO_UPDATE

            FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_VCC_TO_UPDATE
        END
        CLOSE RECURRENT_CURSOR
        DEALLOCATE RECURRENT_CURSOR

    -- AQUI TERMINA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION





    -- TERMINAMOS LA ACTUALIZACION DE DATA ACTUALIZANDO EL BUILDVERSION
    UPDATE [dbo].[Version] 
        SET [BuildVersion] = @NEW_DATABASE_BUILD_VERSION, 
            [IsRegistered] = 0,
            [TimeStamp] = GETUTCDATE() 
        WHERE [BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    PRINT 'UPDATED_DATABASE_BUILD_VERSION'

    -- COMPLETAMOS LA TRANSACCION
    COMMIT TRANSACTION
END TRY
BEGIN CATCH
    IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

    DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
    DECLARE @Severity integer = ERROR_SEVERITY()
    DECLARE @State integer = ERROR_STATE()

    RAISERROR(@Message, @Severity, @State)
    --RETURN -1
END CATCH
